Title | Impact

ABA JOURNAL | 0,534

ACADEME-BULLETIN OF THE AAUP | 0,376

ACADEMIC PSYCHIATRY | 0,340

ACADEMY OF MANAGEMENT JOURNAL | 2,375

ACADEMY OF MANAGEMENT REVIEW | 3,912

ACCIDENT ANALYSIS AND PREVENTION | 0,686

ACCOUNTING ORGANIZATIONS AND SOCIETY | 0,437

ACCOUNTING REVIEW | 0,630

ACTA PSYCHIATRICA SCANDINAVICA | 1,774

ACTA PSYCHOLOGICA | 1,267

ACTA SOCIOLOGICA | 0,634

ADAPTIVE BEHAVIOR | 0,667

ADDICTION | 2,494

ADDICTION RESEARCH | 0,596

ADDICTIVE BEHAVIORS | 0,978

ADMINISTRATION & SOCIETY | 0,308

ADMINISTRATION AND POLICY IN MENTAL HEALTH | 0,574

ADMINISTRATION IN SOCIAL WORK | 0,485

ADMINISTRATIVE LAW REVIEW | 0,600

ADMINISTRATIVE SCIENCE QUARTERLY | 3,333

ADOLESCENCE | 0,444

ADOLESCENT PSYCHIATRY | 0,290

ADULT EDUCATION QUARTERLY | 0,414

ADVANCES IN CHILD DEVELOPMENT AND BEHAVIOR |

ADVANCES IN CONSUMER RESEARCH | 0,107

ADVANCES IN ECONOMETRICS : A RESEARCH ANNUAL | 0,000

ADVANCES IN EXPERIMENTAL SOCIAL PSYCHOLOGY | 5,250

ADVANCES IN NURSING SCIENCE | 0,818

ADVANCES IN STRATEGIC MANAGEMENT : A RESEARCH ANNUAL | 0,739

AFFILIA-JOURNAL OF WOMEN AND SOCIAL WORK | 0,317

AFRICA | 0,565

AFRICA TODAY | 0,341

AFRICAN AFFAIRS | 0,605

AGEING AND SOCIETY | 0,721

AGGRESSION AND VIOLENT BEHAVIOR | 0,755

AGGRESSIVE BEHAVIOR | 0,815

AGING & MENTAL HEALTH | 0,526

AGING NEUROPSYCHOLOGY AND COGNITION | 0,725

AGRICULTURAL ECONOMICS | 0,429

AGRICULTURAL HISTORY | 0,133

AIDS & PUBLIC POLICY JOURNAL | 0,524

AIDS CARE-PSYCHOLOGICAL AND SOCIO-MEDICAL ASPECTS OF AIDS/HIV | 0,942

AIDS EDUCATION AND PREVENTION | 1,044

AIDS PATIENT CARE AND STDS | 0,304

ALBERTA JOURNAL OF EDUCATIONAL RESEARCH | 0,041

ALCOHOL HEALTH & RESEARCH WORLD | 0,676

ALCOHOL RESEARCH & HEALTH | 0,429

ALTERNATIVES-SOCIAL TRANSFORMATION AND HUMANE GOVERNANCE | 0,324

AMERICAN ANNALS OF THE DEAF | 0,766

AMERICAN ANTHROPOLOGIST | 0,710

AMERICAN ANTIQUITY | 1,100

AMERICAN BANKRUPTCY LAW JOURNAL | 1,294

AMERICAN BEHAVIORAL SCIENTIST | 0,619

AMERICAN BUSINESS LAW JOURNAL | 0,633

AMERICAN CRIMINAL LAW REVIEW | 1,125

AMERICAN ECONOMIC REVIEW | 1,795

AMERICAN ETHNOLOGIST | 0,453

AMERICAN HISTORICAL REVIEW | 1,217

AMERICAN INDIAN AND ALASKA NATIVE MENTAL HEALTH RESEARCH | 0,556

AMERICAN JOURNAL OF AGRICULTURAL ECONOMICS | 0,674

AMERICAN JOURNAL OF ART THERAPY | 0,056

AMERICAN JOURNAL OF CLINICAL HYPNOSIS | 0,227

AMERICAN JOURNAL OF COMMUNITY PSYCHOLOGY | 1,500

AMERICAN JOURNAL OF COMPARATIVE LAW | 2,114

AMERICAN JOURNAL OF DRUG AND ALCOHOL ABUSE | 1,053

AMERICAN JOURNAL OF ECONOMICS AND SOCIOLOGY | 0,167

AMERICAN JOURNAL OF EDUCATION | 0,900

AMERICAN JOURNAL OF EVALUATION | 1,147

AMERICAN JOURNAL OF FAMILY THERAPY | 0,327

AMERICAN JOURNAL OF GERIATRIC PSYCHIATRY | 1,802

AMERICAN JOURNAL OF HEALTH BEHAVIOR | 0,297

AMERICAN JOURNAL OF HEALTH PROMOTION | 1,011

AMERICAN JOURNAL OF HUMAN BIOLOGY | 0,695

AMERICAN JOURNAL OF INTERNATIONAL LAW | 2,667

AMERICAN JOURNAL OF LAW & MEDICINE | 1,594

AMERICAN JOURNAL OF LEGAL HISTORY | 0,091

AMERICAN JOURNAL OF MANAGED CARE | 0,642

AMERICAN JOURNAL OF NURSING | 0,181

AMERICAN JOURNAL OF OCCUPATIONAL THERAPY | 0,770

AMERICAN JOURNAL OF ORTHOPSYCHIATRY | 1,939

AMERICAN JOURNAL OF PHYSICAL ANTHROPOLOGY | 1,827

AMERICAN JOURNAL OF POLITICAL SCIENCE | 1,788

AMERICAN JOURNAL OF PSYCHIATRY | 6,577

AMERICAN JOURNAL OF PSYCHOLOGY | 0,286

AMERICAN JOURNAL OF PSYCHOTHERAPY | 0,362

AMERICAN JOURNAL OF PUBLIC HEALTH | 3,269

AMERICAN JOURNAL OF SOCIOLOGY | 2,829

AMERICAN JOURNAL OF SPEECH-LANGUAGE PATHOLOGY | 1,127

AMERICAN JOURNAL ON ADDICTIONS | 0,941

AMERICAN JOURNAL ON MENTAL RETARDATION | 1,478

AMERICAN POLITICAL SCIENCE REVIEW | 2,211

AMERICAN POLITICS QUARTERLY | 0,318

AMERICAN PSYCHOLOGIST | 6,857

AMERICAN REVIEW OF PUBLIC ADMINISTRATION | 0,333

AMERICAN SOCIOLOGICAL REVIEW | 3,255

ANALYTISCHE PSYCHOLOGIE | 0,071

ANIMAL LEARNING & BEHAVIOR | 1,105

ANNALS OF BEHAVIORAL MEDICINE | 2,506

ANNALS OF DYSLEXIA | 0,320

ANNALS OF REGIONAL SCIENCE | 0,763

ANNALS OF SCIENCE | 0,379

ANNALS OF THE AMERICAN ACADEMY OF POLITICAL AND SOCIAL SCIENCE | 0,527

ANNALS OF THE ASSOCIATION OF AMERICAN GEOGRAPHERS | 2,109

ANNALS OF TOURISM RESEARCH | 0,318

ANNEE PSYCHOLOGIQUE | 0,238

ANNUAL REVIEW OF ANTHROPOLOGY | 1,089

ANNUAL REVIEW OF PSYCHOLOGY | 5,851

ANNUAL REVIEW OF PUBLIC HEALTH | 4,524

ANNUAL REVIEW OF SOCIOLOGY | 2,809

ANTHROPOLOGICAL QUARTERLY | 0,182

ANTHROPOLOGICAL SCIENCE | 0,429

ANTHROPOLOGIE | 0,224

ANTHROPOLOGY & EDUCATION QUARTERLY | 0,293

ANTHROPOLOGY AND ARCHEOLOGY OF EURASIA | 0,111

ANTHROPOS | 0,206

ANTHROZOOS | 0,039

ANTIPODE | 1,226

ANTITRUST LAW JOURNAL | 1,750

APPLIED & PREVENTIVE PSYCHOLOGY | 1,325

APPLIED COGNITIVE PSYCHOLOGY | 0,929

APPLIED ECONOMICS | 0,213

APPLIED ECONOMICS LETTERS | 0,096

APPLIED ERGONOMICS | 0,642

APPLIED GEOGRAPHY | 0,413

APPLIED LINGUISTICS | 0,692

APPLIED MEASUREMENT IN EDUCATION | 0,279

APPLIED NURSING RESEARCH | 0,473

APPLIED PSYCHOLINGUISTICS | 0,818

APPLIED PSYCHOLOGICAL MEASUREMENT | 0,561

APPLIED PSYCHOLOGY-AN INTERNATIONAL REVIEW-PSYCHOLOGIE APPLIQUEE-REVUE INTE | 0,518

APPLIED PSYCHOPHYSIOLOGY AND BIOFEEDBACK | 0,700

ARCHIVE FOR HISTORY OF EXACT SCIENCES | 0,250

ARCHIVES EUROPEENNES DE SOCIOLOGIE | 0,269

ARCHIVES OF CLINICAL NEUROPSYCHOLOGY | 1,395

ARCHIVES OF GENERAL PSYCHIATRY | 11,778

ARCHIVES OF PSYCHIATRIC NURSING | 0,514

ARCHIVES OF SEXUAL BEHAVIOR | 1,271

ARCHIVES OF SUICIDE RESEARCH | 0,718

ARCTIC ANTHROPOLOGY | 0,130

AREA | 1,215

ARMED FORCES & SOCIETY | 0,067

ARTS IN PSYCHOTHERAPY | 0,240

ASIA PACIFIC JOURNAL OF SOCIAL WORK | 0,000

ASIAN JOURNAL OF WOMENS STUDIES | 0,024

ASIAN SURVEY | 0,225

ASLIB PROCEEDINGS | 0,397

ASSESSMENT | 0,918

ASSISTIVE TECHNOLOGY | 0,552

AUDITING-A JOURNAL OF PRACTICE & THEORY | 0,290

AUSSEN POLITIK | 0,125

AUSTRALIAN AND NEW ZEALAND JOURNAL OF CRIMINOLOGY | 0,079

AUSTRALIAN AND NEW ZEALAND JOURNAL OF PSYCHIATRY | 1,265

AUSTRALIAN AND NEW ZEALAND JOURNAL OF PUBLIC HEALTH | 1,047

AUSTRALIAN FEMINIST STUDIES | 0,054

AUSTRALIAN GEOGRAPHER | 0,590

AUSTRALIAN JOURNAL OF AGRICULTURAL AND RESOURCE ECONOMICS | 0,417

AUSTRALIAN JOURNAL OF EDUCATION | 0,054

AUSTRALIAN JOURNAL OF INTERNATIONAL AFFAIRS | 0,485

AUSTRALIAN JOURNAL OF POLITICAL SCIENCE | 0,361

AUSTRALIAN JOURNAL OF PSYCHOLOGY | 0,660

AUSTRALIAN JOURNAL OF PUBLIC ADMINISTRATION | 0,305

AUSTRALIAN JOURNAL OF SOCIAL ISSUES | 0,190

AUSTRALIAN PSYCHOLOGIST | 0,710

BASIC AND APPLIED SOCIAL PSYCHOLOGY | 0,375

BEHAVIOR ANALYST | 0,500

BEHAVIOR AND PHILOSOPHY | 0,273

BEHAVIOR GENETICS | 1,516

BEHAVIOR MODIFICATION | 0,734

BEHAVIOR RESEARCH METHODS INSTRUMENTS & COMPUTERS | 0,750

BEHAVIOR THERAPY | 1,494

BEHAVIORAL & SOCIAL SCIENCES LIBRARIAN | 0,000

BEHAVIORAL AND BRAIN SCIENCES | 14,250

BEHAVIORAL DISORDERS | 0,500

BEHAVIORAL HEALTHCARE TOMORROW | 0,149

BEHAVIORAL MEDICINE | 1,000

BEHAVIORAL SCIENCES & THE LAW | 0,929

BEHAVIOUR & INFORMATION TECHNOLOGY | 0,413

BEHAVIOUR CHANGE | 0,217

BEHAVIOUR RESEARCH AND THERAPY | 1,699

BEHAVIOURAL PROCESSES | 0,906

BERLINER JOURNAL FUR SOZIOLOGIE | 0,259

BETRIEBSWIRTSCHAFTLICHE FORSCHUNG UND PRAXIS | 0,261

BIJDRAGEN TOT DE TAAL- LAND- EN VOLKENKUNDE | 0,231

BIOETHICS | 0,630

BIOLOGICAL PSYCHOLOGY | 1,500

BIOLOGY & PHILOSOPHY | 0,627

BIRTH-ISSUES IN PERINATAL CARE | 1,250

BLACK SCHOLAR | 0,171

BOSTON UNIVERSITY LAW REVIEW | 1,254

BRAIN AND COGNITION | 0,630

BRAIN AND LANGUAGE | 1,473

BRITISH JOURNAL FOR THE HISTORY OF SCIENCE | 0,405

BRITISH JOURNAL FOR THE PHILOSOPHY OF SCIENCE | 0,867

BRITISH JOURNAL OF CLINICAL PSYCHOLOGY | 1,091

BRITISH JOURNAL OF CRIMINOLOGY | 0,791

BRITISH JOURNAL OF DEVELOPMENTAL DISABILITIES | 0,130

BRITISH JOURNAL OF DEVELOPMENTAL PSYCHOLOGY | 0,800

BRITISH JOURNAL OF EDUCATIONAL PSYCHOLOGY | 0,537

BRITISH JOURNAL OF EDUCATIONAL STUDIES | 0,628

BRITISH JOURNAL OF EDUCATIONAL TECHNOLOGY | 0,318

BRITISH JOURNAL OF FAMILY PLANNING | 0,791

BRITISH JOURNAL OF HEALTH PSYCHOLOGY | 0,981

BRITISH JOURNAL OF INDUSTRIAL RELATIONS | 1,000

BRITISH JOURNAL OF MATHEMATICAL & STATISTICAL PSYCHOLOGY | 1,257

BRITISH JOURNAL OF MEDICAL PSYCHOLOGY | 0,562

BRITISH JOURNAL OF POLITICAL SCIENCE | 0,803

BRITISH JOURNAL OF PSYCHIATRY | 4,827

BRITISH JOURNAL OF PSYCHOLOGY | 1,053

BRITISH JOURNAL OF SOCIAL PSYCHOLOGY | 1,352

BRITISH JOURNAL OF SOCIAL WORK | 0,489

BRITISH JOURNAL OF SOCIOLOGY | 0,697

BRITISH JOURNAL OF SOCIOLOGY OF EDUCATION | 0,948

BROOKINGS PAPERS ON ECONOMIC ACTIVITY | 3,926

BUFFALO LAW REVIEW | 1,043

BULLETIN OF CONCERNED ASIAN SCHOLARS | 0,315

BULLETIN OF INDONESIAN ECONOMIC STUDIES | 0,714

BULLETIN OF THE ATOMIC SCIENTISTS | 0,246

BULLETIN OF THE HISTORY OF MEDICINE | 0,556

BULLETIN OF THE MEDICAL LIBRARY ASSOCIATION | 0,343

BULLETIN OF THE MENNINGER CLINIC | 0,523

BUSINESS HISTORY | 0,978

BUSINESS HISTORY REVIEW | 0,480

BUSINESS LAWYER | 0,802

CAHIERS DE PSYCHOLOGIE COGNITIVE-CURRENT PSYCHOLOGY OF COGNITION | 0,260

CALIFORNIA LAW REVIEW | 2,695

CALIFORNIA MANAGEMENT REVIEW | 2,877

CAMBRIDGE JOURNAL OF ECONOMICS | 1,114

CAMBRIDGE QUARTERLY OF HEALTHCARE ETHICS | 0,466

CANADIAN GEOGRAPHER-GEOGRAPHE CANADIEN | 0,796

CANADIAN JOURNAL OF ADMINISTRATIVE SCIENCES-REVUE CANADIENNE DES SCIENCES D | 0,264

CANADIAN JOURNAL OF BEHAVIOURAL SCIENCE-REVUE CANADIENNE DES SCIENCES DU CO | 0,245

CANADIAN JOURNAL OF CRIMINOLOGY-REVUE CANADIENNE DE CRIMINOLOGIE | 0,262

CANADIAN JOURNAL OF ECONOMICS-REVUE CANADIENNE D ECONOMIQUE | 0,404

CANADIAN JOURNAL OF EXPERIMENTAL PSYCHOLOGY-REVUE CANADIENNE DE PSYCHOLOGIE | 0,500

CANADIAN JOURNAL OF INFORMATION AND LIBRARY SCIENCE-REVUE CANADIENNE DES SC | 0,167

CANADIAN JOURNAL OF LINGUISTICS-REVUE CANADIENNE DE LINGUISTIQUE | 0,238

CANADIAN JOURNAL OF POLITICAL SCIENCE-REVUE CANADIENNE DE SCIENCE POLITIQUE | 0,310

CANADIAN JOURNAL OF PSYCHIATRY-REVUE CANADIENNE DE PSYCHIATRIE | 1,623

CANADIAN JOURNAL OF PUBLIC HEALTH-REVUE CANADIENNE DE SANTE PUBLIQUE | 0,667

CANADIAN JOURNAL OF SOCIOLOGY-CAHIERS CANADIENS DE SOCIOLOGIE | 0,250

CANADIAN JOURNAL ON AGING-REVUE CANADIENNE DU VIEILLISSEMENT | 0,415

CANADIAN MODERN LANGUAGE REVIEW-REVUE CANADIENNE DES LANGUES VIVANTES | 0,180

CANADIAN PSYCHOLOGY-PSYCHOLOGIE CANADIENNE | 0,516

CANADIAN PUBLIC ADMINISTRATION-ADMINISTRATION PUBLIQUE DU CANADA | 0,237

CANADIAN PUBLIC POLICY-ANALYSE DE POLITIQUES | 0,322

CANADIAN REVIEW OF SOCIOLOGY AND ANTHROPOLOGY-REVUE CANADIENNE DE SOCIOLOGI | 0,275

CANCER NURSING | 0,855

CANCER PRACTICE | 0,741

CAREER DEVELOPMENT QUARTERLY | 1,298

CARTOGRAPHIC JOURNAL | 0,161

CATHOLIC UNIVERSITY LAW REVIEW | 0,824

CESKOSLOVENSKA PSYCHOLOGIE | 0,295

CHILD & FAMILY BEHAVIOR THERAPY | 0,345

CHILD ABUSE & NEGLECT | 1,072

CHILD AND ADOLESCENT PSYCHIATRIC CLINICS OF NORTH AMERICA | 0,901

CHILD CARE HEALTH AND DEVELOPMENT | 0,636

CHILD DEVELOPMENT | 2,768

CHILD PSYCHIATRY & HUMAN DEVELOPMENT | 0,422

CHILD WELFARE | 0,712

CHILDHOOD-A GLOBAL JOURNAL OF CHILD RESEARCH | 0,469

CHILDREN AND YOUTH SERVICES REVIEW | 0,338

CHILDRENS HEALTH CARE | 0,350

CHINA ECONOMIC REVIEW | 0,409

CHINA JOURNAL | 0,900

CHINA QUARTERLY | 0,932

CHINESE EDUCATION AND SOCIETY | 0,024

CHINESE LAW AND GOVERNMENT | 0,033

CHINESE SOCIOLOGY AND ANTHROPOLOGY | 0,033

CITIES | 0,493

CLINICAL LINGUISTICS & PHONETICS | 0,837

CLINICAL NEUROPSYCHOLOGIST | 0,948

CLINICAL PSYCHOLOGY & PSYCHOTHERAPY | 0,565

CLINICAL PSYCHOLOGY REVIEW | 1,430

CLINICAL PSYCHOLOGY-SCIENCE AND PRACTICE | 1,682

CLINICAL SOCIAL WORK JOURNAL | 0,255

COGNITION | 2,622

COGNITION & EMOTION | 1,863

COGNITION AND INSTRUCTION | 0,696

COGNITIVE AND BEHAVIORAL PRACTICE | 0,862

COGNITIVE DEVELOPMENT | 0,962

COGNITIVE NEUROPSYCHOLOGY | 2,180

COGNITIVE PSYCHOLOGY | 3,463

COGNITIVE SCIENCE | 1,629

COGNITIVE THERAPY AND RESEARCH | 0,756

COLLEGE & RESEARCH LIBRARIES | 0,905

COLLEGIUM ANTROPOLOGICUM | 0,355

COLUMBIA JOURNAL OF LAW AND SOCIAL PROBLEMS | 0,300

COLUMBIA JOURNAL OF TRANSNATIONAL LAW | 1,139

COLUMBIA LAW REVIEW | 4,700

COMMENTARY | 0,234

COMMON MARKET LAW REVIEW | 1,367

COMMUNICATION EDUCATION | 0,350

COMMUNICATION MONOGRAPHS | 1,049

COMMUNICATION RESEARCH | 1,091

COMMUNICATION THEORY | 0,818

COMMUNIST AND POST-COMMUNIST STUDIES | 0,265

COMMUNIST ECONOMIES & ECONOMIC TRANSFORMATION | 0,500

COMMUNITY MENTAL HEALTH JOURNAL | 0,789

COMPARATIVE EDUCATION | 0,675

COMPARATIVE EDUCATION REVIEW | 0,710

COMPARATIVE POLITICAL STUDIES | 1,071

COMPARATIVE POLITICS | 0,902

COMPARATIVE STUDIES IN SOCIETY AND HISTORY | 0,315

COMPREHENSIVE PSYCHIATRY | 1,400

COMPUTATIONAL LINGUISTICS | 1,146

COMPUTERS & EDUCATION | 0,300

COMPUTERS IN HUMAN BEHAVIOR | 0,333

CONFIGURATIONS | 0,281

CONFLICT MANAGEMENT AND PEACE SCIENCE | 0,000

CONSCIOUSNESS AND COGNITION | 1,962

CONTEMPORARY ECONOMIC POLICY | 0,398

CONTEMPORARY EDUCATIONAL PSYCHOLOGY | 0,595

CONTEMPORARY FAMILY THERAPY | 0,169

CONTEMPORARY PACIFIC | 0,147

CONTEMPORARY PSYCHOANALYSIS | 0,759

CONTEMPORARY SOCIOLOGY-A JOURNAL OF REVIEWS | 0,976

CONTINUITY AND CHANGE | 0,742

CONTRIBUTIONS TO INDIAN SOCIOLOGY | 0,054

CORNELL INTERNATIONAL LAW JOURNAL | 1,000

CORNELL LAW REVIEW | 3,517

COUNSELING PSYCHOLOGIST | 0,747

CREATIVITY RESEARCH JOURNAL | 0,206

CRIME & DELINQUENCY | 0,897

CRIME AND JUSTICE-A REVIEW OF RESEARCH | 0,719

CRIME LAW AND SOCIAL CHANGE | 0,283

CRIMINAL JUSTICE AND BEHAVIOR | 0,979

CRIMINAL LAW REVIEW | 0,552

CRIMINOLOGY | 2,393

CRISIS INTERVENTION AND TIME-LIMITED TREATMENT | 0,308

CRITICAL REVIEW | 0,180

CRITICAL STUDIES IN MASS COMMUNICATION | 0,224

CRITICAL STUDIES IN MEDIA COMMUNICATION |

CRITIQUE OF ANTHROPOLOGY | 0,429

CULTURAL ANTHROPOLOGY | 0,805

CULTURAL STUDIES | 0,286

CULTURE & PSYCHOLOGY | 0,368

CULTURE MEDICINE AND PSYCHIATRY | 0,545

CURRENT ANTHROPOLOGY | 2,429

CURRENT DIRECTIONS IN PSYCHOLOGICAL SCIENCE | 1,430

CURRENT HISTORY | 0,276

CURRENT OPINION IN PSYCHIATRY | 0,563

CURRENT PSYCHOLOGY | 0,217

CURRICULUM INQUIRY | 0,219

DADOS-REVISTA DE CIENCIAS SOCIAIS | 0,167

DAEDALUS | 0,663

DATABASE | 0,393

DEATH STUDIES | 0,742

DECISION SCIENCES | 0,473

DEFENCE AND PEACE ECONOMICS | 0,471

DEMOGRAPHY | 1,807

DENVER UNIVERSITY LAW REVIEW | 0,141

DESARROLLO ECONOMICO-REVISTA DE CIENCIAS SOCIALES | 0,155

DEVELOPING ECONOMIES | 0,583

DEVELOPMENT AND CHANGE | 0,893

DEVELOPMENT AND PSYCHOPATHOLOGY | 3,079

DEVELOPMENTAL NEUROPSYCHOLOGY | 0,871

DEVELOPMENTAL PSYCHOLOGY | 2,044

DEVELOPMENTAL REVIEW | 1,357

DEVIANT BEHAVIOR | 0,406

DIAGNOSTICA | 2,067

DISABILITY & SOCIETY | 1,082

DISABILITY AND REHABILITATION | 0,535

DISASTERS | 0,435

DISCOURSE & SOCIETY | 1,800

DISCOURSE PROCESSES | 1,581

DISSENT | 0,237

DREAMING | 0,513

DRUG AND ALCOHOL REVIEW | 0,783

DRUGS-EDUCATION PREVENTION AND POLICY | 0,446

DRUSTVENA ISTRAZIVANJA | 0,084

DUKE LAW JOURNAL | 3,130

DYNAMISCHE PSYCHIATRIE | 0,226

EARLY CHILDHOOD RESEARCH QUARTERLY | 0,509

EARLY DEVELOPMENT & PARENTING | 0,148

EAST EUROPEAN POLITICS AND SOCIETIES | 1,109

EAST EUROPEAN QUARTERLY | 0,093

EASTERN EUROPEAN ECONOMICS | 0,062

ECOLOGICAL ECONOMICS | 1,258

ECOLOGICAL PSYCHOLOGY | 1,240

ECOLOGY LAW QUARTERLY | 1,000

ECONOMETRIC THEORY | 0,475

ECONOMETRICA | 1,874

ECONOMIC AND INDUSTRIAL DEMOCRACY | 0,415

ECONOMIC AND SOCIAL REVIEW | 0,158

ECONOMIC DEVELOPMENT AND CULTURAL CHANGE | 0,803

ECONOMIC DEVELOPMENT QUARTERLY | 0,323

ECONOMIC GEOGRAPHY | 1,909

ECONOMIC HISTORY REVIEW | 1,419

ECONOMIC INQUIRY | 0,626

ECONOMIC JOURNAL | 1,396

ECONOMIC MODELLING | 0,233

ECONOMIC POLICY | 2,208

ECONOMIC RECORD | 0,121

ECONOMIC THEORY | 0,466

ECONOMICA | 0,803

ECONOMICS AND PHILOSOPHY | 0,875

ECONOMICS LETTERS | 0,254

ECONOMICS OF EDUCATION REVIEW | 0,280

ECONOMICS OF PLANNING | 0,130

ECONOMICS OF TRANSITION | 0,418

ECONOMIST | 0,340

ECONOMY AND SOCIETY | 0,902

ECONTENT | 0,065

ECOSYSTEM HEALTH | 1,000

ECUMENE | 0,590

EDUCATION AND TRAINING IN MENTAL RETARDATION AND DEVELOPMENTAL DISABILITIES | 0,342

EDUCATION AND URBAN SOCIETY | 0,373

EDUCATIONAL ADMINISTRATION QUARTERLY | 0,685

EDUCATIONAL AND PSYCHOLOGICAL MEASUREMENT | 0,608

EDUCATIONAL EVALUATION AND POLICY ANALYSIS | 0,857

EDUCATIONAL GERONTOLOGY | 0,211

EDUCATIONAL LEADERSHIP | 0,255

EDUCATIONAL POLICY | 0,426

EDUCATIONAL PSYCHOLOGIST | 3,517

EDUCATIONAL PSYCHOLOGY REVIEW | 1,000

EDUCATIONAL RESEARCH | 0,667

EDUCATIONAL REVIEW | 0,405

EDUCATIONAL STUDIES | 0,426

EKONOMICKY CASOPIS | 0,106

EKONOMISKA SAMFUNDETS TIDSKRIFT | 0,047

ELECTORAL STUDIES | 0,361

ELECTRONIC LIBRARY | 0,190

ELEMENTA-JOURNAL OF SLAVIC STUDIES & COMPARATIVE CULTURAL SEMIOTICS | 0,111

ELEMENTARY SCHOOL JOURNAL | 0,865

EMPLOYEE RELATIONS LAW JOURNAL | 0,104

ENERGY ECONOMICS | 0,561

ENERGY JOURNAL | 1,000

ENERGY POLICY | 0,669

ENVIRONMENT AND BEHAVIOR | 0,973

ENVIRONMENT AND PLANNING A | 1,210

ENVIRONMENT AND PLANNING B-PLANNING & DESIGN | 0,632

ENVIRONMENT AND PLANNING C-GOVERNMENT AND POLICY | 0,859

ENVIRONMENT AND PLANNING D-SOCIETY & SPACE | 2,152

ENVIRONMENT AND URBANIZATION | 0,815

ENVIRONMENTAL & RESOURCE ECONOMICS | 0,554

ENVIRONMENTAL ETHICS | 0,410

ENVIRONMENTAL HISTORY | 0,688

ENVIRONMENTAL VALUES | 0,622

ERGONOMICS | 0,691

ETHICS | 1,478

ETHICS & BEHAVIOR | 0,674

ETHNIC AND RACIAL STUDIES | 0,767

ETHNOHISTORY | 0,119

ETHNOLOGY | 0,268

ETHOS | 0,333

ETR&D-EDUCATIONAL TECHNOLOGY RESEARCH AND DEVELOPMENT | 0,177

EUROPEAN ADDICTION RESEARCH | 1,569

EUROPEAN CHILD & ADOLESCENT PSYCHIATRY | 0,577

EUROPEAN EATING DISORDERS REVIEW | 0,561

EUROPEAN ECONOMIC REVIEW | 0,893

EUROPEAN JOURNAL OF COGNITIVE PSYCHOLOGY | 0,452

EUROPEAN JOURNAL OF COMMUNICATION | 0,639

EUROPEAN JOURNAL OF INDUSTRIAL RELATIONS | 1,107

EUROPEAN JOURNAL OF INTERNATIONAL RELATIONS | 1,036

EUROPEAN JOURNAL OF PERSONALITY | 0,845

EUROPEAN JOURNAL OF POLITICAL RESEARCH | 0,602

EUROPEAN JOURNAL OF POPULATION-REVUE EUROPEENNE DE DEMOGRAPHIE | 0,269

EUROPEAN JOURNAL OF PSYCHIATRY | 0,231

EUROPEAN JOURNAL OF PSYCHOLOGICAL ASSESSMENT | 0,412

EUROPEAN JOURNAL OF PSYCHOLOGY OF EDUCATION | 0,258

EUROPEAN JOURNAL OF PUBLIC HEALTH | 1,165

EUROPEAN JOURNAL OF SOCIAL PSYCHOLOGY | 1,069

EUROPEAN JOURNAL OF WOMENS STUDIES | 0,275

EUROPEAN PSYCHIATRY | 0,748

EUROPEAN REVIEW OF AGRICULTURAL ECONOMICS | 0,472

EUROPEAN SOCIOLOGICAL REVIEW | 0,703

EUROPEAN URBAN AND REGIONAL STUDIES | 1,861

EUROPE-ASIA STUDIES | 0,394

EVALUATION & THE HEALTH PROFESSIONS | 0,696

EVALUATION AND PROGRAM PLANNING | 0,253

EVALUATION REVIEW | 0,895

EVOLUTION AND HUMAN BEHAVIOR | 1,741

EVOLUTION PSYCHIATRIQUE | 0,083

EVOLUTIONARY ANTHROPOLOGY | 3,658

EXCEPTIONAL CHILDREN | 1,214

EXPERIMENTAL AND CLINICAL PSYCHOPHARMACOLOGY | 1,747

EXPLORATIONS IN ECONOMIC HISTORY | 0,429

FAMILIES IN SOCIETY-THE JOURNAL OF CONTEMPORARY HUMAN SERVICES | 0,361

FAMILY & COMMUNITY HEALTH | 0,286

FAMILY LAW QUARTERLY | 1,632

FAMILY PLANNING PERSPECTIVES | 2,013

FAMILY PROCESS | 0,887

FAMILY RELATIONS | 0,859

FEDERAL PROBATION | 0,245

FEMINISM & PSYCHOLOGY | 0,265

FEMINIST ECONOMICS | 0,434

FEMINIST REVIEW | 0,135

FEMINIST STUDIES | 0,173

FILOSOFICKY CASOPIS | 0,069

FINANCE A UVER | 0,281

FINANCIAL MANAGEMENT | 0,238

FOCUS ON EXCEPTIONAL CHILDREN | 0,000

FOLIA PHONIATRICA ET LOGOPAEDICA | 0,354

FOOD AND DRUG LAW JOURNAL | 0,771

FOOD POLICY | 0,306

FORBES | 0,027

FORDHAM LAW REVIEW | 1,309

FOREIGN AFFAIRS | 3,233

FOREIGN LANGUAGE ANNALS | 0,328

FOREIGN POLICY | 1,310

FORTUNE | 0,124

FORUM DER PSYCHOANALYSE | 0,304

FRONTIERS-A JOURNAL OF WOMEN STUDIES | 0,083

FUTURE OF CHILDREN | 1,811

FUTURES | 0,258

FUTURIST | 0,210

GAMES AND ECONOMIC BEHAVIOR | 0,390

GENDER & SOCIETY | 1,098

GENERAL HOSPITAL PSYCHIATRY | 1,512

GENERATIONS-JOURNAL OF THE AMERICAN SOCIETY ON AGING | 0,187

GENETIC SOCIAL AND GENERAL PSYCHOLOGY MONOGRAPHS | 0,703

GENEVA PAPERS ON RISK AND INSURANCE THEORY | 0,762

GEOFORUM | 1,518

GEOGRAPHICAL ANALYSIS | 1,024

GEOGRAPHICAL JOURNAL | 0,930

GEOGRAPHICAL REVIEW | 0,277

GEOGRAPHISCHE ZEITSCHRIFT | 0,294

GEOGRAPHY | 0,323

GEORGE WASHINGTON LAW REVIEW | 1,311

GEORGETOWN LAW JOURNAL | 3,353

GERIATRIC NURSING | 0,198

GERMAN STUDIES REVIEW | 0,091

GERONTOLOGIST | 1,776

GIFTED CHILD QUARTERLY | 0,737

GLOBAL GOVERNANCE | 0,522

GLQ-A JOURNAL OF LESBIAN AND GAY STUDIES | 0,542

GOVERNANCE-AN INTERNATIONAL JOURNAL OF POLICY AND ADMINISTRATION | 0,973

GOVERNMENT AND OPPOSITION | 0,450

GOVERNMENT INFORMATION QUARTERLY | 0,190

GROUP | 0,259

GROUP & ORGANIZATION MANAGEMENT | 0,590

GROUP DECISION AND NEGOTIATION | 0,294

GROWTH AND CHANGE | 0,578

GRUPPENDYNAMIK-ZEITSCHRIFT FUR ANGEWANDTE SOZIALPSYCHOLOGIE | 0,087

GRUPPENPSYCHOTHERAPIE UND GRUPPENDYNAMIK | 1,273

HABITAT INTERNATIONAL | 0,219

HARVARD BUSINESS REVIEW | 2,561

HARVARD CIVIL RIGHTS-CIVIL LIBERTIES LAW REVIEW | 1,786

HARVARD EDUCATIONAL REVIEW | 0,963

HARVARD ENVIRONMENTAL LAW REVIEW | 2,217

HARVARD INTERNATIONAL JOURNAL OF PRESS-POLITICS | 0,465

HARVARD INTERNATIONAL LAW JOURNAL | 2,667

HARVARD JOURNAL OF LAW AND PUBLIC POLICY | 1,019

HARVARD JOURNAL ON LEGISLATION | 0,912

HARVARD LAW REVIEW | 6,347

HARVARD REVIEW OF PSYCHIATRY | 1,076

HASTINGS CENTER REPORT | 1,315

HASTINGS LAW JOURNAL | 1,040

HEALTH & SOCIAL CARE IN THE COMMUNITY | 0,365

HEALTH & SOCIAL WORK | 0,741

HEALTH AFFAIRS | 3,823

HEALTH CARE ANALYSIS | 0,377

HEALTH CARE FINANCING REVIEW | 0,500

HEALTH CARE MANAGEMENT REVIEW | 0,850

HEALTH COMMUNICATION | 0,571

HEALTH ECONOMICS | 1,966

HEALTH EDUCATION & BEHAVIOR | 1,954

HEALTH EDUCATION RESEARCH | 0,922

HEALTH POLICY | 0,918

HEALTH POLICY AND PLANNING | 1,096

HEALTH PROMOTION INTERNATIONAL | 1,109

HEALTH PSYCHOLOGY | 3,074

HEALTH SERVICES RESEARCH | 2,070

HIGHER EDUCATION | 0,259

HISPANIC JOURNAL OF BEHAVIORAL SCIENCES | 0,281

HISTORIA MATHEMATICA | 0,258

HISTORICAL STUDIES IN THE PHYSICAL AND BIOLOGICAL SCIENCES | 0,211

HISTORY AND PHILOSOPHY OF LOGIC | 0,250

HISTORY AND PHILOSOPHY OF THE LIFE SCIENCES | 0,192

HISTORY OF EDUCATION QUARTERLY | 0,100

HISTORY OF POLITICAL ECONOMY | 0,092

HISTORY OF PSYCHIATRY | 0,688

HISTORY OF SCIENCE | 0,792

HISTORY OF THE HUMAN SCIENCES | 0,333

HISTORY WORKSHOP JOURNAL | 0,293

HITOTSUBASHI JOURNAL OF ECONOMICS | 0,286

HOMME | 0,442

HOMO | 0,368

HOSPITALS & HEALTH NETWORKS | 0,221

HOUSING POLICY DEBATE | 1,490

HOUSING STUDIES | 0,761

HOUSING THEORY AND SOCIETY | 0,214

HUMAN COMMUNICATION RESEARCH | 0,700

HUMAN DEVELOPMENT | 0,577

HUMAN ECOLOGY | 0,702

HUMAN FACTORS | 0,954

HUMAN FACTORS AND ERGONOMICS IN MANUFACTURING | 0,136

HUMAN MOVEMENT SCIENCE | 0,805

HUMAN NATURE-AN INTERDISCIPLINARY BIOSOCIAL PERSPECTIVE | 1,379

HUMAN ORGANIZATION | 0,592

HUMAN PERFORMANCE | 1,733

HUMAN RELATIONS | 0,832

HUMAN RESOURCE MANAGEMENT | 1,268

HUMAN RIGHTS QUARTERLY | 0,339

HUMAN STUDIES | 0,364

HUMOR-INTERNATIONAL JOURNAL OF HUMOR RESEARCH | 0,083

IDENTITIES-GLOBAL STUDIES IN CULTURE AND POWER | 0,267

IDS BULLETIN-INSTITUTE OF DEVELOPMENT STUDIES | 0,316

IEEE TRANSACTIONS ON ENGINEERING MANAGEMENT | 0,325

IIC-INTERNATIONAL REVIEW OF INDUSTRIAL PROPERTY AND COPYRIGHT LAW | 0,482

IMF STAFF PAPERS | 1,000

IN SESSION-PSYCHOTHERAPY IN PRACTICE | 0,217

INDIAN JOURNAL OF SOCIAL WORK | 0,014

INDIANA LAW JOURNAL | 1,844

INDUSTRIAL & LABOR RELATIONS REVIEW | 1,048

INDUSTRIAL MARKETING MANAGEMENT | 0,420

INDUSTRIAL RELATIONS | 0,873

INFANT AND CHILD DEVELOPMENT | 0,143

INFANT BEHAVIOR & DEVELOPMENT | 1,188

INFANT MENTAL HEALTH JOURNAL | 0,842

INFANTS AND YOUNG CHILDREN | 0,297

INFORMATION & MANAGEMENT | 0,683

INFORMATION PROCESSING & MANAGEMENT | 0,719

INFORMATION SOCIETY | 0,404

INFORMATION SYSTEMS JOURNAL | 0,375

INFORMATION SYSTEMS RESEARCH | 1,093

INFORMATION TECHNOLOGY AND LIBRARIES | 0,481

INNOVATIONS IN EDUCATION AND TRAINING INTERNATIONAL | 0,130

INQUIRY-THE JOURNAL OF HEALTH CARE ORGANIZATION PROVISION AND FINANCING | 0,941

INSTRUCTIONAL SCIENCE | 0,651

INSURANCE MATHEMATICS & ECONOMICS | 0,607

INTEGRATIVE PHYSIOLOGICAL AND BEHAVIORAL SCIENCE | 0,250

INTELLIGENCE | 0,500

INTERDISCIPLINARY SCIENCE REVIEWS | 0,058

INTERFACES | 0,629

INTERLENDING & DOCUMENT SUPPLY | 0,400

INTERNASJONAL POLITIKK | 0,083

INTERNATIONAL AFFAIRS | 0,938

INTERNATIONAL ECONOMIC REVIEW | 0,950

INTERNATIONAL FAMILY PLANNING PERSPECTIVES | 0,770

INTERNATIONAL INTERACTIONS | 0,393

INTERNATIONAL JOURNAL | 0,314

INTERNATIONAL JOURNAL FOR QUALITY IN HEALTH CARE | 0,744

INTERNATIONAL JOURNAL OF AGING & HUMAN DEVELOPMENT | 0,431

INTERNATIONAL JOURNAL OF AVIATION PSYCHOLOGY | 0,745

INTERNATIONAL JOURNAL OF BEHAVIORAL DEVELOPMENT | 0,706

INTERNATIONAL JOURNAL OF BEHAVIORAL MEDICINE | 0,556

INTERNATIONAL JOURNAL OF CLINICAL AND EXPERIMENTAL HYPNOSIS | 0,897

INTERNATIONAL JOURNAL OF COMPARATIVE SOCIOLOGY | 0,244

INTERNATIONAL JOURNAL OF CONFLICT MANAGEMENT | 0,633

INTERNATIONAL JOURNAL OF EATING DISORDERS | 1,336

INTERNATIONAL JOURNAL OF EDUCATIONAL DEVELOPMENT | 0,134

INTERNATIONAL JOURNAL OF ELECTRONIC COMMERCE | 0,451

INTERNATIONAL JOURNAL OF FORECASTING | 0,677

INTERNATIONAL JOURNAL OF GAME THEORY | 0,365

INTERNATIONAL JOURNAL OF GEOGRAPHICAL INFORMATION SCIENCE | 0,988

INTERNATIONAL JOURNAL OF GERIATRIC PSYCHIATRY | 1,495

INTERNATIONAL JOURNAL OF GROUP PSYCHOTHERAPY | 0,761

INTERNATIONAL JOURNAL OF HEALTH PLANNING AND MANAGEMENT | 0,472

INTERNATIONAL JOURNAL OF HEALTH SERVICES | 1,217

INTERNATIONAL JOURNAL OF HUMAN-COMPUTER INTERACTION | 0,529

INTERNATIONAL JOURNAL OF HUMAN-COMPUTER STUDIES | 0,333

INTERNATIONAL JOURNAL OF INDUSTRIAL ERGONOMICS | 0,255

INTERNATIONAL JOURNAL OF INDUSTRIAL ORGANIZATION | 0,489

INTERNATIONAL JOURNAL OF INFORMATION MANAGEMENT | 0,424

INTERNATIONAL JOURNAL OF INTERCULTURAL RELATIONS | 0,400

INTERNATIONAL JOURNAL OF LANGUAGE & COMMUNICATION DISORDERS | 0,356

INTERNATIONAL JOURNAL OF LAW AND PSYCHIATRY | 0,662

INTERNATIONAL JOURNAL OF MANPOWER | 0,116

INTERNATIONAL JOURNAL OF MARKET RESEARCH |

INTERNATIONAL JOURNAL OF MENTAL HEALTH | 0,100

INTERNATIONAL JOURNAL OF MIDDLE EAST STUDIES | 0,250

INTERNATIONAL JOURNAL OF NURSING STUDIES | 0,521

INTERNATIONAL JOURNAL OF OFFENDER THERAPY AND COMPARATIVE CRIMINOLOGY | 0,250

INTERNATIONAL JOURNAL OF OPERATIONS & PRODUCTION MANAGEMENT | 0,412

INTERNATIONAL JOURNAL OF OSTEOARCHAEOLOGY | 0,289

INTERNATIONAL JOURNAL OF PSYCHIATRY IN MEDICINE | 1,033

INTERNATIONAL JOURNAL OF PSYCHOANALYSIS | 1,160

INTERNATIONAL JOURNAL OF PSYCHOLOGY | 0,575

INTERNATIONAL JOURNAL OF PSYCHOPHYSIOLOGY | 1,489

INTERNATIONAL JOURNAL OF PUBLIC OPINION RESEARCH | 0,114

INTERNATIONAL JOURNAL OF REHABILITATION RESEARCH | 0,323

INTERNATIONAL JOURNAL OF RESEARCH IN MARKETING | 1,133

INTERNATIONAL JOURNAL OF SCIENCE EDUCATION | 0,705

INTERNATIONAL JOURNAL OF SELECTION AND ASSESSMENT | 0,395

INTERNATIONAL JOURNAL OF SERVICE INDUSTRY MANAGEMENT | 0,200

INTERNATIONAL JOURNAL OF SOCIAL PSYCHIATRY | 0,724

INTERNATIONAL JOURNAL OF SOCIAL WELFARE | 0,111

INTERNATIONAL JOURNAL OF SPORT PSYCHOLOGY | 0,804

INTERNATIONAL JOURNAL OF STRESS MANAGEMENT | 0,545

INTERNATIONAL JOURNAL OF TECHNOLOGY MANAGEMENT | 0,198

INTERNATIONAL JOURNAL OF THE SOCIOLOGY OF LAW | 0,158

INTERNATIONAL JOURNAL OF URBAN AND REGIONAL RESEARCH | 1,244

INTERNATIONAL LABOUR REVIEW | 0,439

INTERNATIONAL MIGRATION | 0,373

INTERNATIONAL MIGRATION REVIEW | 0,586

INTERNATIONAL ORGANIZATION | 3,982

INTERNATIONAL POLITICAL SCIENCE REVIEW | 0,488

INTERNATIONAL REGIONAL SCIENCE REVIEW | 0,909

INTERNATIONAL REVIEW OF ADMINISTRATIVE SCIENCES | 0,232

INTERNATIONAL REVIEW OF LAW AND ECONOMICS | 0,540

INTERNATIONAL REVIEW OF PSYCHIATRY | 0,337

INTERNATIONAL REVIEW OF RESEARCH IN MENTAL RETARDATION | 0,375

INTERNATIONAL REVIEW OF SOCIAL HISTORY | 0,250

INTERNATIONAL SECURITY | 2,784

INTERNATIONAL SOCIAL SCIENCE JOURNAL | 0,325

INTERNATIONAL SOCIAL WORK | 0,127

INTERNATIONAL SOCIOLOGY | 0,708

INTERNATIONAL STUDIES QUARTERLY | 1,162

INTERNATIONAL TAX AND PUBLIC FINANCE | 0,464

INTERNATIONALE POLITIK | 0,083

INTERNET WORLD | 1,167

INTERVENTION IN SCHOOL AND CLINIC | 0,237

IOWA LAW REVIEW | 1,381

IRISH JOURNAL OF PSYCHOLOGICAL MEDICINE | 0,290

ISIS | 0,524

ISRAEL JOURNAL OF PSYCHIATRY AND RELATED SCIENCES | 0,182

ISSUES & STUDIES | 0,218

ISSUES IN LAW & MEDICINE | 0,270

ISSUES IN SCIENCE AND TECHNOLOGY | 0,296

JAHRBUCHER FUR NATIONALOKONOMIE UND STATISTIK | 0,118

JAPAN AND THE WORLD ECONOMY | 0,169

JAPAN QUARTERLY | 0,074

JAPANESE JOURNAL OF EDUCATIONAL PSYCHOLOGY | 0,040

JAPANESE JOURNAL OF PSYCHOLOGY | 0,133

JAPANESE PSYCHOLOGICAL RESEARCH | 0,122

JAVNOST-THE PUBLIC | 0,020

JOURNAL FOR RESEARCH IN MATHEMATICS EDUCATION | 0,294

JOURNAL FOR THE EDUCATION OF THE GIFTED | 0,647

JOURNAL FOR THE SCIENTIFIC STUDY OF RELIGION | 0,773

JOURNAL FOR THE THEORY OF SOCIAL BEHAVIOUR | 0,488

JOURNAL OF ABNORMAL CHILD PSYCHOLOGY | 1,917

JOURNAL OF ABNORMAL PSYCHOLOGY | 3,352

JOURNAL OF ACADEMIC LIBRARIANSHIP | 0,296

JOURNAL OF ACCOUNTING & ECONOMICS | 0,397

JOURNAL OF ACCOUNTING RESEARCH | 1,071

JOURNAL OF ADDICTIVE DISEASES | 1,045

JOURNAL OF ADOLESCENCE | 0,656

JOURNAL OF ADOLESCENT & ADULT LITERACY | 0,531

JOURNAL OF ADOLESCENT HEALTH | 1,415

JOURNAL OF ADOLESCENT RESEARCH | 0,925

JOURNAL OF ADULT DEVELOPMENT | 0,400

JOURNAL OF ADVANCED NURSING | 0,769

JOURNAL OF ADVERTISING | 0,630

JOURNAL OF ADVERTISING RESEARCH | 0,500

JOURNAL OF AFFECTIVE DISORDERS | 1,938

JOURNAL OF AFRICAN ECONOMIES | 0,304

JOURNAL OF AFRICAN HISTORY | 0,194

JOURNAL OF AGING AND HEALTH | 1,204

JOURNAL OF AGING AND PHYSICAL ACTIVITY | 1,136

JOURNAL OF AGING STUDIES | 0,519

JOURNAL OF AGRICULTURAL & ENVIRONMENTAL ETHICS | 0,333

JOURNAL OF AGRICULTURAL AND RESOURCE ECONOMICS | 0,423

JOURNAL OF AGRICULTURAL ECONOMICS | 0,545

JOURNAL OF ALCOHOL AND DRUG EDUCATION | 0,312

JOURNAL OF AMERICAN COLLEGE HEALTH | 1,588

JOURNAL OF AMERICAN HISTORY | 0,564

JOURNAL OF ANALYTICAL PSYCHOLOGY | 0,377

JOURNAL OF ANTHROPOLOGICAL ARCHAEOLOGY | 0,484

JOURNAL OF ANTHROPOLOGICAL RESEARCH | 0,559

JOURNAL OF ANXIETY DISORDERS | 1,513

JOURNAL OF APPLIED BEHAVIOR ANALYSIS | 1,466

JOURNAL OF APPLIED COMMUNICATION RESEARCH | 0,707

JOURNAL OF APPLIED DEVELOPMENTAL PSYCHOLOGY | 0,477

JOURNAL OF APPLIED ECONOMETRICS | 0,607

JOURNAL OF APPLIED GERONTOLOGY | 0,429

JOURNAL OF APPLIED PSYCHOLOGY | 1,730

JOURNAL OF APPLIED RESEARCH IN INTELLECTUAL DISABILITIES | 0,642

JOURNAL OF APPLIED SOCIAL PSYCHOLOGY | 0,722

JOURNAL OF APPLIED SPORT PSYCHOLOGY | 1,105

JOURNAL OF ARCHITECTURAL AND PLANNING RESEARCH | 0,282

JOURNAL OF ASIAN AND AFRICAN STUDIES | 0,025

JOURNAL OF ASIAN STUDIES | 0,538

JOURNAL OF AUTISM AND DEVELOPMENTAL DISORDERS | 2,309

JOURNAL OF BALTIC STUDIES | 0,147

JOURNAL OF BANKING & FINANCE | 0,533

JOURNAL OF BEHAVIOR THERAPY AND EXPERIMENTAL PSYCHIATRY | 0,567

JOURNAL OF BEHAVIORAL DECISION MAKING | 1,639

JOURNAL OF BEHAVIORAL HEALTH SERVICES & RESEARCH | 0,662

JOURNAL OF BEHAVIORAL MEDICINE | 1,099

JOURNAL OF BIOSOCIAL SCIENCE | 0,549

JOURNAL OF BLACK STUDIES | 0,157

JOURNAL OF BROADCASTING & ELECTRONIC MEDIA | 0,487

JOURNAL OF BUSINESS | 1,162

JOURNAL OF BUSINESS & ECONOMIC STATISTICS | 0,750

JOURNAL OF BUSINESS AND PSYCHOLOGY | 0,203

JOURNAL OF BUSINESS AND TECHNICAL COMMUNICATION | 0,433

JOURNAL OF BUSINESS ETHICS | 0,955

JOURNAL OF BUSINESS RESEARCH | 0,407

JOURNAL OF BUSINESS VENTURING | 0,538

JOURNAL OF CAREER ASSESSMENT | 1,320

JOURNAL OF CAREER DEVELOPMENT | 0,233

JOURNAL OF CHILD & ADOLESCENT SUBSTANCE ABUSE | 0,194

JOURNAL OF CHILD LANGUAGE | 0,945

JOURNAL OF CHILD PSYCHOLOGY AND PSYCHIATRY AND ALLIED DISCIPLINES | 2,940

JOURNAL OF CLASSIFICATION | 0,846

JOURNAL OF CLINICAL AND EXPERIMENTAL NEUROPSYCHOLOGY | 1,067

JOURNAL OF CLINICAL CHILD PSYCHOLOGY | 2,526

JOURNAL OF CLINICAL ETHICS | 0,705

JOURNAL OF CLINICAL NURSING | 0,473

JOURNAL OF CLINICAL PSYCHIATRY | 4,454

JOURNAL OF CLINICAL PSYCHOLOGY | 0,680

JOURNAL OF CLINICAL PSYCHOLOGY IN MEDICAL SETTINGS | 0,419

JOURNAL OF COGNITIVE NEUROSCIENCE | 5,115

JOURNAL OF COLLEGE STUDENT DEVELOPMENT | 0,470

JOURNAL OF COMMON MARKET STUDIES | 0,836

JOURNAL OF COMMONWEALTH & COMPARATIVE POLITICS | 0,667

JOURNAL OF COMMUNICATION | 0,535

JOURNAL OF COMMUNICATION DISORDERS | 0,582

JOURNAL OF COMMUNITY & APPLIED SOCIAL PSYCHOLOGY | 0,373

JOURNAL OF COMMUNITY HEALTH | 0,762

JOURNAL OF COMMUNITY PSYCHOLOGY | 0,736

JOURNAL OF COMPARATIVE ECONOMICS | 0,884

JOURNAL OF COMPARATIVE FAMILY STUDIES | 0,169

JOURNAL OF COMPARATIVE PSYCHOLOGY | 1,477

JOURNAL OF COMPUTER ASSISTED LEARNING | 0,212

JOURNAL OF CONFLICT RESOLUTION | 0,870

JOURNAL OF CONSTRUCTIVIST PSYCHOLOGY | 0,545

JOURNAL OF CONSULTING AND CLINICAL PSYCHOLOGY | 4,390

JOURNAL OF CONSUMER AFFAIRS | 0,343

JOURNAL OF CONSUMER RESEARCH | 2,460

JOURNAL OF CONTEMPORARY ASIA | 0,220

JOURNAL OF CONTEMPORARY ETHNOGRAPHY | 0,230

JOURNAL OF COUNSELING AND DEVELOPMENT | 0,650

JOURNAL OF COUNSELING PSYCHOLOGY | 1,564

JOURNAL OF CREATIVE BEHAVIOR | 0,533

JOURNAL OF CRIMINAL JUSTICE | 0,364

JOURNAL OF CRIMINAL LAW & CRIMINOLOGY | 1,150

JOURNAL OF CROSS-CULTURAL PSYCHOLOGY | 1,218

JOURNAL OF CURRICULUM STUDIES | 0,438

JOURNAL OF DEMOCRACY | 0,881

JOURNAL OF DEVELOPING AREAS | 0,182

JOURNAL OF DEVELOPMENT ECONOMICS | 0,598

JOURNAL OF DEVELOPMENT STUDIES | 0,506

JOURNAL OF DEVELOPMENTAL AND BEHAVIORAL PEDIATRICS | 1,041

JOURNAL OF DEVELOPMENTAL AND PHYSICAL DISABILITIES | 0,100

JOURNAL OF DOCUMENTATION | 1,640

JOURNAL OF DRUG EDUCATION | 0,511

JOURNAL OF DRUG ISSUES | 0,510

JOURNAL OF EARLY ADOLESCENCE | 0,395

JOURNAL OF EARLY INTERVENTION | 0,918

JOURNAL OF ECONOMETRICS | 0,977

JOURNAL OF ECONOMIC BEHAVIOR & ORGANIZATION | 0,567

JOURNAL OF ECONOMIC DYNAMICS & CONTROL | 0,496

JOURNAL OF ECONOMIC EDUCATION | 0,266

JOURNAL OF ECONOMIC HISTORY | 0,654

JOURNAL OF ECONOMIC ISSUES | 0,451

JOURNAL OF ECONOMIC LITERATURE | 6,676

JOURNAL OF ECONOMIC PERSPECTIVES | 2,336

JOURNAL OF ECONOMIC PSYCHOLOGY | 0,246

JOURNAL OF ECONOMIC THEORY | 0,622

JOURNAL OF ECONOMICS & MANAGEMENT STRATEGY | 0,378

JOURNAL OF ECONOMICS-ZEITSCHRIFT FUR NATIONALOKONOMIE | 0,155

JOURNAL OF ECT | 1,817

JOURNAL OF EDUCATIONAL AND BEHAVIORAL STATISTICS | 1,088

JOURNAL OF EDUCATIONAL AND PSYCHOLOGICAL CONSULTATION | 0,595

JOURNAL OF EDUCATIONAL COMPUTING RESEARCH | 0,086

JOURNAL OF EDUCATIONAL MEASUREMENT | 0,353

JOURNAL OF EDUCATIONAL PSYCHOLOGY | 1,844

JOURNAL OF EDUCATIONAL RESEARCH | 0,351

JOURNAL OF ELDER ABUSE & NEGLECT | 0,160

JOURNAL OF EMOTIONAL AND BEHAVIORAL DISORDERS | 1,022

JOURNAL OF EMPLOYMENT COUNSELING | 0,500

JOURNAL OF ENVIRONMENTAL ECONOMICS AND MANAGEMENT | 1,118

JOURNAL OF ENVIRONMENTAL PSYCHOLOGY | 0,689

JOURNAL OF EUROPEAN PUBLIC POLICY | 1,680

JOURNAL OF EUROPEAN SOCIAL POLICY | 0,649

JOURNAL OF EVOLUTIONARY ECONOMICS | 0,368

JOURNAL OF EXPERIMENTAL CHILD PSYCHOLOGY | 1,276

JOURNAL OF EXPERIMENTAL EDUCATION | 0,386

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-ANIMAL BEHAVIOR PROCESSES | 1,365

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-APPLIED | 1,000

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-GENERAL | 3,636

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-HUMAN PERCEPTION AND PERFORMANCE | 2,247

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-LEARNING MEMORY AND COGNITION | 2,753

JOURNAL OF EXPERIMENTAL SOCIAL PSYCHOLOGY | 1,481

JOURNAL OF FAMILY HISTORY | 0,413

JOURNAL OF FAMILY ISSUES | 0,868

JOURNAL OF FAMILY PSYCHOLOGY | 1,058

JOURNAL OF FAMILY THERAPY | 0,551

JOURNAL OF FAMILY VIOLENCE | 0,760

JOURNAL OF FINANCE | 2,753

JOURNAL OF FINANCIAL AND QUANTITATIVE ANALYSIS | 0,596

JOURNAL OF FINANCIAL ECONOMICS | 1,904

JOURNAL OF FINANCIAL INTERMEDIATION | 0,519

JOURNAL OF FINANCIAL SERVICES RESEARCH | 0,240

JOURNAL OF FLUENCY DISORDERS | 0,370

JOURNAL OF FORECASTING | 0,377

JOURNAL OF FORENSIC PSYCHIATRY | 0,726

JOURNAL OF FUTURES MARKETS | 0,337

JOURNAL OF GENDER STUDIES | 0,091

JOURNAL OF GENERAL PSYCHOLOGY | 0,519

JOURNAL OF GENETIC PSYCHOLOGY | 0,476

JOURNAL OF GEOGRAPHY | 0,831

JOURNAL OF GEOGRAPHY IN HIGHER EDUCATION | 1,140

JOURNAL OF GOVERNMENT INFORMATION | 0,328

JOURNAL OF HEAD TRAUMA REHABILITATION | 1,353

JOURNAL OF HEALTH AND SOCIAL BEHAVIOR | 2,490

JOURNAL OF HEALTH CARE FOR THE POOR AND UNDERSERVED | 0,767

JOURNAL OF HEALTH COMMUNICATION | 0,463

JOURNAL OF HEALTH ECONOMICS | 1,923

JOURNAL OF HEALTH POLITICS POLICY AND LAW | 0,941

JOURNAL OF HEALTHCARE MANAGEMENT | 0,648

JOURNAL OF HIGHER EDUCATION | 0,562

JOURNAL OF HISTORICAL GEOGRAPHY | 0,795

JOURNAL OF HISTORICAL SOCIOLOGY | 0,303

JOURNAL OF HOMOSEXUALITY | 0,296

JOURNAL OF HOUSING ECONOMICS | 0,242

JOURNAL OF HUMAN EVOLUTION | 2,675

JOURNAL OF HUMAN RESOURCES | 1,235

JOURNAL OF HUMANISTIC PSYCHOLOGY | 0,319

JOURNAL OF INDUSTRIAL ECONOMICS | 1,244

JOURNAL OF INFORMATION ETHICS | 0,148

JOURNAL OF INFORMATION SCIENCE | 0,473

JOURNAL OF INFORMATION TECHNOLOGY | 0,382

JOURNAL OF INSTITUTIONAL AND THEORETICAL ECONOMICS-ZEITSCHRIFT FUR DIE GESA | 0,433

JOURNAL OF INTELLECTUAL DISABILITY RESEARCH | 1,123

JOURNAL OF INTERAMERICAN STUDIES AND WORLD AFFAIRS | 0,121

JOURNAL OF INTERDISCIPLINARY HISTORY | 0,415

JOURNAL OF INTERNATIONAL BUSINESS STUDIES | 1,012

JOURNAL OF INTERNATIONAL ECONOMICS | 1,280

JOURNAL OF INTERNATIONAL MARKETING | 0,850

JOURNAL OF INTERNATIONAL MONEY AND FINANCE | 0,394

JOURNAL OF INTERPERSONAL VIOLENCE | 1,062

JOURNAL OF JAPANESE STUDIES | 0,375

JOURNAL OF LABOR ECONOMICS | 1,273

JOURNAL OF LABOR RESEARCH | 0,219

JOURNAL OF LANGUAGE AND SOCIAL PSYCHOLOGY | 0,525

JOURNAL OF LATIN AMERICAN STUDIES | 0,447

JOURNAL OF LAW & ECONOMICS | 1,050

JOURNAL OF LAW AND SOCIETY | 0,691

JOURNAL OF LAW ECONOMICS & ORGANIZATION | 1,383

JOURNAL OF LAW MEDICINE & ETHICS | 0,810

JOURNAL OF LEARNING DISABILITIES | 1,000

JOURNAL OF LEGAL EDUCATION | 0,646

JOURNAL OF LEGAL MEDICINE | 0,733

JOURNAL OF LEGAL STUDIES | 4,468

JOURNAL OF LEISURE RESEARCH | 1,304

JOURNAL OF LIBRARIANSHIP AND INFORMATION SCIENCE | 0,263

JOURNAL OF LINGUISTICS | 0,571

JOURNAL OF LITERACY RESEARCH | 0,909

JOURNAL OF MACROECONOMICS | 0,241

JOURNAL OF MANAGEMENT | 1,235

JOURNAL OF MANAGEMENT INQUIRY | 0,649

JOURNAL OF MANAGEMENT STUDIES | 0,646

JOURNAL OF MARITAL AND FAMILY THERAPY | 1,106

JOURNAL OF MARITIME LAW AND COMMERCE | 0,712

JOURNAL OF MARKETING | 2,039

JOURNAL OF MARKETING RESEARCH | 1,679

JOURNAL OF MARRIAGE AND THE FAMILY | 2,135

JOURNAL OF MATERIAL CULTURE | 0,375

JOURNAL OF MATHEMATICAL ECONOMICS | 0,314

JOURNAL OF MATHEMATICAL PSYCHOLOGY | 1,056

JOURNAL OF MATHEMATICAL SOCIOLOGY | 0,500

JOURNAL OF MEDIA ECONOMICS | 0,259

JOURNAL OF MEDICAL ETHICS | 0,955

JOURNAL OF MEDICINE AND PHILOSOPHY | 0,479

JOURNAL OF MEMORY AND LANGUAGE | 2,638

JOURNAL OF MIDWIFERY & WOMENS HEALTH |

JOURNAL OF MIND AND BEHAVIOR | 0,316

JOURNAL OF MODERN AFRICAN STUDIES | 0,688

JOURNAL OF MODERN HISTORY | 0,656

JOURNAL OF MONETARY ECONOMICS | 0,970

JOURNAL OF MONEY CREDIT AND BANKING | 0,915

JOURNAL OF MORAL EDUCATION | 0,182

JOURNAL OF MOTOR BEHAVIOR | 1,141

JOURNAL OF MULTICULTURAL COUNSELING AND DEVELOPMENT | 0,395

JOURNAL OF MUSIC THERAPY | 0,152

JOURNAL OF NEGRO EDUCATION | 0,045

JOURNAL OF NERVOUS AND MENTAL DISEASE | 1,626

JOURNAL OF NEUROLINGUISTICS | 0,514

JOURNAL OF NONVERBAL BEHAVIOR | 0,704

JOURNAL OF NURSE-MIDWIFERY | 0,569

JOURNAL OF NURSING ADMINISTRATION | 0,555

JOURNAL OF NURSING CARE QUALITY | 0,272

JOURNAL OF NURSING EDUCATION | 0,420

JOURNAL OF OCCUPATIONAL AND ORGANIZATIONAL PSYCHOLOGY | 0,466

JOURNAL OF OCCUPATIONAL REHABILITATION | 0,683

JOURNAL OF ORGANIZATIONAL BEHAVIOR | 0,808

JOURNAL OF ORGANIZATIONAL BEHAVIOR MANAGEMENT | 0,206

JOURNAL OF ORGANIZATIONAL CHANGE MANAGEMENT | 0,250

JOURNAL OF PALESTINE STUDIES | 0,149

JOURNAL OF PALLIATIVE CARE | 1,153

JOURNAL OF PARAPSYCHOLOGY | 0,654

JOURNAL OF PEACE RESEARCH | 1,027

JOURNAL OF PEASANT STUDIES | 0,647

JOURNAL OF PEDIATRIC PSYCHOLOGY | 1,541

JOURNAL OF PERINATAL & NEONATAL NURSING | 0,236

JOURNAL OF PERSONAL & INTERPERSONAL LOSS | 0,533

JOURNAL OF PERSONALITY | 1,488

JOURNAL OF PERSONALITY AND SOCIAL PSYCHOLOGY | 3,172

JOURNAL OF PERSONALITY ASSESSMENT | 0,734

JOURNAL OF PERSONALITY DISORDERS | 1,333

JOURNAL OF PHILOSOPHY OF EDUCATION | 0,463

JOURNAL OF PHONETICS | 0,667

JOURNAL OF PLANNING EDUCATION AND RESEARCH | 0,740

JOURNAL OF POLICY ANALYSIS AND MANAGEMENT | 0,897

JOURNAL OF POLICY MODELING | 0,145

JOURNAL OF POLITICAL & MILITARY SOCIOLOGY | 0,161

JOURNAL OF POLITICAL ECONOMY | 2,320

JOURNAL OF POLITICAL PHILOSOPHY | 0,622

JOURNAL OF POLITICS | 0,736

JOURNAL OF POPULATION ECONOMICS | 0,390

JOURNAL OF PORTFOLIO MANAGEMENT | 0,253

JOURNAL OF POST KEYNESIAN ECONOMICS | 0,500

JOURNAL OF PRAGMATICS | 0,405

JOURNAL OF PRODUCT INNOVATION MANAGEMENT | 1,000

JOURNAL OF PRODUCTIVITY ANALYSIS | 0,559

JOURNAL OF PROFESSIONAL NURSING | 0,437

JOURNAL OF PSYCHIATRIC RESEARCH | 2,330

JOURNAL OF PSYCHIATRY & NEUROSCIENCE | 2,039

JOURNAL OF PSYCHOACTIVE DRUGS | 0,548

JOURNAL OF PSYCHOEDUCATIONAL ASSESSMENT | 0,543

JOURNAL OF PSYCHOHISTORY | 0,364

JOURNAL OF PSYCHOLINGUISTIC RESEARCH | 0,725

JOURNAL OF PSYCHOLOGY | 0,393

JOURNAL OF PSYCHOLOGY AND THEOLOGY | 0,268

JOURNAL OF PSYCHOPATHOLOGY AND BEHAVIORAL ASSESSMENT | 0,667

JOURNAL OF PSYCHOPHYSIOLOGY | 0,685

JOURNAL OF PSYCHOSOCIAL ONCOLOGY | 0,364

JOURNAL OF PSYCHOSOMATIC OBSTETRICS AND GYNECOLOGY | 0,529

JOURNAL OF PSYCHOSOMATIC RESEARCH | 1,446

JOURNAL OF PUBLIC ECONOMICS | 0,847

JOURNAL OF PUBLIC HEALTH MEDICINE | 1,015

JOURNAL OF PUBLIC HEALTH POLICY | 0,674

JOURNAL OF PUBLIC POLICY & MARKETING | 0,661

JOURNAL OF QUANTITATIVE CRIMINOLOGY | 0,763

JOURNAL OF REAL ESTATE FINANCE AND ECONOMICS | 0,676

JOURNAL OF REAL ESTATE TAXATION | 0,056

JOURNAL OF REGIONAL SCIENCE | 0,651

JOURNAL OF REGULATORY ECONOMICS | 0,361

JOURNAL OF REHABILITATION | 0,153

JOURNAL OF REHABILITATION RESEARCH AND DEVELOPMENT | 0,569

JOURNAL OF RELIGION & HEALTH | 0,104

JOURNAL OF RESEARCH IN CRIME AND DELINQUENCY | 1,657

JOURNAL OF RESEARCH IN PERSONALITY | 1,000

JOURNAL OF RESEARCH IN SCIENCE TEACHING | 0,992

JOURNAL OF RESEARCH ON ADOLESCENCE | 1,500

JOURNAL OF RETAILING | 0,600

JOURNAL OF RISK AND INSURANCE | 0,554

JOURNAL OF RISK AND UNCERTAINTY | 0,878

JOURNAL OF RURAL HEALTH | 0,672

JOURNAL OF RURAL STUDIES | 1,559

JOURNAL OF SAFETY RESEARCH | 0,468

JOURNAL OF SCHOLARLY PUBLISHING | 0,086

JOURNAL OF SCHOOL HEALTH | 0,789

JOURNAL OF SCHOOL PSYCHOLOGY | 0,911

JOURNAL OF SEX & MARITAL THERAPY | 1,017

JOURNAL OF SEX RESEARCH | 1,308

JOURNAL OF SMALL BUSINESS MANAGEMENT | 0,167

JOURNAL OF SOCIAL AND CLINICAL PSYCHOLOGY | 0,882

JOURNAL OF SOCIAL AND PERSONAL RELATIONSHIPS | 0,559

JOURNAL OF SOCIAL BEHAVIOR AND PERSONALITY | 0,168

JOURNAL OF SOCIAL DISTRESS AND THE HOMELESS | 0,059

JOURNAL OF SOCIAL HISTORY | 0,327

JOURNAL OF SOCIAL ISSUES | 1,167

JOURNAL OF SOCIAL POLICY | 1,326

JOURNAL OF SOCIAL PSYCHOLOGY | 0,286

JOURNAL OF SOCIAL SERVICE RESEARCH | 0,386

JOURNAL OF SOCIAL WORK EDUCATION | 1,046

JOURNAL OF SOCIAL WORK PRACTICE | 0,154

JOURNAL OF SOCIOLOGY | 0,235

JOURNAL OF SOCIOLOGY AND SOCIAL WELFARE | 0,139

JOURNAL OF SOUTHEAST ASIAN STUDIES | 0,000

JOURNAL OF SOUTHERN AFRICAN STUDIES | 0,468

JOURNAL OF SPECIAL EDUCATION | 0,617

JOURNAL OF SPEECH LANGUAGE AND HEARING RESEARCH | 1,590

JOURNAL OF SPORT & EXERCISE PSYCHOLOGY | 1,475

JOURNAL OF SPORT HISTORY | 0,071

JOURNAL OF STRATEGIC STUDIES | 0,209

JOURNAL OF STUDIES ON ALCOHOL | 2,005

JOURNAL OF SUBSTANCE ABUSE | 0,800

JOURNAL OF SUBSTANCE ABUSE TREATMENT | 0,914

JOURNAL OF TAXATION | 0,161

JOURNAL OF TEACHER EDUCATION | 0,394

JOURNAL OF TEACHING IN PHYSICAL EDUCATION | 0,412

JOURNAL OF THE ACADEMY OF MARKETING SCIENCE | 0,980

JOURNAL OF THE AMERICAN ACADEMY OF CHILD AND ADOLESCENT PSYCHIATRY | 3,175

JOURNAL OF THE AMERICAN ACADEMY OF PSYCHIATRY AND THE LAW | 0,686

JOURNAL OF THE AMERICAN GERIATRICS SOCIETY | 3,136

JOURNAL OF THE AMERICAN MEDICAL INFORMATICS ASSOCIATION | 3,089

JOURNAL OF THE AMERICAN PLANNING ASSOCIATION | 1,120

JOURNAL OF THE AMERICAN PSYCHOANALYTIC ASSOCIATION | 1,090

JOURNAL OF THE AMERICAN SOCIETY FOR INFORMATION SCIENCE | 1,226

JOURNAL OF THE AMERICAN SOCIETY FOR PSYCHICAL RESEARCH | 0,167

JOURNAL OF THE ASSOCIATION FOR PERSONS WITH SEVERE HANDICAPS | 1,816

JOURNAL OF THE COPYRIGHT SOCIETY OF THE USA | 0,947

JOURNAL OF THE EXPERIMENTAL ANALYSIS OF BEHAVIOR | 1,172

JOURNAL OF THE HISTORY OF BIOLOGY | 0,500

JOURNAL OF THE HISTORY OF IDEAS | 0,275

JOURNAL OF THE HISTORY OF MEDICINE AND ALLIED SCIENCES | 0,250

JOURNAL OF THE HISTORY OF SEXUALITY | 1,000

JOURNAL OF THE HISTORY OF THE BEHAVIORAL SCIENCES | 0,240

JOURNAL OF THE JAPANESE AND INTERNATIONAL ECONOMIES | 0,368

JOURNAL OF THE LEARNING SCIENCES | 1,286

JOURNAL OF THE MARKET RESEARCH SOCIETY | 0,389

JOURNAL OF THE OPERATIONAL RESEARCH SOCIETY | 0,648

JOURNAL OF THE PHILOSOPHY OF SPORT | 1,250

JOURNAL OF THE POLYNESIAN SOCIETY | 0,452

JOURNAL OF THE ROYAL ANTHROPOLOGICAL INSTITUTE | 0,623

JOURNAL OF THE ROYAL SOCIETY FOR THE PROMOTION OF HEALTH | 0,098

JOURNAL OF THE ROYAL SOCIETY OF HEALTH | 0,259

JOURNAL OF THE ROYAL STATISTICAL SOCIETY SERIES A-STATISTICS IN SOCIETY | 1,277

JOURNAL OF THEORETICAL POLITICS | 0,413

JOURNAL OF TRANSPORT ECONOMICS AND POLICY | 0,326

JOURNAL OF TRAUMATIC STRESS | 1,836

JOURNAL OF URBAN AFFAIRS | 0,762

JOURNAL OF URBAN ECONOMICS | 1,011

JOURNAL OF URBAN HISTORY | 0,239

JOURNAL OF URBAN PLANNING AND DEVELOPMENT-ASCE | 0,091

JOURNAL OF URBAN TECHNOLOGY | 0,258

JOURNAL OF VISUAL IMPAIRMENT & BLINDNESS | 0,181

JOURNAL OF VOCATIONAL BEHAVIOR | 1,356

JOURNAL OF WOMEN & AGING | 0,295

JOURNAL OF WOMENS HEALTH | 1,395

JOURNAL OF WOMENS HEALTH & GENDER-BASED MEDICINE | 0,395

JOURNAL OF WORLD BUSINESS | 0,571

JOURNAL OF WORLD TRADE | 0,539

JOURNAL OF YOUTH AND ADOLESCENCE | 0,723

JOURNALISM & MASS COMMUNICATION QUARTERLY | 0,435

JOURNALS OF GERONTOLOGY SERIES A-BIOLOGICAL SCIENCES AND MEDICAL SCIENCES | 1,549

JOURNALS OF GERONTOLOGY SERIES B-PSYCHOLOGICAL SCIENCES AND SOCIAL SCIENCES | 1,102

JUDICATURE | 0,431

JUSTICE SYSTEM JOURNAL | 0,238

JUVENILE AND FAMILY COURT JOURNAL | 0,279

KENNEDY INSTITUTE OF ETHICS JOURNAL | 0,955

KNOWLEDGE ORGANIZATION | 0,778

KOLNER ZEITSCHRIFT FUR SOZIOLOGIE UND SOZIALPSYCHOLOGIE | 0,797

KOREAN JOURNAL OF DEFENSE ANALYSIS | 0,333

KRIMINALISTIK | 0,137

KYKLOS | 0,306

LABOR HISTORY | 0,204

LAND ECONOMICS | 0,987

LAND USE POLICY | 0,429

LANDSCAPE AND URBAN PLANNING | 0,637

LANGUAGE | 3,371

LANGUAGE & COMMUNICATION | 0,583

LANGUAGE AND COGNITIVE PROCESSES | 0,875

LANGUAGE AND SPEECH | 0,639

LANGUAGE IN SOCIETY | 0,667

LANGUAGE LEARNING | 0,340

LANGUAGE SPEECH AND HEARING SERVICES IN SCHOOLS | 0,585

LATIN AMERICAN PERSPECTIVES | 0,209

LATIN AMERICAN RESEARCH REVIEW | 0,574

LAW & SOCIETY REVIEW | 1,778

LAW AND HUMAN BEHAVIOR | 1,861

LAW AND PHILOSOPHY | 0,333

LAW AND SOCIAL INQUIRY-JOURNAL OF THE AMERICAN BAR FOUNDATION | 1,154

LAW LIBRARY JOURNAL | 0,105

LEADERSHIP QUARTERLY | 0,830

LEARNED PUBLISHING | 0,305

LEARNING AND INDIVIDUAL DIFFERENCES | 0,459

LEARNING AND INSTRUCTION | 0,536

LEARNING AND MOTIVATION | 1,156

LEARNING DISABILITY QUARTERLY | 1,091

LEGISLATIVE STUDIES QUARTERLY | 0,468

LEISURE SCIENCES | 1,000

LIBRARY & INFORMATION SCIENCE RESEARCH | 0,297

LIBRARY ACQUISITIONS-PRACTICE AND THEORY | 0,065

LIBRARY AND INFORMATION SCIENCE | 1,167

LIBRARY COLLECTIONS ACQUISITIONS & TECHNICAL SERVICES | 0,071

LIBRARY JOURNAL | 0,265

LIBRARY QUARTERLY | 0,407

LIBRARY RESOURCES & TECHNICAL SERVICES | 0,361

LIBRARY TRENDS | 0,316

LIBRI | 0,188

LINGUA | 0,686

LINGUISTIC INQUIRY | 1,477

LINGUISTICS | 0,353

LOCAL GOVERNMENT STUDIES | 0,490

LOISIR & SOCIETE-SOCIETY AND LEISURE | 0,065

LONG RANGE PLANNING | 0,207

LOUISIANA LAW REVIEW | 0,319

MACROECONOMIC DYNAMICS | 0,591

MAN IN INDIA | 0,024

MANAGEMENT LEARNING | 1,186

MANAGEMENT SCIENCE | 1,011

MANCHESTER SCHOOL | 0,181

MANKIND QUARTERLY | 0,121

MARINE POLICY | 0,603

MARKETING SCIENCE | 1,364

MARRIAGE AND FAMILY REVIEW | 0,217

MATHEMATICAL FINANCE | 0,889

MATHEMATICAL SOCIAL SCIENCES | 0,307

MEASUREMENT AND EVALUATION IN COUNSELING AND DEVELOPMENT | 0,571

MEDIA CULTURE & SOCIETY | 0,387

MEDIA STUDIES JOURNAL | 0,036

MEDICAL ANTHROPOLOGY QUARTERLY | 0,605

MEDICAL CARE | 2,535

MEDICAL CARE RESEARCH AND REVIEW | 1,740

MEDICAL HISTORY | 0,286

MEDICINE SCIENCE AND THE LAW | 0,472

MEMORY | 1,522

MEMORY & COGNITION | 1,507

MENTAL RETARDATION | 0,965

MERRILL-PALMER QUARTERLY-JOURNAL OF DEVELOPMENTAL PSYCHOLOGY | 0,750

MICHIGAN LAW REVIEW | 4,646

MIDDLE EAST JOURNAL | 0,725

MIDDLE EAST POLICY | 0,349

MIDDLE EASTERN STUDIES | 0,145

MIDWIFERY | 0,849

MILBANK QUARTERLY | 4,568

MILITARY LAW REVIEW | 0,303

MILITARY PSYCHOLOGY | 0,297

MILLENNIUM-JOURNAL OF INTERNATIONAL STUDIES | 0,929

MIND & LANGUAGE | 0,385

MINERVA | 0,414

MINNESOTA LAW REVIEW | 2,217

MINNESOTA SYMPOSIA ON CHILD PSYCHOLOGY | 0,950

MIS QUARTERLY | 2,064

MITTEILUNGEN DER OSTERREICHISCHEN GEOGRAPHISCHEN GESELLSCHAFT | 0,083

MODERN ASIAN STUDIES | 0,224

MODERN CHINA | 0,606

MODERN LANGUAGE JOURNAL | 0,918

MONOGRAPHS OF THE SOCIETY FOR RESEARCH IN CHILD DEVELOPMENT | 3,000

MONTHLY LABOR REVIEW | 0,949

MONTHLY REVIEW-AN INDEPENDENT SOCIALIST MAGAZINE | 0,275

MOTIVATION AND EMOTION | 1,133

MOUVEMENT SOCIAL | 0,020

MULTIVARIATE BEHAVIORAL RESEARCH | 0,641

MUSIC PERCEPTION | 1,065

NARRATIVE INQUIRY | 0,364

NATION | 0,379

NATIONAL TAX JOURNAL | 0,720

NATURAL LANGUAGE & LINGUISTIC THEORY | 0,842

NATURAL RESOURCES JOURNAL | 0,537

NBER MACROECONOMICS ANNUAL | 2,000

NEGOTIATION JOURNAL-ON THE PROCESS OF DISPUTE SETTLEMENT | 0,317

NETHERLANDS JOURNAL OF SOCIAL SCIENCES | 0,048

NEUROBIOLOGY OF LEARNING AND MEMORY | 3,040

NEUROPSYCHOLOGIA | 2,778

NEUROPSYCHOLOGY | 2,702

NEUROPSYCHOLOGY REVIEW | 1,250

NEUROREHABILITATION | 0,442

NEW ENGLAND ECONOMIC REVIEW | 0,395

NEW IDEAS IN PSYCHOLOGY | 0,219

NEW LEFT REVIEW | 1,716

NEW REPUBLIC | 0,211

NEW TECHNOLOGY WORK AND EMPLOYMENT | 0,524

NEW YORK UNIVERSITY LAW REVIEW | 3,386

NEW ZEALAND JOURNAL OF EDUCATIONAL STUDIES | 0,244

NEW ZEALAND JOURNAL OF PSYCHOLOGY | 0,172

NFD INFORMATION-WISSENSCHAFT UND PRAXIS | 0,029

NONPROFIT AND VOLUNTARY SECTOR QUARTERLY | 0,500

NORDIC JOURNAL OF PSYCHIATRY | 0,360

NORDISK PSYKOLOGI | 0,077

NORTHWESTERN UNIVERSITY LAW REVIEW | 3,278

NOTRE DAME LAW REVIEW | 1,261

NOUVELLES QUESTIONS FEMINISTES | 0,000

NURSE EDUCATION TODAY | 0,716

NURSE PRACTITIONER FORUM-CURRENT TOPICS AND COMMUNICATIONS | 0,123

NURSING AND HEALTH CARE PERSPECTIVES | 0,150

NURSING CLINICS OF NORTH AMERICA | 0,387

NURSING CONNECTIONS | 0,143

NURSING ECONOMICS | 0,294

NURSING ETHICS | 0,359

NURSING HISTORY REVIEW | 0,438

NURSING OUTLOOK | 0,825

NURSING RESEARCH | 1,080

NURSING SCIENCE QUARTERLY | 1,278

OCCUPATIONAL THERAPY JOURNAL OF RESEARCH | 0,679

OCEAN DEVELOPMENT AND INTERNATIONAL LAW | 0,458

OCEANIA | 0,333

OMEGA-INTERNATIONAL JOURNAL OF MANAGEMENT SCIENCE | 0,453

OMEGA-JOURNAL OF DEATH AND DYING | 0,322

ONLINE | 0,456

ONLINE & CDROM REVIEW | 0,206

ONLINE INFORMATION REVIEW |

ONLINE JOURNAL OF KNOWLEDGE SYNTHESIS FOR NURSING | 0,000

OPEN ECONOMIES REVIEW | 0,240

ORGANIZATION | 0,963

ORGANIZATION SCIENCE | 1,052

ORGANIZATION STUDIES | 0,818

ORGANIZATIONAL BEHAVIOR AND HUMAN DECISION PROCESSES | 1,200

ORGANIZATIONAL DYNAMICS | 0,800

OSIRIS | 0,065

OSTEUROPA | 0,274

OXFORD BULLETIN OF ECONOMICS AND STATISTICS | 0,386

OXFORD ECONOMIC PAPERS-NEW SERIES | 0,824

OXFORD REVIEW OF ECONOMIC POLICY | 0,723

OXFORD REVIEW OF EDUCATION | 0,703

PACIFIC AFFAIRS | 0,161

PACIFIC REVIEW | 0,620

PAPERS IN REGIONAL SCIENCE | 0,182

PARLIAMENTARY AFFAIRS | 0,373

PARTY POLITICS | 0,353

PAST & PRESENT | 0,540

PATIENT EDUCATION AND COUNSELING | 0,875

PATTERNS OF PREJUDICE | 0,308

PENSEE | 0,044

PERCEPTION | 1,193

PERCEPTION & PSYCHOPHYSICS | 1,252

PERCEPTUAL AND MOTOR SKILLS | 0,308

PERSONAL RELATIONSHIPS | 1,017

PERSONALITY AND INDIVIDUAL DIFFERENCES | 0,920

PERSONALITY AND SOCIAL PSYCHOLOGY BULLETIN | 1,205

PERSONNEL PSYCHOLOGY | 1,733

PERSONNEL REVIEW | 0,192

PERSPECTIVES IN PSYCHIATRIC CARE | 0,545

PHI DELTA KAPPAN | 0,519

PHILOSOPHICAL PSYCHOLOGY | 0,471

PHILOSOPHY & PUBLIC AFFAIRS | 1,120

PHILOSOPHY OF SCIENCE | 0,663

PHILOSOPHY OF THE SOCIAL SCIENCES | 0,200

PHONETICA | 0,450

PHYSIOLOGY & BEHAVIOR | 1,419

PLAINS ANTHROPOLOGIST | 0,273

POLICY AND POLITICS | 0,519

POLICY REVIEW | 0,192

POLICY SCIENCES | 0,146

POLICY STUDIES JOURNAL | 0,360

POLITICAL BEHAVIOR | 0,750

POLITICAL COMMUNICATION | 0,729

POLITICAL GEOGRAPHY | 1,226

POLITICAL PSYCHOLOGY | 0,862

POLITICAL QUARTERLY | 0,675

POLITICAL RESEARCH QUARTERLY | 0,397

POLITICAL SCIENCE | 0,036

POLITICAL SCIENCE QUARTERLY | 0,564

POLITICAL STUDIES | 0,494

POLITICAL THEORY | 0,339

POLITICKA EKONOMIE | 0,154

POLITICS & SOCIETY | 1,378

POLITICS AND THE LIFE SCIENCES | 0,095

POLITISCHE VIERTELJAHRESSCHRIFT | 0,400

POLITY | 0,185

POPULATION | 0,370

POPULATION AND DEVELOPMENT REVIEW | 0,756

POPULATION AND ENVIRONMENT | 0,204

POPULATION BULLETIN | 2,857

POPULATION RESEARCH AND POLICY REVIEW | 0,238

POPULATION STUDIES-A JOURNAL OF DEMOGRAPHY | 0,696

POST-COMMUNIST ECONOMIES | 0,038

POST-SOVIET AFFAIRS | 1,161

POST-SOVIET GEOGRAPHY AND ECONOMICS | 0,362

PRAXIS DER KINDERPSYCHOLOGIE UND KINDERPSYCHIATRIE | 0,360

PROFESSIONAL GEOGRAPHER | 1,133

PROFESSIONAL PSYCHOLOGY-RESEARCH AND PRACTICE | 1,240

PROGRAM-ELECTRONIC LIBRARY AND INFORMATION SYSTEMS | 0,364

PROGRESS IN HUMAN GEOGRAPHY | 2,386

PROGRESS IN PLANNING | 0,379

PSICOTHEMA | 0,473

PSIKHOLOGICHESKII ZHURNAL | 0,121

PS-POLITICAL SCIENCE & POLITICS | 0,374

PSYCHE-ZEITSCHRIFT FUR PSYCHOANALYSE UND IHRE ANWENDUNGEN | 0,324

PSYCHIATRIC ANNALS | 1,080

PSYCHIATRIC CLINICS OF NORTH AMERICA | 1,709

PSYCHIATRIC QUARTERLY | 0,889

PSYCHIATRIC REHABILITATION JOURNAL | 0,455

PSYCHIATRIC SERVICES | 1,795

PSYCHIATRIE DE L ENFANT | 0,024

PSYCHIATRISCHE PRAXIS | 0,893

PSYCHIATRY RESEARCH | 1,557

PSYCHIATRY-INTERPERSONAL AND BIOLOGICAL PROCESSES | 0,827

PSYCHOANALYTIC INQUIRY | 0,272

PSYCHOANALYTIC PSYCHOLOGY | 0,583

PSYCHOANALYTIC QUARTERLY | 0,800

PSYCHOANALYTIC STUDY OF THE CHILD | 0,206

PSYCHOBIOLOGY | 1,194

PSYCHOLOGIA | 0,093

PSYCHOLOGICA BELGICA | 0,417

PSYCHOLOGICAL ASSESSMENT | 1,670

PSYCHOLOGICAL BULLETIN | 6,913

PSYCHOLOGICAL INQUIRY | 2,414

PSYCHOLOGICAL MEDICINE | 3,412

PSYCHOLOGICAL METHODS | 2,190

PSYCHOLOGICAL RECORD | 0,684

PSYCHOLOGICAL REPORTS | 0,238

PSYCHOLOGICAL RESEARCH-PSYCHOLOGISCHE FORSCHUNG | 1,360

PSYCHOLOGICAL REVIEW | 6,069

PSYCHOLOGICAL SCIENCE | 2,565

PSYCHOLOGIE IN ERZIEHUNG UND UNTERRICHT | 0,341

PSYCHOLOGISCHE RUNDSCHAU | 0,676

PSYCHOLOGIST | 0,264

PSYCHOLOGY | 0,159

PSYCHOLOGY & HEALTH | 0,909

PSYCHOLOGY & MARKETING | 0,363

PSYCHOLOGY AND AGING | 2,308

PSYCHOLOGY CRIME & LAW | 0,389

PSYCHOLOGY IN THE SCHOOLS | 0,309

PSYCHOLOGY OF ADDICTIVE BEHAVIORS | 1,088

PSYCHOLOGY OF WOMEN QUARTERLY | 0,894

PSYCHOLOGY PUBLIC POLICY AND LAW | 2,407

PSYCHOMETRIKA | 0,898

PSYCHONOMIC BULLETIN & REVIEW | 1,580

PSYCHO-ONCOLOGY | 1,670

PSYCHOPATHOLOGY | 0,547

PSYCHOPHARMACOLOGY BULLETIN | 2,809

PSYCHOPHYSIOLOGY | 3,106

PSYCHOSOMATIC MEDICINE | 3,246

PSYCHOSOMATICS | 1,555

PSYCHOTHERAPEUT | 0,485

PSYCHOTHERAPIE PSYCHOSOMATIK MEDIZINISCHE PSYCHOLOGIE | 0,346

PSYCHOTHERAPY | 0,311

PSYCHOTHERAPY AND PSYCHOSOMATICS | 2,372

PSYCHOTHERAPY RESEARCH | 1,439

PUBLIC ADMINISTRATION | 0,872

PUBLIC ADMINISTRATION AND DEVELOPMENT | 0,456

PUBLIC ADMINISTRATION REVIEW | 1,172

PUBLIC CHOICE | 0,318

PUBLIC CULTURE | 0,412

PUBLIC FINANCE REVIEW | 0,063

PUBLIC HEALTH | 0,600

PUBLIC HEALTH NURSING | 0,528

PUBLIC HEALTH REPORTS | 1,517

PUBLIC INTEREST | 0,464

PUBLIC MONEY & MANAGEMENT | 0,643

PUBLIC OPINION QUARTERLY | 0,863

PUBLIC PERSONNEL MANAGEMENT | 0,218

PUBLIC RELATIONS REVIEW | 0,500

PUBLIC UNDERSTANDING OF SCIENCE | 0,943

PUBLISHING RESEARCH QUARTERLY | 0,049

PUBLIUS-THE JOURNAL OF FEDERALISM | 0,587

QUALITATIVE HEALTH RESEARCH | 0,929

QUALITY & QUANTITY | 0,204

QUARTERLY JOURNAL OF ECONOMICS | 4,024

QUARTERLY JOURNAL OF EXPERIMENTAL PSYCHOLOGY SECTION A-HUMAN EXPERIMENTAL P | 1,452

QUARTERLY JOURNAL OF EXPERIMENTAL PSYCHOLOGY SECTION B-COMPARATIVE AND PHYS | 1,000

QUARTERLY JOURNAL OF SPEECH | 0,366

QUEST | 0,483

R & D MANAGEMENT | 0,737

RACE & CLASS | 0,319

RADICAL PHILOSOPHY | 0,474

RAND JOURNAL OF ECONOMICS | 1,107

RATIONALITY AND SOCIETY | 1,000

READING AND WRITING | 0,122

READING RESEARCH AND INSTRUCTION | 0,174

READING RESEARCH QUARTERLY | 2,486

READING TEACHER | 0,490

REAL ESTATE ECONOMICS | 0,764

REFERENCE & USER SERVICES QUARTERLY | 0,185

REGIONAL SCIENCE AND URBAN ECONOMICS | 0,464

REGIONAL STUDIES | 1,028

REHABILITATION COUNSELING BULLETIN | 0,382

REHABILITATION PSYCHOLOGY | 1,488

RELATIONS INDUSTRIELLES-INDUSTRIAL RELATIONS | 0,382

REMEDIAL AND SPECIAL EDUCATION | 0,603

RESEARCH IN DEVELOPMENTAL DISABILITIES | 0,470

RESEARCH IN HIGHER EDUCATION | 0,338

RESEARCH IN NURSING & HEALTH | 0,789

RESEARCH IN ORGANIZATIONAL BEHAVIOR | 2,562

RESEARCH IN THE TEACHING OF ENGLISH | 1,080

RESEARCH ON AGING | 0,785

RESEARCH ON LANGUAGE AND SOCIAL INTERACTION | 0,522

RESEARCH ON SOCIAL WORK PRACTICE | 0,239

RESEARCH POLICY | 1,078

RESEARCH QUARTERLY FOR EXERCISE AND SPORT | 0,979

RESEARCH-TECHNOLOGY MANAGEMENT | 0,299

RESOURCE AND ENERGY ECONOMICS | 0,472

RESOURCES POLICY | 0,220

RESTAURATOR-INTERNATIONAL JOURNAL FOR THE PRESERVATION OF LIBRARY AND ARCHI | 0,759

REVIEW OF BLACK POLITICAL ECONOMY | 0,094

REVIEW OF ECONOMIC STUDIES | 1,468

REVIEW OF ECONOMICS AND STATISTICS | 1,031

REVIEW OF EDUCATIONAL RESEARCH | 2,088

REVIEW OF FINANCIAL STUDIES | 1,343

REVIEW OF HIGHER EDUCATION | 0,837

REVIEW OF INCOME AND WEALTH | 0,220

REVIEW OF INDUSTRIAL ORGANIZATION | 0,241

REVIEW OF INTERNATIONAL POLITICAL ECONOMY | 1,614

REVIEW OF INTERNATIONAL STUDIES | 1,080

REVIEW OF RELIGIOUS RESEARCH | 0,381

REVIEW OF RESEARCH IN EDUCATION | 2,421

REVISTA DE SAUDE PUBLICA | 0,226

REVISTA INTERAMERICANA DE PSICOLOGIA | 0,075

REVISTA LATINOAMERICANA DE PSICOLOGIA | 0,077

REVISTA MEXICANA DE PSICOLOGIA | 0,109

REVUE CANADIENNE D ETUDES DU DEVELOPPEMENT-CANADIAN JOURNAL OF DEVELOPMENT | 0,091

REVUE D ETUDES COMPARATIVES EST-OUEST | 0,115

REVUE FRANCAISE DE SOCIOLOGIE | 0,545

RISK ANALYSIS | 1,389

RURAL SOCIOLOGY | 0,867

RUSSIAN AND EAST EUROPEAN FINANCE AND TRADE | 0,024

RUSSIAN EDUCATION AND SOCIETY | 0,013

RUSSIAN POLITICS AND LAW | 0,014

RUTGERS LAW REVIEW | 0,571

SALUD MENTAL | 0,259

SALUD PUBLICA DE MEXICO | 0,368

SCANDINAVIAN HOUSING & PLANNING RESEARCH | 0,312

SCANDINAVIAN JOURNAL OF CARING SCIENCES | 0,603

SCANDINAVIAN JOURNAL OF ECONOMICS | 0,324

SCANDINAVIAN JOURNAL OF PSYCHOLOGY | 0,330

SCANDINAVIAN JOURNAL OF PUBLIC HEALTH | 0,340

SCANDINAVIAN JOURNAL OF SOCIAL MEDICINE | 1,250

SCANDINAVIAN JOURNAL OF SOCIAL WELFARE | 0,158

SCANDINAVIAN POLITICAL STUDIES | 0,703

SCHIZOPHRENIA BULLETIN | 6,085

SCHIZOPHRENIA RESEARCH | 3,506

SCHOOL EFFECTIVENESS AND SCHOOL IMPROVEMENT | 0,578

SCHOOL PSYCHOLOGY INTERNATIONAL | 0,400

SCHOOL PSYCHOLOGY QUARTERLY | 1,049

SCHOOL PSYCHOLOGY REVIEW | 1,424

SCIENCE & SOCIETY | 0,377

SCIENCE COMMUNICATION | 0,444

SCIENCE EDUCATION | 0,918

SCIENCE IN CONTEXT | 0,186

SCIENCE TECHNOLOGY & HUMAN VALUES | 0,941

SCIENCES SOCIALES ET SANTE | 0,515

SCIENTIST | 0,347

SCIENTOMETRICS | 0,660

SCOTTISH GEOGRAPHICAL JOURNAL | 0,292

SCOTTISH JOURNAL OF POLITICAL ECONOMY | 0,450

SECURITIES REGULATION LAW JOURNAL | 0,000

SECURITY DIALOGUE | 0,391

SECURITY STUDIES | 0,738

SERVICE INDUSTRIES JOURNAL | 0,213

SEX ROLES | 0,415

SEXUALITY AND DISABILITY | 0,109

SIGNS | 0,469

SINGAPORE JOURNAL OF TROPICAL GEOGRAPHY | 0,280

SLOAN MANAGEMENT REVIEW | 1,794

SMALL BUSINESS ECONOMICS | 0,515

SMALL GROUP RESEARCH | 0,532

SMITH COLLEGE STUDIES IN SOCIAL WORK | 0,079

SOCIAL & LEGAL STUDIES | 0,543

SOCIAL BEHAVIOR AND PERSONALITY | 0,227

SOCIAL BIOLOGY | 0,267

SOCIAL CHOICE AND WELFARE | 0,782

SOCIAL COGNITION | 1,415

SOCIAL COMPASS | 0,185

SOCIAL DEVELOPMENT | 0,886

SOCIAL FORCES | 1,215

SOCIAL HISTORY OF MEDICINE | 0,862

SOCIAL INDICATORS RESEARCH | 0,435

SOCIAL NETWORKS | 0,590

SOCIAL PHILOSOPHY & POLICY | 0,360

SOCIAL POLICY & ADMINISTRATION | 0,667

SOCIAL POLITICS | 0,486

SOCIAL PROBLEMS | 1,085

SOCIAL PSYCHIATRY AND PSYCHIATRIC EPIDEMIOLOGY | 1,622

SOCIAL PSYCHOLOGY QUARTERLY | 1,277

SOCIAL RESEARCH | 0,292

SOCIAL SCIENCE & MEDICINE | 1,691

SOCIAL SCIENCE COMPUTER REVIEW | 0,429

SOCIAL SCIENCE HISTORY | 0,195

SOCIAL SCIENCE INFORMATION SUR LES SCIENCES SOCIALES | 0,264

SOCIAL SCIENCE JOURNAL | 0,140

SOCIAL SCIENCE QUARTERLY | 0,670

SOCIAL SCIENCE RESEARCH | 0,882

SOCIAL SECURITY BULLETIN | 0,391

SOCIAL SERVICE REVIEW | 0,447

SOCIAL STUDIES OF SCIENCE | 1,115

SOCIAL WORK | 1,372

SOCIAL WORK & SOCIAL SCIENCES REVIEW | 0,000

SOCIAL WORK IN HEALTH CARE | 0,456

SOCIAL WORK RESEARCH | 0,634

SOCIETY | 0,092

SOCIETY & ANIMALS | 0,444

SOCIETY & NATURAL RESOURCES | 0,526

SOCIOLOGIA | 0,115

SOCIOLOGIA RURALIS | 1,132

SOCIOLOGICAL FORUM | 0,667

SOCIOLOGICAL INQUIRY | 0,268

SOCIOLOGICAL METHODOLOGY | 1,227

SOCIOLOGICAL METHODS & RESEARCH | 1,258

SOCIOLOGICAL PERSPECTIVES | 0,451

SOCIOLOGICAL QUARTERLY | 0,600

SOCIOLOGICAL RESEARCH ONLINE | 0,211

SOCIOLOGICAL REVIEW | 1,069

SOCIOLOGICAL SPECTRUM | 0,231

SOCIOLOGICAL THEORY | 0,679

SOCIOLOGICAL THEORY AND METHODS | 0,026

SOCIOLOGICKY CASOPIS | 0,080

SOCIOLOGIE DU TRAVAIL | 0,231

SOCIOLOGISK FORSKNING | 0,119

SOCIOLOGY OF EDUCATION | 1,241

SOCIOLOGY OF HEALTH & ILLNESS | 1,481

SOCIOLOGY OF RELIGION | 0,545

SOCIOLOGY OF SPORT JOURNAL | 0,297

SOCIOLOGY-THE JOURNAL OF THE BRITISH SOCIOLOGICAL ASSOCIATION | 1,408

SOTSIOLOGICHESKIE ISSLEDOVANIYA | 0,146

SOUTH AFRICAN JOURNAL OF ECONOMICS | 0,104

SOUTH AFRICAN JOURNAL OF PSYCHOLOGY | 0,220

SOUTHERN CALIFORNIA LAW REVIEW | 1,873

SOUTHERN ECONOMIC JOURNAL | 0,417

SOZIALE WELT-ZEITSCHRIFT FUR SOZIALWISSENSCHAFTLICHE FORSCHUNG UND PRAXIS | 0,271

SPACE POLICY | 0,167

SPATIAL VISION | 1,324

SPORT PSYCHOLOGIST | 0,649

SPRACHE & KOGNITION | 0,357

STANFORD JOURNAL OF INTERNATIONAL LAW | 0,471

STANFORD LAW REVIEW | 5,414

STRATEGIC MANAGEMENT JOURNAL | 2,531

STRESS MEDICINE | 0,759

STUDIA PSYCHOLOGICA | 0,292

STUDIES IN AMERICAN POLITICAL DEVELOPMENT | 0,250

STUDIES IN COMPARATIVE INTERNATIONAL DEVELOPMENT | 0,147

STUDIES IN EAST EUROPEAN THOUGHT | 0,286

STUDIES IN FAMILY PLANNING | 0,984

STUDIES IN HIGHER EDUCATION | 0,636

STUDIES IN HISTORY AND PHILOSOPHY OF SCIENCE | 1,000

STUDIES IN NONLINEAR DYNAMICS AND ECONOMETRICS | 0,150

STUDIES IN SYMBOLIC INTERACTION | 0,091

SUBSTANCE USE & MISUSE | 0,687

SUICIDE AND LIFE-THREATENING BEHAVIOR | 1,306

SUPREME COURT REVIEW | 1,294

SWISS JOURNAL OF PSYCHOLOGY | 0,133

SYMBOLIC INTERACTION | 0,966

SYNTAX AND SEMANTICS | 0,205

SYNTHESE | 0,147

SYSTEM DYNAMICS REVIEW | 0,455

SYSTEM FAMILIE | 0,387

SYSTEMIC PRACTICE AND ACTION RESEARCH | 0,179

SYSTEMS RESEARCH AND BEHAVIORAL SCIENCE | 0,242

TEACHERS COLLEGE RECORD | 0,300

TEACHING AND TEACHER EDUCATION | 0,317

TEACHING OF PSYCHOLOGY | 0,352

TEACHING SOCIOLOGY | 0,484

TECHNICAL COMMUNICATION | 0,393

TECHNOLOGICAL FORECASTING AND SOCIAL CHANGE | 0,231

TECHNOLOGY AND CULTURE | 0,549

TECHNOLOGY IN SOCIETY | 0,185

TELECOMMUNICATIONS POLICY | 0,731

TESOL QUARTERLY | 0,806

TEXAS LAW REVIEW | 3,038

THEORETICAL MEDICINE AND BIOETHICS | 0,443

THEORY & PSYCHOLOGY | 1,372

THEORY AND DECISION | 0,453

THEORY AND SOCIETY | 1,277

THEORY CULTURE & SOCIETY | 1,105

THEORY INTO PRACTICE | 0,191

THIRD WORLD PLANNING REVIEW | 0,195

THIRD WORLD QUARTERLY | 0,311

TIDSSKRIFT FOR SAMFUNNSFORSKNING | 0,161

TIJDSCHRIFT VOOR ECONOMISCHE EN SOCIALE GEOGRAFIE | 0,311

TIME & SOCIETY | 0,462

TOBACCO CONTROL | 1,717

TOPICS IN EARLY CHILDHOOD SPECIAL EDUCATION | 1,081

TOPICS IN GERIATRIC REHABILITATION | 0,203

TOPICS IN LANGUAGE DISORDERS | 0,404

TOTAL QUALITY MANAGEMENT | 0,269

TOURISM MANAGEMENT | 0,328

TRAINING & DEVELOPMENT | 0,102

TRANSACTIONS OF THE INSTITUTE OF BRITISH GEOGRAPHERS | 2,698

TRANSPORT REVIEWS | 0,568

TRANSPORTATION | 0,250

TRANSPORTATION JOURNAL | 0,206

TRANSPORTATION QUARTERLY | 0,082

TRANSPORTATION RESEARCH PART A-POLICY AND PRACTICE | 0,280

TRANSPORTATION RESEARCH PART B-METHODOLOGICAL | 0,442

TRANSPORTATION RESEARCH PART D-TRANSPORT AND ENVIRONMENT | 0,443

TRANSPORTATION RESEARCH PART E-LOGISTICS AND TRANSPORTATION REVIEW | 0,128

TRANSPORTATION SCIENCE | 0,714

TRAVAIL HUMAIN | 0,212

TRIMESTRE ECONOMICO | 0,045

TURK PSIKOLOJI DERGISI | 0,214

UCLA LAW REVIEW | 2,765

UNIVERSITY OF CHICAGO LAW REVIEW | 2,338

UNIVERSITY OF CINCINNATI LAW REVIEW | 0,857

UNIVERSITY OF ILLINOIS LAW REVIEW | 1,352

UNIVERSITY OF PENNSYLVANIA JOURNAL OF INTERNATIONAL ECONOMIC LAW | 0,667

UNIVERSITY OF PENNSYLVANIA LAW REVIEW | 3,278

UNIVERSITY OF PITTSBURGH LAW REVIEW | 0,919

URBAN AFFAIRS REVIEW | 0,746

URBAN EDUCATION | 0,386

URBAN GEOGRAPHY | 0,831

URBAN LAWYER | 0,486

URBAN STUDIES | 0,816

VANDERBILT LAW REVIEW | 2,718

VENEREOLOGY-THE INTERDISCIPLINARY INTERNATIONAL JOURNAL OF SEXUAL HEALTH | 0,237

VERHALTENSTHERAPIE | 0,311

VIRGINIA LAW REVIEW | 4,029

VISUAL COGNITION | 0,295

VOLTA REVIEW | 0,021

VOPROSY PSIKHOLOGII | 0,169

WASHINGTON LAW REVIEW | 0,667

WASHINGTON QUARTERLY | 0,167

WELTWIRTSCHAFTLICHES ARCHIV-REVIEW OF WORLD ECONOMICS | 0,277

WESTERN JOURNAL OF COMMUNICATION | 0,149

WESTERN JOURNAL OF NURSING RESEARCH | 0,329

WISCONSIN LAW REVIEW | 1,134

WOMEN & HEALTH | 0,904

WOMEN & POLITICS | 0,229

WOMEN & THERAPY | 0,115

WOMENS HEALTH ISSUES | 0,611

WOMENS STUDIES INTERNATIONAL FORUM | 0,216

WORK AND OCCUPATIONS | 1,281

WORK AND STRESS | 0,824

WORK EMPLOYMENT AND SOCIETY | 0,952

WORKFORCE | 0,075

WORLD BANK ECONOMIC REVIEW | 0,643

WORLD BANK RESEARCH OBSERVER | 1,036

WORLD DEVELOPMENT | 0,810

WORLD ECONOMY | 0,696

WORLD POLICY JOURNAL | 0,225

WORLD POLITICS | 4,452

WORLD TODAY | 0,044

WRITTEN COMMUNICATION | 0,536

YALE LAW JOURNAL | 4,729

YEARBOOK OF PHYSICAL ANTHROPOLOGY | 1,846

YOUNG CHILDREN | 0,295

YOUTH & SOCIETY | 0,395

ZEITSCHRIFT FUR ARBEITS-UND ORGANISATIONSPSYCHOLOGIE | 0,333

ZEITSCHRIFT FUR BIBLIOTHEKSWESEN UND BIBLIOGRAPHIE | 0,105

ZEITSCHRIFT FUR ENTWICKLUNGSPSYCHOLOGIE UND PADAGOGISCHE PSYCHOLOGIE | 0,345

ZEITSCHRIFT FUR EXPERIMENTELLE PSYCHOLOGIE | 0,500

ZEITSCHRIFT FUR GERONTOLOGIE UND GERIATRIE | 0,458

ZEITSCHRIFT FUR KINDER-UND JUGENDPSYCHIATRIE UND PSYCHOTHERAPIE | 0,375

ZEITSCHRIFT FUR KLINISCHE PSYCHOLOGIE PSYCHIATRIE UND PSYCHOTHERAPIE | 0,500

ZEITSCHRIFT FUR KLINISCHE PSYCHOLOGIE UND PSYCHOTHERAPIE | 0,193

ZEITSCHRIFT FUR PADAGOGIK | 0,189

ZEITSCHRIFT FUR PADAGOGISCHE PSYCHOLOGIE | 1,743

ZEITSCHRIFT FUR PSYCHOLOGIE | 0,167

ZEITSCHRIFT FUR PSYCHOSOMATISCHE MEDIZIN UND PSYCHOTHERAPIE | 0,490

ZEITSCHRIFT FUR SOZIALPSYCHOLOGIE | 0,341

ZEITSCHRIFT FUR SOZIOLOGIE | 0,604

ZYGON | 0,293

Title | Impact

ABA JOURNAL | 0,534

ACADEME-BULLETIN OF THE AAUP | 0,376

ACADEMIC PSYCHIATRY | 0,340

ACADEMY OF MANAGEMENT JOURNAL | 2,375

ACADEMY OF MANAGEMENT REVIEW | 3,912

ACCIDENT ANALYSIS AND PREVENTION | 0,686

ACCOUNTING ORGANIZATIONS AND SOCIETY | 0,437

ACCOUNTING REVIEW | 0,630

ACTA PSYCHIATRICA SCANDINAVICA | 1,774

ACTA PSYCHOLOGICA | 1,267

ACTA SOCIOLOGICA | 0,634

ADAPTIVE BEHAVIOR | 0,667

ADDICTION | 2,494

ADDICTION RESEARCH | 0,596

ADDICTIVE BEHAVIORS | 0,978

ADMINISTRATION & SOCIETY | 0,308

ADMINISTRATION AND POLICY IN MENTAL HEALTH | 0,574

ADMINISTRATION IN SOCIAL WORK | 0,485

ADMINISTRATIVE LAW REVIEW | 0,600

ADMINISTRATIVE SCIENCE QUARTERLY | 3,333

ADOLESCENCE | 0,444

ADOLESCENT PSYCHIATRY | 0,290

ADULT EDUCATION QUARTERLY | 0,414

ADVANCES IN CHILD DEVELOPMENT AND BEHAVIOR |

ADVANCES IN CONSUMER RESEARCH | 0,107

ADVANCES IN ECONOMETRICS : A RESEARCH ANNUAL | 0,000

ADVANCES IN EXPERIMENTAL SOCIAL PSYCHOLOGY | 5,250

ADVANCES IN NURSING SCIENCE | 0,818

ADVANCES IN STRATEGIC MANAGEMENT : A RESEARCH ANNUAL | 0,739

AFFILIA-JOURNAL OF WOMEN AND SOCIAL WORK | 0,317

AFRICA | 0,565

AFRICA TODAY | 0,341

AFRICAN AFFAIRS | 0,605

AGEING AND SOCIETY | 0,721

AGGRESSION AND VIOLENT BEHAVIOR | 0,755

AGGRESSIVE BEHAVIOR | 0,815

AGING & MENTAL HEALTH | 0,526

AGING NEUROPSYCHOLOGY AND COGNITION | 0,725

AGRICULTURAL ECONOMICS | 0,429

AGRICULTURAL HISTORY | 0,133

AIDS & PUBLIC POLICY JOURNAL | 0,524

AIDS CARE-PSYCHOLOGICAL AND SOCIO-MEDICAL ASPECTS OF AIDS/HIV | 0,942

AIDS EDUCATION AND PREVENTION | 1,044

AIDS PATIENT CARE AND STDS | 0,304

ALBERTA JOURNAL OF EDUCATIONAL RESEARCH | 0,041

ALCOHOL HEALTH & RESEARCH WORLD | 0,676

ALCOHOL RESEARCH & HEALTH | 0,429

ALTERNATIVES-SOCIAL TRANSFORMATION AND HUMANE GOVERNANCE | 0,324

AMERICAN ANNALS OF THE DEAF | 0,766

AMERICAN ANTHROPOLOGIST | 0,710

AMERICAN ANTIQUITY | 1,100

AMERICAN BANKRUPTCY LAW JOURNAL | 1,294

AMERICAN BEHAVIORAL SCIENTIST | 0,619

AMERICAN BUSINESS LAW JOURNAL | 0,633

AMERICAN CRIMINAL LAW REVIEW | 1,125

AMERICAN ECONOMIC REVIEW | 1,795

AMERICAN ETHNOLOGIST | 0,453

AMERICAN HISTORICAL REVIEW | 1,217

AMERICAN INDIAN AND ALASKA NATIVE MENTAL HEALTH RESEARCH | 0,556

AMERICAN JOURNAL OF AGRICULTURAL ECONOMICS | 0,674

AMERICAN JOURNAL OF ART THERAPY | 0,056

AMERICAN JOURNAL OF CLINICAL HYPNOSIS | 0,227

AMERICAN JOURNAL OF COMMUNITY PSYCHOLOGY | 1,500

AMERICAN JOURNAL OF COMPARATIVE LAW | 2,114

AMERICAN JOURNAL OF DRUG AND ALCOHOL ABUSE | 1,053

AMERICAN JOURNAL OF ECONOMICS AND SOCIOLOGY | 0,167

AMERICAN JOURNAL OF EDUCATION | 0,900

AMERICAN JOURNAL OF EVALUATION | 1,147

AMERICAN JOURNAL OF FAMILY THERAPY | 0,327

AMERICAN JOURNAL OF GERIATRIC PSYCHIATRY | 1,802

AMERICAN JOURNAL OF HEALTH BEHAVIOR | 0,297

AMERICAN JOURNAL OF HEALTH PROMOTION | 1,011

AMERICAN JOURNAL OF HUMAN BIOLOGY | 0,695

AMERICAN JOURNAL OF INTERNATIONAL LAW | 2,667

AMERICAN JOURNAL OF LAW & MEDICINE | 1,594

AMERICAN JOURNAL OF LEGAL HISTORY | 0,091

AMERICAN JOURNAL OF MANAGED CARE | 0,642

AMERICAN JOURNAL OF NURSING | 0,181

AMERICAN JOURNAL OF OCCUPATIONAL THERAPY | 0,770

AMERICAN JOURNAL OF ORTHOPSYCHIATRY | 1,939

AMERICAN JOURNAL OF PHYSICAL ANTHROPOLOGY | 1,827

AMERICAN JOURNAL OF POLITICAL SCIENCE | 1,788

AMERICAN JOURNAL OF PSYCHIATRY | 6,577

AMERICAN JOURNAL OF PSYCHOLOGY | 0,286

AMERICAN JOURNAL OF PSYCHOTHERAPY | 0,362

AMERICAN JOURNAL OF PUBLIC HEALTH | 3,269

AMERICAN JOURNAL OF SOCIOLOGY | 2,829

AMERICAN JOURNAL OF SPEECH-LANGUAGE PATHOLOGY | 1,127

AMERICAN JOURNAL ON ADDICTIONS | 0,941

AMERICAN JOURNAL ON MENTAL RETARDATION | 1,478

AMERICAN POLITICAL SCIENCE REVIEW | 2,211

AMERICAN POLITICS QUARTERLY | 0,318

AMERICAN PSYCHOLOGIST | 6,857

AMERICAN REVIEW OF PUBLIC ADMINISTRATION | 0,333

AMERICAN SOCIOLOGICAL REVIEW | 3,255

ANALYTISCHE PSYCHOLOGIE | 0,071

ANIMAL LEARNING & BEHAVIOR | 1,105

ANNALS OF BEHAVIORAL MEDICINE | 2,506

ANNALS OF DYSLEXIA | 0,320

ANNALS OF REGIONAL SCIENCE | 0,763

ANNALS OF SCIENCE | 0,379

ANNALS OF THE AMERICAN ACADEMY OF POLITICAL AND SOCIAL SCIENCE | 0,527

ANNALS OF THE ASSOCIATION OF AMERICAN GEOGRAPHERS | 2,109

ANNALS OF TOURISM RESEARCH | 0,318

ANNEE PSYCHOLOGIQUE | 0,238

ANNUAL REVIEW OF ANTHROPOLOGY | 1,089

ANNUAL REVIEW OF PSYCHOLOGY | 5,851

ANNUAL REVIEW OF PUBLIC HEALTH | 4,524

ANNUAL REVIEW OF SOCIOLOGY | 2,809

ANTHROPOLOGICAL QUARTERLY | 0,182

ANTHROPOLOGICAL SCIENCE | 0,429

ANTHROPOLOGIE | 0,224

ANTHROPOLOGY & EDUCATION QUARTERLY | 0,293

ANTHROPOLOGY AND ARCHEOLOGY OF EURASIA | 0,111

ANTHROPOS | 0,206

ANTHROZOOS | 0,039

ANTIPODE | 1,226

ANTITRUST LAW JOURNAL | 1,750

APPLIED & PREVENTIVE PSYCHOLOGY | 1,325

APPLIED COGNITIVE PSYCHOLOGY | 0,929

APPLIED ECONOMICS | 0,213

APPLIED ECONOMICS LETTERS | 0,096

APPLIED ERGONOMICS | 0,642

APPLIED GEOGRAPHY | 0,413

APPLIED LINGUISTICS | 0,692

APPLIED MEASUREMENT IN EDUCATION | 0,279

APPLIED NURSING RESEARCH | 0,473

APPLIED PSYCHOLINGUISTICS | 0,818

APPLIED PSYCHOLOGICAL MEASUREMENT | 0,561

APPLIED PSYCHOLOGY-AN INTERNATIONAL REVIEW-PSYCHOLOGIE APPLIQUEE-REVUE INTE | 0,518

APPLIED PSYCHOPHYSIOLOGY AND BIOFEEDBACK | 0,700

ARCHIVE FOR HISTORY OF EXACT SCIENCES | 0,250

ARCHIVES EUROPEENNES DE SOCIOLOGIE | 0,269

ARCHIVES OF CLINICAL NEUROPSYCHOLOGY | 1,395

ARCHIVES OF GENERAL PSYCHIATRY | 11,778

ARCHIVES OF PSYCHIATRIC NURSING | 0,514

ARCHIVES OF SEXUAL BEHAVIOR | 1,271

ARCHIVES OF SUICIDE RESEARCH | 0,718

ARCTIC ANTHROPOLOGY | 0,130

AREA | 1,215

ARMED FORCES & SOCIETY | 0,067

ARTS IN PSYCHOTHERAPY | 0,240

ASIA PACIFIC JOURNAL OF SOCIAL WORK | 0,000

ASIAN JOURNAL OF WOMENS STUDIES | 0,024

ASIAN SURVEY | 0,225

ASLIB PROCEEDINGS | 0,397

ASSESSMENT | 0,918

ASSISTIVE TECHNOLOGY | 0,552

AUDITING-A JOURNAL OF PRACTICE & THEORY | 0,290

AUSSEN POLITIK | 0,125

AUSTRALIAN AND NEW ZEALAND JOURNAL OF CRIMINOLOGY | 0,079

AUSTRALIAN AND NEW ZEALAND JOURNAL OF PSYCHIATRY | 1,265

AUSTRALIAN AND NEW ZEALAND JOURNAL OF PUBLIC HEALTH | 1,047

AUSTRALIAN FEMINIST STUDIES | 0,054

AUSTRALIAN GEOGRAPHER | 0,590

AUSTRALIAN JOURNAL OF AGRICULTURAL AND RESOURCE ECONOMICS | 0,417

AUSTRALIAN JOURNAL OF EDUCATION | 0,054

AUSTRALIAN JOURNAL OF INTERNATIONAL AFFAIRS | 0,485

AUSTRALIAN JOURNAL OF POLITICAL SCIENCE | 0,361

AUSTRALIAN JOURNAL OF PSYCHOLOGY | 0,660

AUSTRALIAN JOURNAL OF PUBLIC ADMINISTRATION | 0,305

AUSTRALIAN JOURNAL OF SOCIAL ISSUES | 0,190

AUSTRALIAN PSYCHOLOGIST | 0,710

BASIC AND APPLIED SOCIAL PSYCHOLOGY | 0,375

BEHAVIOR ANALYST | 0,500

BEHAVIOR AND PHILOSOPHY | 0,273

BEHAVIOR GENETICS | 1,516

BEHAVIOR MODIFICATION | 0,734

BEHAVIOR RESEARCH METHODS INSTRUMENTS & COMPUTERS | 0,750

BEHAVIOR THERAPY | 1,494

BEHAVIORAL & SOCIAL SCIENCES LIBRARIAN | 0,000

BEHAVIORAL AND BRAIN SCIENCES | 14,250

BEHAVIORAL DISORDERS | 0,500

BEHAVIORAL HEALTHCARE TOMORROW | 0,149

BEHAVIORAL MEDICINE | 1,000

BEHAVIORAL SCIENCES & THE LAW | 0,929

BEHAVIOUR & INFORMATION TECHNOLOGY | 0,413

BEHAVIOUR CHANGE | 0,217

BEHAVIOUR RESEARCH AND THERAPY | 1,699

BEHAVIOURAL PROCESSES | 0,906

BERLINER JOURNAL FUR SOZIOLOGIE | 0,259

BETRIEBSWIRTSCHAFTLICHE FORSCHUNG UND PRAXIS | 0,261

BIJDRAGEN TOT DE TAAL- LAND- EN VOLKENKUNDE | 0,231

BIOETHICS | 0,630

BIOLOGICAL PSYCHOLOGY | 1,500

BIOLOGY & PHILOSOPHY | 0,627

BIRTH-ISSUES IN PERINATAL CARE | 1,250

BLACK SCHOLAR | 0,171

BOSTON UNIVERSITY LAW REVIEW | 1,254

BRAIN AND COGNITION | 0,630

BRAIN AND LANGUAGE | 1,473

BRITISH JOURNAL FOR THE HISTORY OF SCIENCE | 0,405

BRITISH JOURNAL FOR THE PHILOSOPHY OF SCIENCE | 0,867

BRITISH JOURNAL OF CLINICAL PSYCHOLOGY | 1,091

BRITISH JOURNAL OF CRIMINOLOGY | 0,791

BRITISH JOURNAL OF DEVELOPMENTAL DISABILITIES | 0,130

BRITISH JOURNAL OF DEVELOPMENTAL PSYCHOLOGY | 0,800

BRITISH JOURNAL OF EDUCATIONAL PSYCHOLOGY | 0,537

BRITISH JOURNAL OF EDUCATIONAL STUDIES | 0,628

BRITISH JOURNAL OF EDUCATIONAL TECHNOLOGY | 0,318

BRITISH JOURNAL OF FAMILY PLANNING | 0,791

BRITISH JOURNAL OF HEALTH PSYCHOLOGY | 0,981

BRITISH JOURNAL OF INDUSTRIAL RELATIONS | 1,000

BRITISH JOURNAL OF MATHEMATICAL & STATISTICAL PSYCHOLOGY | 1,257

BRITISH JOURNAL OF MEDICAL PSYCHOLOGY | 0,562

BRITISH JOURNAL OF POLITICAL SCIENCE | 0,803

BRITISH JOURNAL OF PSYCHIATRY | 4,827

BRITISH JOURNAL OF PSYCHOLOGY | 1,053

BRITISH JOURNAL OF SOCIAL PSYCHOLOGY | 1,352

BRITISH JOURNAL OF SOCIAL WORK | 0,489

BRITISH JOURNAL OF SOCIOLOGY | 0,697

BRITISH JOURNAL OF SOCIOLOGY OF EDUCATION | 0,948

BROOKINGS PAPERS ON ECONOMIC ACTIVITY | 3,926

BUFFALO LAW REVIEW | 1,043

BULLETIN OF CONCERNED ASIAN SCHOLARS | 0,315

BULLETIN OF INDONESIAN ECONOMIC STUDIES | 0,714

BULLETIN OF THE ATOMIC SCIENTISTS | 0,246

BULLETIN OF THE HISTORY OF MEDICINE | 0,556

BULLETIN OF THE MEDICAL LIBRARY ASSOCIATION | 0,343

BULLETIN OF THE MENNINGER CLINIC | 0,523

BUSINESS HISTORY | 0,978

BUSINESS HISTORY REVIEW | 0,480

BUSINESS LAWYER | 0,802

CAHIERS DE PSYCHOLOGIE COGNITIVE-CURRENT PSYCHOLOGY OF COGNITION | 0,260

CALIFORNIA LAW REVIEW | 2,695

CALIFORNIA MANAGEMENT REVIEW | 2,877

CAMBRIDGE JOURNAL OF ECONOMICS | 1,114

CAMBRIDGE QUARTERLY OF HEALTHCARE ETHICS | 0,466

CANADIAN GEOGRAPHER-GEOGRAPHE CANADIEN | 0,796

CANADIAN JOURNAL OF ADMINISTRATIVE SCIENCES-REVUE CANADIENNE DES SCIENCES D | 0,264

CANADIAN JOURNAL OF BEHAVIOURAL SCIENCE-REVUE CANADIENNE DES SCIENCES DU CO | 0,245

CANADIAN JOURNAL OF CRIMINOLOGY-REVUE CANADIENNE DE CRIMINOLOGIE | 0,262

CANADIAN JOURNAL OF ECONOMICS-REVUE CANADIENNE D ECONOMIQUE | 0,404

CANADIAN JOURNAL OF EXPERIMENTAL PSYCHOLOGY-REVUE CANADIENNE DE PSYCHOLOGIE | 0,500

CANADIAN JOURNAL OF INFORMATION AND LIBRARY SCIENCE-REVUE CANADIENNE DES SC | 0,167

CANADIAN JOURNAL OF LINGUISTICS-REVUE CANADIENNE DE LINGUISTIQUE | 0,238

CANADIAN JOURNAL OF POLITICAL SCIENCE-REVUE CANADIENNE DE SCIENCE POLITIQUE | 0,310

CANADIAN JOURNAL OF PSYCHIATRY-REVUE CANADIENNE DE PSYCHIATRIE | 1,623

CANADIAN JOURNAL OF PUBLIC HEALTH-REVUE CANADIENNE DE SANTE PUBLIQUE | 0,667

CANADIAN JOURNAL OF SOCIOLOGY-CAHIERS CANADIENS DE SOCIOLOGIE | 0,250

CANADIAN JOURNAL ON AGING-REVUE CANADIENNE DU VIEILLISSEMENT | 0,415

CANADIAN MODERN LANGUAGE REVIEW-REVUE CANADIENNE DES LANGUES VIVANTES | 0,180

CANADIAN PSYCHOLOGY-PSYCHOLOGIE CANADIENNE | 0,516

CANADIAN PUBLIC ADMINISTRATION-ADMINISTRATION PUBLIQUE DU CANADA | 0,237

CANADIAN PUBLIC POLICY-ANALYSE DE POLITIQUES | 0,322

CANADIAN REVIEW OF SOCIOLOGY AND ANTHROPOLOGY-REVUE CANADIENNE DE SOCIOLOGI | 0,275

CANCER NURSING | 0,855

CANCER PRACTICE | 0,741

CAREER DEVELOPMENT QUARTERLY | 1,298

CARTOGRAPHIC JOURNAL | 0,161

CATHOLIC UNIVERSITY LAW REVIEW | 0,824

CESKOSLOVENSKA PSYCHOLOGIE | 0,295

CHILD & FAMILY BEHAVIOR THERAPY | 0,345

CHILD ABUSE & NEGLECT | 1,072

CHILD AND ADOLESCENT PSYCHIATRIC CLINICS OF NORTH AMERICA | 0,901

CHILD CARE HEALTH AND DEVELOPMENT | 0,636

CHILD DEVELOPMENT | 2,768

CHILD PSYCHIATRY & HUMAN DEVELOPMENT | 0,422

CHILD WELFARE | 0,712

CHILDHOOD-A GLOBAL JOURNAL OF CHILD RESEARCH | 0,469

CHILDREN AND YOUTH SERVICES REVIEW | 0,338

CHILDRENS HEALTH CARE | 0,350

CHINA ECONOMIC REVIEW | 0,409

CHINA JOURNAL | 0,900

CHINA QUARTERLY | 0,932

CHINESE EDUCATION AND SOCIETY | 0,024

CHINESE LAW AND GOVERNMENT | 0,033

CHINESE SOCIOLOGY AND ANTHROPOLOGY | 0,033

CITIES | 0,493

CLINICAL LINGUISTICS & PHONETICS | 0,837

CLINICAL NEUROPSYCHOLOGIST | 0,948

CLINICAL PSYCHOLOGY & PSYCHOTHERAPY | 0,565

CLINICAL PSYCHOLOGY REVIEW | 1,430

CLINICAL PSYCHOLOGY-SCIENCE AND PRACTICE | 1,682

CLINICAL SOCIAL WORK JOURNAL | 0,255

COGNITION | 2,622

COGNITION & EMOTION | 1,863

COGNITION AND INSTRUCTION | 0,696

COGNITIVE AND BEHAVIORAL PRACTICE | 0,862

COGNITIVE DEVELOPMENT | 0,962

COGNITIVE NEUROPSYCHOLOGY | 2,180

COGNITIVE PSYCHOLOGY | 3,463

COGNITIVE SCIENCE | 1,629

COGNITIVE THERAPY AND RESEARCH | 0,756

COLLEGE & RESEARCH LIBRARIES | 0,905

COLLEGIUM ANTROPOLOGICUM | 0,355

COLUMBIA JOURNAL OF LAW AND SOCIAL PROBLEMS | 0,300

COLUMBIA JOURNAL OF TRANSNATIONAL LAW | 1,139

COLUMBIA LAW REVIEW | 4,700

COMMENTARY | 0,234

COMMON MARKET LAW REVIEW | 1,367

COMMUNICATION EDUCATION | 0,350

COMMUNICATION MONOGRAPHS | 1,049

COMMUNICATION RESEARCH | 1,091

COMMUNICATION THEORY | 0,818

COMMUNIST AND POST-COMMUNIST STUDIES | 0,265

COMMUNIST ECONOMIES & ECONOMIC TRANSFORMATION | 0,500

COMMUNITY MENTAL HEALTH JOURNAL | 0,789

COMPARATIVE EDUCATION | 0,675

COMPARATIVE EDUCATION REVIEW | 0,710

COMPARATIVE POLITICAL STUDIES | 1,071

COMPARATIVE POLITICS | 0,902

COMPARATIVE STUDIES IN SOCIETY AND HISTORY | 0,315

COMPREHENSIVE PSYCHIATRY | 1,400

COMPUTATIONAL LINGUISTICS | 1,146

COMPUTERS & EDUCATION | 0,300

COMPUTERS IN HUMAN BEHAVIOR | 0,333

CONFIGURATIONS | 0,281

CONFLICT MANAGEMENT AND PEACE SCIENCE | 0,000

CONSCIOUSNESS AND COGNITION | 1,962

CONTEMPORARY ECONOMIC POLICY | 0,398

CONTEMPORARY EDUCATIONAL PSYCHOLOGY | 0,595

CONTEMPORARY FAMILY THERAPY | 0,169

CONTEMPORARY PACIFIC | 0,147

CONTEMPORARY PSYCHOANALYSIS | 0,759

CONTEMPORARY SOCIOLOGY-A JOURNAL OF REVIEWS | 0,976

CONTINUITY AND CHANGE | 0,742

CONTRIBUTIONS TO INDIAN SOCIOLOGY | 0,054

CORNELL INTERNATIONAL LAW JOURNAL | 1,000

CORNELL LAW REVIEW | 3,517

COUNSELING PSYCHOLOGIST | 0,747

CREATIVITY RESEARCH JOURNAL | 0,206

CRIME & DELINQUENCY | 0,897

CRIME AND JUSTICE-A REVIEW OF RESEARCH | 0,719

CRIME LAW AND SOCIAL CHANGE | 0,283

CRIMINAL JUSTICE AND BEHAVIOR | 0,979

CRIMINAL LAW REVIEW | 0,552

CRIMINOLOGY | 2,393

CRISIS INTERVENTION AND TIME-LIMITED TREATMENT | 0,308

CRITICAL REVIEW | 0,180

CRITICAL STUDIES IN MASS COMMUNICATION | 0,224

CRITICAL STUDIES IN MEDIA COMMUNICATION |

CRITIQUE OF ANTHROPOLOGY | 0,429

CULTURAL ANTHROPOLOGY | 0,805

CULTURAL STUDIES | 0,286

CULTURE & PSYCHOLOGY | 0,368

CULTURE MEDICINE AND PSYCHIATRY | 0,545

CURRENT ANTHROPOLOGY | 2,429

CURRENT DIRECTIONS IN PSYCHOLOGICAL SCIENCE | 1,430

CURRENT HISTORY | 0,276

CURRENT OPINION IN PSYCHIATRY | 0,563

CURRENT PSYCHOLOGY | 0,217

CURRICULUM INQUIRY | 0,219

DADOS-REVISTA DE CIENCIAS SOCIAIS | 0,167

DAEDALUS | 0,663

DATABASE | 0,393

DEATH STUDIES | 0,742

DECISION SCIENCES | 0,473

DEFENCE AND PEACE ECONOMICS | 0,471

DEMOGRAPHY | 1,807

DENVER UNIVERSITY LAW REVIEW | 0,141

DESARROLLO ECONOMICO-REVISTA DE CIENCIAS SOCIALES | 0,155

DEVELOPING ECONOMIES | 0,583

DEVELOPMENT AND CHANGE | 0,893

DEVELOPMENT AND PSYCHOPATHOLOGY | 3,079

DEVELOPMENTAL NEUROPSYCHOLOGY | 0,871

DEVELOPMENTAL PSYCHOLOGY | 2,044

DEVELOPMENTAL REVIEW | 1,357

DEVIANT BEHAVIOR | 0,406

DIAGNOSTICA | 2,067

DISABILITY & SOCIETY | 1,082

DISABILITY AND REHABILITATION | 0,535

DISASTERS | 0,435

DISCOURSE & SOCIETY | 1,800

DISCOURSE PROCESSES | 1,581

DISSENT | 0,237

DREAMING | 0,513

DRUG AND ALCOHOL REVIEW | 0,783

DRUGS-EDUCATION PREVENTION AND POLICY | 0,446

DRUSTVENA ISTRAZIVANJA | 0,084

DUKE LAW JOURNAL | 3,130

DYNAMISCHE PSYCHIATRIE | 0,226

EARLY CHILDHOOD RESEARCH QUARTERLY | 0,509

EARLY DEVELOPMENT & PARENTING | 0,148

EAST EUROPEAN POLITICS AND SOCIETIES | 1,109

EAST EUROPEAN QUARTERLY | 0,093

EASTERN EUROPEAN ECONOMICS | 0,062

ECOLOGICAL ECONOMICS | 1,258

ECOLOGICAL PSYCHOLOGY | 1,240

ECOLOGY LAW QUARTERLY | 1,000

ECONOMETRIC THEORY | 0,475

ECONOMETRICA | 1,874

ECONOMIC AND INDUSTRIAL DEMOCRACY | 0,415

ECONOMIC AND SOCIAL REVIEW | 0,158

ECONOMIC DEVELOPMENT AND CULTURAL CHANGE | 0,803

ECONOMIC DEVELOPMENT QUARTERLY | 0,323

ECONOMIC GEOGRAPHY | 1,909

ECONOMIC HISTORY REVIEW | 1,419

ECONOMIC INQUIRY | 0,626

ECONOMIC JOURNAL | 1,396

ECONOMIC MODELLING | 0,233

ECONOMIC POLICY | 2,208

ECONOMIC RECORD | 0,121

ECONOMIC THEORY | 0,466

ECONOMICA | 0,803

ECONOMICS AND PHILOSOPHY | 0,875

ECONOMICS LETTERS | 0,254

ECONOMICS OF EDUCATION REVIEW | 0,280

ECONOMICS OF PLANNING | 0,130

ECONOMICS OF TRANSITION | 0,418

ECONOMIST | 0,340

ECONOMY AND SOCIETY | 0,902

ECONTENT | 0,065

ECOSYSTEM HEALTH | 1,000

ECUMENE | 0,590

EDUCATION AND TRAINING IN MENTAL RETARDATION AND DEVELOPMENTAL DISABILITIES | 0,342

EDUCATION AND URBAN SOCIETY | 0,373

EDUCATIONAL ADMINISTRATION QUARTERLY | 0,685

EDUCATIONAL AND PSYCHOLOGICAL MEASUREMENT | 0,608

EDUCATIONAL EVALUATION AND POLICY ANALYSIS | 0,857

EDUCATIONAL GERONTOLOGY | 0,211

EDUCATIONAL LEADERSHIP | 0,255

EDUCATIONAL POLICY | 0,426

EDUCATIONAL PSYCHOLOGIST | 3,517

EDUCATIONAL PSYCHOLOGY REVIEW | 1,000

EDUCATIONAL RESEARCH | 0,667

EDUCATIONAL REVIEW | 0,405

EDUCATIONAL STUDIES | 0,426

EKONOMICKY CASOPIS | 0,106

EKONOMISKA SAMFUNDETS TIDSKRIFT | 0,047

ELECTORAL STUDIES | 0,361

ELECTRONIC LIBRARY | 0,190

ELEMENTA-JOURNAL OF SLAVIC STUDIES & COMPARATIVE CULTURAL SEMIOTICS | 0,111

ELEMENTARY SCHOOL JOURNAL | 0,865

EMPLOYEE RELATIONS LAW JOURNAL | 0,104

ENERGY ECONOMICS | 0,561

ENERGY JOURNAL | 1,000

ENERGY POLICY | 0,669

ENVIRONMENT AND BEHAVIOR | 0,973

ENVIRONMENT AND PLANNING A | 1,210

ENVIRONMENT AND PLANNING B-PLANNING & DESIGN | 0,632

ENVIRONMENT AND PLANNING C-GOVERNMENT AND POLICY | 0,859

ENVIRONMENT AND PLANNING D-SOCIETY & SPACE | 2,152

ENVIRONMENT AND URBANIZATION | 0,815

ENVIRONMENTAL & RESOURCE ECONOMICS | 0,554

ENVIRONMENTAL ETHICS | 0,410

ENVIRONMENTAL HISTORY | 0,688

ENVIRONMENTAL VALUES | 0,622

ERGONOMICS | 0,691

ETHICS | 1,478

ETHICS & BEHAVIOR | 0,674

ETHNIC AND RACIAL STUDIES | 0,767

ETHNOHISTORY | 0,119

ETHNOLOGY | 0,268

ETHOS | 0,333

ETR&D-EDUCATIONAL TECHNOLOGY RESEARCH AND DEVELOPMENT | 0,177

EUROPEAN ADDICTION RESEARCH | 1,569

EUROPEAN CHILD & ADOLESCENT PSYCHIATRY | 0,577

EUROPEAN EATING DISORDERS REVIEW | 0,561

EUROPEAN ECONOMIC REVIEW | 0,893

EUROPEAN JOURNAL OF COGNITIVE PSYCHOLOGY | 0,452

EUROPEAN JOURNAL OF COMMUNICATION | 0,639

EUROPEAN JOURNAL OF INDUSTRIAL RELATIONS | 1,107

EUROPEAN JOURNAL OF INTERNATIONAL RELATIONS | 1,036

EUROPEAN JOURNAL OF PERSONALITY | 0,845

EUROPEAN JOURNAL OF POLITICAL RESEARCH | 0,602

EUROPEAN JOURNAL OF POPULATION-REVUE EUROPEENNE DE DEMOGRAPHIE | 0,269

EUROPEAN JOURNAL OF PSYCHIATRY | 0,231

EUROPEAN JOURNAL OF PSYCHOLOGICAL ASSESSMENT | 0,412

EUROPEAN JOURNAL OF PSYCHOLOGY OF EDUCATION | 0,258

EUROPEAN JOURNAL OF PUBLIC HEALTH | 1,165

EUROPEAN JOURNAL OF SOCIAL PSYCHOLOGY | 1,069

EUROPEAN JOURNAL OF WOMENS STUDIES | 0,275

EUROPEAN PSYCHIATRY | 0,748

EUROPEAN REVIEW OF AGRICULTURAL ECONOMICS | 0,472

EUROPEAN SOCIOLOGICAL REVIEW | 0,703

EUROPEAN URBAN AND REGIONAL STUDIES | 1,861

EUROPE-ASIA STUDIES | 0,394

EVALUATION & THE HEALTH PROFESSIONS | 0,696

EVALUATION AND PROGRAM PLANNING | 0,253

EVALUATION REVIEW | 0,895

EVOLUTION AND HUMAN BEHAVIOR | 1,741

EVOLUTION PSYCHIATRIQUE | 0,083

EVOLUTIONARY ANTHROPOLOGY | 3,658

EXCEPTIONAL CHILDREN | 1,214

EXPERIMENTAL AND CLINICAL PSYCHOPHARMACOLOGY | 1,747

EXPLORATIONS IN ECONOMIC HISTORY | 0,429

FAMILIES IN SOCIETY-THE JOURNAL OF CONTEMPORARY HUMAN SERVICES | 0,361

FAMILY & COMMUNITY HEALTH | 0,286

FAMILY LAW QUARTERLY | 1,632

FAMILY PLANNING PERSPECTIVES | 2,013

FAMILY PROCESS | 0,887

FAMILY RELATIONS | 0,859

FEDERAL PROBATION | 0,245

FEMINISM & PSYCHOLOGY | 0,265

FEMINIST ECONOMICS | 0,434

FEMINIST REVIEW | 0,135

FEMINIST STUDIES | 0,173

FILOSOFICKY CASOPIS | 0,069

FINANCE A UVER | 0,281

FINANCIAL MANAGEMENT | 0,238

FOCUS ON EXCEPTIONAL CHILDREN | 0,000

FOLIA PHONIATRICA ET LOGOPAEDICA | 0,354

FOOD AND DRUG LAW JOURNAL | 0,771

FOOD POLICY | 0,306

FORBES | 0,027

FORDHAM LAW REVIEW | 1,309

FOREIGN AFFAIRS | 3,233

FOREIGN LANGUAGE ANNALS | 0,328

FOREIGN POLICY | 1,310

FORTUNE | 0,124

FORUM DER PSYCHOANALYSE | 0,304

FRONTIERS-A JOURNAL OF WOMEN STUDIES | 0,083

FUTURE OF CHILDREN | 1,811

FUTURES | 0,258

FUTURIST | 0,210

GAMES AND ECONOMIC BEHAVIOR | 0,390

GENDER & SOCIETY | 1,098

GENERAL HOSPITAL PSYCHIATRY | 1,512

GENERATIONS-JOURNAL OF THE AMERICAN SOCIETY ON AGING | 0,187

GENETIC SOCIAL AND GENERAL PSYCHOLOGY MONOGRAPHS | 0,703

GENEVA PAPERS ON RISK AND INSURANCE THEORY | 0,762

GEOFORUM | 1,518

GEOGRAPHICAL ANALYSIS | 1,024

GEOGRAPHICAL JOURNAL | 0,930

GEOGRAPHICAL REVIEW | 0,277

GEOGRAPHISCHE ZEITSCHRIFT | 0,294

GEOGRAPHY | 0,323

GEORGE WASHINGTON LAW REVIEW | 1,311

GEORGETOWN LAW JOURNAL | 3,353

GERIATRIC NURSING | 0,198

GERMAN STUDIES REVIEW | 0,091

GERONTOLOGIST | 1,776

GIFTED CHILD QUARTERLY | 0,737

GLOBAL GOVERNANCE | 0,522

GLQ-A JOURNAL OF LESBIAN AND GAY STUDIES | 0,542

GOVERNANCE-AN INTERNATIONAL JOURNAL OF POLICY AND ADMINISTRATION | 0,973

GOVERNMENT AND OPPOSITION | 0,450

GOVERNMENT INFORMATION QUARTERLY | 0,190

GROUP | 0,259

GROUP & ORGANIZATION MANAGEMENT | 0,590

GROUP DECISION AND NEGOTIATION | 0,294

GROWTH AND CHANGE | 0,578

GRUPPENDYNAMIK-ZEITSCHRIFT FUR ANGEWANDTE SOZIALPSYCHOLOGIE | 0,087

GRUPPENPSYCHOTHERAPIE UND GRUPPENDYNAMIK | 1,273

HABITAT INTERNATIONAL | 0,219

HARVARD BUSINESS REVIEW | 2,561

HARVARD CIVIL RIGHTS-CIVIL LIBERTIES LAW REVIEW | 1,786

HARVARD EDUCATIONAL REVIEW | 0,963

HARVARD ENVIRONMENTAL LAW REVIEW | 2,217

HARVARD INTERNATIONAL JOURNAL OF PRESS-POLITICS | 0,465

HARVARD INTERNATIONAL LAW JOURNAL | 2,667

HARVARD JOURNAL OF LAW AND PUBLIC POLICY | 1,019

HARVARD JOURNAL ON LEGISLATION | 0,912

HARVARD LAW REVIEW | 6,347

HARVARD REVIEW OF PSYCHIATRY | 1,076

HASTINGS CENTER REPORT | 1,315

HASTINGS LAW JOURNAL | 1,040

HEALTH & SOCIAL CARE IN THE COMMUNITY | 0,365

HEALTH & SOCIAL WORK | 0,741

HEALTH AFFAIRS | 3,823

HEALTH CARE ANALYSIS | 0,377

HEALTH CARE FINANCING REVIEW | 0,500

HEALTH CARE MANAGEMENT REVIEW | 0,850

HEALTH COMMUNICATION | 0,571

HEALTH ECONOMICS | 1,966

HEALTH EDUCATION & BEHAVIOR | 1,954

HEALTH EDUCATION RESEARCH | 0,922

HEALTH POLICY | 0,918

HEALTH POLICY AND PLANNING | 1,096

HEALTH PROMOTION INTERNATIONAL | 1,109

HEALTH PSYCHOLOGY | 3,074

HEALTH SERVICES RESEARCH | 2,070

HIGHER EDUCATION | 0,259

HISPANIC JOURNAL OF BEHAVIORAL SCIENCES | 0,281

HISTORIA MATHEMATICA | 0,258

HISTORICAL STUDIES IN THE PHYSICAL AND BIOLOGICAL SCIENCES | 0,211

HISTORY AND PHILOSOPHY OF LOGIC | 0,250

HISTORY AND PHILOSOPHY OF THE LIFE SCIENCES | 0,192

HISTORY OF EDUCATION QUARTERLY | 0,100

HISTORY OF POLITICAL ECONOMY | 0,092

HISTORY OF PSYCHIATRY | 0,688

HISTORY OF SCIENCE | 0,792

HISTORY OF THE HUMAN SCIENCES | 0,333

HISTORY WORKSHOP JOURNAL | 0,293

HITOTSUBASHI JOURNAL OF ECONOMICS | 0,286

HOMME | 0,442

HOMO | 0,368

HOSPITALS & HEALTH NETWORKS | 0,221

HOUSING POLICY DEBATE | 1,490

HOUSING STUDIES | 0,761

HOUSING THEORY AND SOCIETY | 0,214

HUMAN COMMUNICATION RESEARCH | 0,700

HUMAN DEVELOPMENT | 0,577

HUMAN ECOLOGY | 0,702

HUMAN FACTORS | 0,954

HUMAN FACTORS AND ERGONOMICS IN MANUFACTURING | 0,136

HUMAN MOVEMENT SCIENCE | 0,805

HUMAN NATURE-AN INTERDISCIPLINARY BIOSOCIAL PERSPECTIVE | 1,379

HUMAN ORGANIZATION | 0,592

HUMAN PERFORMANCE | 1,733

HUMAN RELATIONS | 0,832

HUMAN RESOURCE MANAGEMENT | 1,268

HUMAN RIGHTS QUARTERLY | 0,339

HUMAN STUDIES | 0,364

HUMOR-INTERNATIONAL JOURNAL OF HUMOR RESEARCH | 0,083

IDENTITIES-GLOBAL STUDIES IN CULTURE AND POWER | 0,267

IDS BULLETIN-INSTITUTE OF DEVELOPMENT STUDIES | 0,316

IEEE TRANSACTIONS ON ENGINEERING MANAGEMENT | 0,325

IIC-INTERNATIONAL REVIEW OF INDUSTRIAL PROPERTY AND COPYRIGHT LAW | 0,482

IMF STAFF PAPERS | 1,000

IN SESSION-PSYCHOTHERAPY IN PRACTICE | 0,217

INDIAN JOURNAL OF SOCIAL WORK | 0,014

INDIANA LAW JOURNAL | 1,844

INDUSTRIAL & LABOR RELATIONS REVIEW | 1,048

INDUSTRIAL MARKETING MANAGEMENT | 0,420

INDUSTRIAL RELATIONS | 0,873

INFANT AND CHILD DEVELOPMENT | 0,143

INFANT BEHAVIOR & DEVELOPMENT | 1,188

INFANT MENTAL HEALTH JOURNAL | 0,842

INFANTS AND YOUNG CHILDREN | 0,297

INFORMATION & MANAGEMENT | 0,683

INFORMATION PROCESSING & MANAGEMENT | 0,719

INFORMATION SOCIETY | 0,404

INFORMATION SYSTEMS JOURNAL | 0,375

INFORMATION SYSTEMS RESEARCH | 1,093

INFORMATION TECHNOLOGY AND LIBRARIES | 0,481

INNOVATIONS IN EDUCATION AND TRAINING INTERNATIONAL | 0,130

INQUIRY-THE JOURNAL OF HEALTH CARE ORGANIZATION PROVISION AND FINANCING | 0,941

INSTRUCTIONAL SCIENCE | 0,651

INSURANCE MATHEMATICS & ECONOMICS | 0,607

INTEGRATIVE PHYSIOLOGICAL AND BEHAVIORAL SCIENCE | 0,250

INTELLIGENCE | 0,500

INTERDISCIPLINARY SCIENCE REVIEWS | 0,058

INTERFACES | 0,629

INTERLENDING & DOCUMENT SUPPLY | 0,400

INTERNASJONAL POLITIKK | 0,083

INTERNATIONAL AFFAIRS | 0,938

INTERNATIONAL ECONOMIC REVIEW | 0,950

INTERNATIONAL FAMILY PLANNING PERSPECTIVES | 0,770

INTERNATIONAL INTERACTIONS | 0,393

INTERNATIONAL JOURNAL | 0,314

INTERNATIONAL JOURNAL FOR QUALITY IN HEALTH CARE | 0,744

INTERNATIONAL JOURNAL OF AGING & HUMAN DEVELOPMENT | 0,431

INTERNATIONAL JOURNAL OF AVIATION PSYCHOLOGY | 0,745

INTERNATIONAL JOURNAL OF BEHAVIORAL DEVELOPMENT | 0,706

INTERNATIONAL JOURNAL OF BEHAVIORAL MEDICINE | 0,556

INTERNATIONAL JOURNAL OF CLINICAL AND EXPERIMENTAL HYPNOSIS | 0,897

INTERNATIONAL JOURNAL OF COMPARATIVE SOCIOLOGY | 0,244

INTERNATIONAL JOURNAL OF CONFLICT MANAGEMENT | 0,633

INTERNATIONAL JOURNAL OF EATING DISORDERS | 1,336

INTERNATIONAL JOURNAL OF EDUCATIONAL DEVELOPMENT | 0,134

INTERNATIONAL JOURNAL OF ELECTRONIC COMMERCE | 0,451

INTERNATIONAL JOURNAL OF FORECASTING | 0,677

INTERNATIONAL JOURNAL OF GAME THEORY | 0,365

INTERNATIONAL JOURNAL OF GEOGRAPHICAL INFORMATION SCIENCE | 0,988

INTERNATIONAL JOURNAL OF GERIATRIC PSYCHIATRY | 1,495

INTERNATIONAL JOURNAL OF GROUP PSYCHOTHERAPY | 0,761

INTERNATIONAL JOURNAL OF HEALTH PLANNING AND MANAGEMENT | 0,472

INTERNATIONAL JOURNAL OF HEALTH SERVICES | 1,217

INTERNATIONAL JOURNAL OF HUMAN-COMPUTER INTERACTION | 0,529

INTERNATIONAL JOURNAL OF HUMAN-COMPUTER STUDIES | 0,333

INTERNATIONAL JOURNAL OF INDUSTRIAL ERGONOMICS | 0,255

INTERNATIONAL JOURNAL OF INDUSTRIAL ORGANIZATION | 0,489

INTERNATIONAL JOURNAL OF INFORMATION MANAGEMENT | 0,424

INTERNATIONAL JOURNAL OF INTERCULTURAL RELATIONS | 0,400

INTERNATIONAL JOURNAL OF LANGUAGE & COMMUNICATION DISORDERS | 0,356

INTERNATIONAL JOURNAL OF LAW AND PSYCHIATRY | 0,662

INTERNATIONAL JOURNAL OF MANPOWER | 0,116

INTERNATIONAL JOURNAL OF MARKET RESEARCH |

INTERNATIONAL JOURNAL OF MENTAL HEALTH | 0,100

INTERNATIONAL JOURNAL OF MIDDLE EAST STUDIES | 0,250

INTERNATIONAL JOURNAL OF NURSING STUDIES | 0,521

INTERNATIONAL JOURNAL OF OFFENDER THERAPY AND COMPARATIVE CRIMINOLOGY | 0,250

INTERNATIONAL JOURNAL OF OPERATIONS & PRODUCTION MANAGEMENT | 0,412

INTERNATIONAL JOURNAL OF OSTEOARCHAEOLOGY | 0,289

INTERNATIONAL JOURNAL OF PSYCHIATRY IN MEDICINE | 1,033

INTERNATIONAL JOURNAL OF PSYCHOANALYSIS | 1,160

INTERNATIONAL JOURNAL OF PSYCHOLOGY | 0,575

INTERNATIONAL JOURNAL OF PSYCHOPHYSIOLOGY | 1,489

INTERNATIONAL JOURNAL OF PUBLIC OPINION RESEARCH | 0,114

INTERNATIONAL JOURNAL OF REHABILITATION RESEARCH | 0,323

INTERNATIONAL JOURNAL OF RESEARCH IN MARKETING | 1,133

INTERNATIONAL JOURNAL OF SCIENCE EDUCATION | 0,705

INTERNATIONAL JOURNAL OF SELECTION AND ASSESSMENT | 0,395

INTERNATIONAL JOURNAL OF SERVICE INDUSTRY MANAGEMENT | 0,200

INTERNATIONAL JOURNAL OF SOCIAL PSYCHIATRY | 0,724

INTERNATIONAL JOURNAL OF SOCIAL WELFARE | 0,111

INTERNATIONAL JOURNAL OF SPORT PSYCHOLOGY | 0,804

INTERNATIONAL JOURNAL OF STRESS MANAGEMENT | 0,545

INTERNATIONAL JOURNAL OF TECHNOLOGY MANAGEMENT | 0,198

INTERNATIONAL JOURNAL OF THE SOCIOLOGY OF LAW | 0,158

INTERNATIONAL JOURNAL OF URBAN AND REGIONAL RESEARCH | 1,244

INTERNATIONAL LABOUR REVIEW | 0,439

INTERNATIONAL MIGRATION | 0,373

INTERNATIONAL MIGRATION REVIEW | 0,586

INTERNATIONAL ORGANIZATION | 3,982

INTERNATIONAL POLITICAL SCIENCE REVIEW | 0,488

INTERNATIONAL REGIONAL SCIENCE REVIEW | 0,909

INTERNATIONAL REVIEW OF ADMINISTRATIVE SCIENCES | 0,232

INTERNATIONAL REVIEW OF LAW AND ECONOMICS | 0,540

INTERNATIONAL REVIEW OF PSYCHIATRY | 0,337

INTERNATIONAL REVIEW OF RESEARCH IN MENTAL RETARDATION | 0,375

INTERNATIONAL REVIEW OF SOCIAL HISTORY | 0,250

INTERNATIONAL SECURITY | 2,784

INTERNATIONAL SOCIAL SCIENCE JOURNAL | 0,325

INTERNATIONAL SOCIAL WORK | 0,127

INTERNATIONAL SOCIOLOGY | 0,708

INTERNATIONAL STUDIES QUARTERLY | 1,162

INTERNATIONAL TAX AND PUBLIC FINANCE | 0,464

INTERNATIONALE POLITIK | 0,083

INTERNET WORLD | 1,167

INTERVENTION IN SCHOOL AND CLINIC | 0,237

IOWA LAW REVIEW | 1,381

IRISH JOURNAL OF PSYCHOLOGICAL MEDICINE | 0,290

ISIS | 0,524

ISRAEL JOURNAL OF PSYCHIATRY AND RELATED SCIENCES | 0,182

ISSUES & STUDIES | 0,218

ISSUES IN LAW & MEDICINE | 0,270

ISSUES IN SCIENCE AND TECHNOLOGY | 0,296

JAHRBUCHER FUR NATIONALOKONOMIE UND STATISTIK | 0,118

JAPAN AND THE WORLD ECONOMY | 0,169

JAPAN QUARTERLY | 0,074

JAPANESE JOURNAL OF EDUCATIONAL PSYCHOLOGY | 0,040

JAPANESE JOURNAL OF PSYCHOLOGY | 0,133

JAPANESE PSYCHOLOGICAL RESEARCH | 0,122

JAVNOST-THE PUBLIC | 0,020

JOURNAL FOR RESEARCH IN MATHEMATICS EDUCATION | 0,294

JOURNAL FOR THE EDUCATION OF THE GIFTED | 0,647

JOURNAL FOR THE SCIENTIFIC STUDY OF RELIGION | 0,773

JOURNAL FOR THE THEORY OF SOCIAL BEHAVIOUR | 0,488

JOURNAL OF ABNORMAL CHILD PSYCHOLOGY | 1,917

JOURNAL OF ABNORMAL PSYCHOLOGY | 3,352

JOURNAL OF ACADEMIC LIBRARIANSHIP | 0,296

JOURNAL OF ACCOUNTING & ECONOMICS | 0,397

JOURNAL OF ACCOUNTING RESEARCH | 1,071

JOURNAL OF ADDICTIVE DISEASES | 1,045

JOURNAL OF ADOLESCENCE | 0,656

JOURNAL OF ADOLESCENT & ADULT LITERACY | 0,531

JOURNAL OF ADOLESCENT HEALTH | 1,415

JOURNAL OF ADOLESCENT RESEARCH | 0,925

JOURNAL OF ADULT DEVELOPMENT | 0,400

JOURNAL OF ADVANCED NURSING | 0,769

JOURNAL OF ADVERTISING | 0,630

JOURNAL OF ADVERTISING RESEARCH | 0,500

JOURNAL OF AFFECTIVE DISORDERS | 1,938

JOURNAL OF AFRICAN ECONOMIES | 0,304

JOURNAL OF AFRICAN HISTORY | 0,194

JOURNAL OF AGING AND HEALTH | 1,204

JOURNAL OF AGING AND PHYSICAL ACTIVITY | 1,136

JOURNAL OF AGING STUDIES | 0,519

JOURNAL OF AGRICULTURAL & ENVIRONMENTAL ETHICS | 0,333

JOURNAL OF AGRICULTURAL AND RESOURCE ECONOMICS | 0,423

JOURNAL OF AGRICULTURAL ECONOMICS | 0,545

JOURNAL OF ALCOHOL AND DRUG EDUCATION | 0,312

JOURNAL OF AMERICAN COLLEGE HEALTH | 1,588

JOURNAL OF AMERICAN HISTORY | 0,564

JOURNAL OF ANALYTICAL PSYCHOLOGY | 0,377

JOURNAL OF ANTHROPOLOGICAL ARCHAEOLOGY | 0,484

JOURNAL OF ANTHROPOLOGICAL RESEARCH | 0,559

JOURNAL OF ANXIETY DISORDERS | 1,513

JOURNAL OF APPLIED BEHAVIOR ANALYSIS | 1,466

JOURNAL OF APPLIED COMMUNICATION RESEARCH | 0,707

JOURNAL OF APPLIED DEVELOPMENTAL PSYCHOLOGY | 0,477

JOURNAL OF APPLIED ECONOMETRICS | 0,607

JOURNAL OF APPLIED GERONTOLOGY | 0,429

JOURNAL OF APPLIED PSYCHOLOGY | 1,730

JOURNAL OF APPLIED RESEARCH IN INTELLECTUAL DISABILITIES | 0,642

JOURNAL OF APPLIED SOCIAL PSYCHOLOGY | 0,722

JOURNAL OF APPLIED SPORT PSYCHOLOGY | 1,105

JOURNAL OF ARCHITECTURAL AND PLANNING RESEARCH | 0,282

JOURNAL OF ASIAN AND AFRICAN STUDIES | 0,025

JOURNAL OF ASIAN STUDIES | 0,538

JOURNAL OF AUTISM AND DEVELOPMENTAL DISORDERS | 2,309

JOURNAL OF BALTIC STUDIES | 0,147

JOURNAL OF BANKING & FINANCE | 0,533

JOURNAL OF BEHAVIOR THERAPY AND EXPERIMENTAL PSYCHIATRY | 0,567

JOURNAL OF BEHAVIORAL DECISION MAKING | 1,639

JOURNAL OF BEHAVIORAL HEALTH SERVICES & RESEARCH | 0,662

JOURNAL OF BEHAVIORAL MEDICINE | 1,099

JOURNAL OF BIOSOCIAL SCIENCE | 0,549

JOURNAL OF BLACK STUDIES | 0,157

JOURNAL OF BROADCASTING & ELECTRONIC MEDIA | 0,487

JOURNAL OF BUSINESS | 1,162

JOURNAL OF BUSINESS & ECONOMIC STATISTICS | 0,750

JOURNAL OF BUSINESS AND PSYCHOLOGY | 0,203

JOURNAL OF BUSINESS AND TECHNICAL COMMUNICATION | 0,433

JOURNAL OF BUSINESS ETHICS | 0,955

JOURNAL OF BUSINESS RESEARCH | 0,407

JOURNAL OF BUSINESS VENTURING | 0,538

JOURNAL OF CAREER ASSESSMENT | 1,320

JOURNAL OF CAREER DEVELOPMENT | 0,233

JOURNAL OF CHILD & ADOLESCENT SUBSTANCE ABUSE | 0,194

JOURNAL OF CHILD LANGUAGE | 0,945

JOURNAL OF CHILD PSYCHOLOGY AND PSYCHIATRY AND ALLIED DISCIPLINES | 2,940

JOURNAL OF CLASSIFICATION | 0,846

JOURNAL OF CLINICAL AND EXPERIMENTAL NEUROPSYCHOLOGY | 1,067

JOURNAL OF CLINICAL CHILD PSYCHOLOGY | 2,526

JOURNAL OF CLINICAL ETHICS | 0,705

JOURNAL OF CLINICAL NURSING | 0,473

JOURNAL OF CLINICAL PSYCHIATRY | 4,454

JOURNAL OF CLINICAL PSYCHOLOGY | 0,680

JOURNAL OF CLINICAL PSYCHOLOGY IN MEDICAL SETTINGS | 0,419

JOURNAL OF COGNITIVE NEUROSCIENCE | 5,115

JOURNAL OF COLLEGE STUDENT DEVELOPMENT | 0,470

JOURNAL OF COMMON MARKET STUDIES | 0,836

JOURNAL OF COMMONWEALTH & COMPARATIVE POLITICS | 0,667

JOURNAL OF COMMUNICATION | 0,535

JOURNAL OF COMMUNICATION DISORDERS | 0,582

JOURNAL OF COMMUNITY & APPLIED SOCIAL PSYCHOLOGY | 0,373

JOURNAL OF COMMUNITY HEALTH | 0,762

JOURNAL OF COMMUNITY PSYCHOLOGY | 0,736

JOURNAL OF COMPARATIVE ECONOMICS | 0,884

JOURNAL OF COMPARATIVE FAMILY STUDIES | 0,169

JOURNAL OF COMPARATIVE PSYCHOLOGY | 1,477

JOURNAL OF COMPUTER ASSISTED LEARNING | 0,212

JOURNAL OF CONFLICT RESOLUTION | 0,870

JOURNAL OF CONSTRUCTIVIST PSYCHOLOGY | 0,545

JOURNAL OF CONSULTING AND CLINICAL PSYCHOLOGY | 4,390

JOURNAL OF CONSUMER AFFAIRS | 0,343

JOURNAL OF CONSUMER RESEARCH | 2,460

JOURNAL OF CONTEMPORARY ASIA | 0,220

JOURNAL OF CONTEMPORARY ETHNOGRAPHY | 0,230

JOURNAL OF COUNSELING AND DEVELOPMENT | 0,650

JOURNAL OF COUNSELING PSYCHOLOGY | 1,564

JOURNAL OF CREATIVE BEHAVIOR | 0,533

JOURNAL OF CRIMINAL JUSTICE | 0,364

JOURNAL OF CRIMINAL LAW & CRIMINOLOGY | 1,150

JOURNAL OF CROSS-CULTURAL PSYCHOLOGY | 1,218

JOURNAL OF CURRICULUM STUDIES | 0,438

JOURNAL OF DEMOCRACY | 0,881

JOURNAL OF DEVELOPING AREAS | 0,182

JOURNAL OF DEVELOPMENT ECONOMICS | 0,598

JOURNAL OF DEVELOPMENT STUDIES | 0,506

JOURNAL OF DEVELOPMENTAL AND BEHAVIORAL PEDIATRICS | 1,041

JOURNAL OF DEVELOPMENTAL AND PHYSICAL DISABILITIES | 0,100

JOURNAL OF DOCUMENTATION | 1,640

JOURNAL OF DRUG EDUCATION | 0,511

JOURNAL OF DRUG ISSUES | 0,510

JOURNAL OF EARLY ADOLESCENCE | 0,395

JOURNAL OF EARLY INTERVENTION | 0,918

JOURNAL OF ECONOMETRICS | 0,977

JOURNAL OF ECONOMIC BEHAVIOR & ORGANIZATION | 0,567

JOURNAL OF ECONOMIC DYNAMICS & CONTROL | 0,496

JOURNAL OF ECONOMIC EDUCATION | 0,266

JOURNAL OF ECONOMIC HISTORY | 0,654

JOURNAL OF ECONOMIC ISSUES | 0,451

JOURNAL OF ECONOMIC LITERATURE | 6,676

JOURNAL OF ECONOMIC PERSPECTIVES | 2,336

JOURNAL OF ECONOMIC PSYCHOLOGY | 0,246

JOURNAL OF ECONOMIC THEORY | 0,622

JOURNAL OF ECONOMICS & MANAGEMENT STRATEGY | 0,378

JOURNAL OF ECONOMICS-ZEITSCHRIFT FUR NATIONALOKONOMIE | 0,155

JOURNAL OF ECT | 1,817

JOURNAL OF EDUCATIONAL AND BEHAVIORAL STATISTICS | 1,088

JOURNAL OF EDUCATIONAL AND PSYCHOLOGICAL CONSULTATION | 0,595

JOURNAL OF EDUCATIONAL COMPUTING RESEARCH | 0,086

JOURNAL OF EDUCATIONAL MEASUREMENT | 0,353

JOURNAL OF EDUCATIONAL PSYCHOLOGY | 1,844

JOURNAL OF EDUCATIONAL RESEARCH | 0,351

JOURNAL OF ELDER ABUSE & NEGLECT | 0,160

JOURNAL OF EMOTIONAL AND BEHAVIORAL DISORDERS | 1,022

JOURNAL OF EMPLOYMENT COUNSELING | 0,500

JOURNAL OF ENVIRONMENTAL ECONOMICS AND MANAGEMENT | 1,118

JOURNAL OF ENVIRONMENTAL PSYCHOLOGY | 0,689

JOURNAL OF EUROPEAN PUBLIC POLICY | 1,680

JOURNAL OF EUROPEAN SOCIAL POLICY | 0,649

JOURNAL OF EVOLUTIONARY ECONOMICS | 0,368

JOURNAL OF EXPERIMENTAL CHILD PSYCHOLOGY | 1,276

JOURNAL OF EXPERIMENTAL EDUCATION | 0,386

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-ANIMAL BEHAVIOR PROCESSES | 1,365

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-APPLIED | 1,000

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-GENERAL | 3,636

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-HUMAN PERCEPTION AND PERFORMANCE | 2,247

JOURNAL OF EXPERIMENTAL PSYCHOLOGY-LEARNING MEMORY AND COGNITION | 2,753

JOURNAL OF EXPERIMENTAL SOCIAL PSYCHOLOGY | 1,481

JOURNAL OF FAMILY HISTORY | 0,413

JOURNAL OF FAMILY ISSUES | 0,868

JOURNAL OF FAMILY PSYCHOLOGY | 1,058

JOURNAL OF FAMILY THERAPY | 0,551

JOURNAL OF FAMILY VIOLENCE | 0,760

JOURNAL OF FINANCE | 2,753

JOURNAL OF FINANCIAL AND QUANTITATIVE ANALYSIS | 0,596

JOURNAL OF FINANCIAL ECONOMICS | 1,904

JOURNAL OF FINANCIAL INTERMEDIATION | 0,519

JOURNAL OF FINANCIAL SERVICES RESEARCH | 0,240

JOURNAL OF FLUENCY DISORDERS | 0,370

JOURNAL OF FORECASTING | 0,377

JOURNAL OF FORENSIC PSYCHIATRY | 0,726

JOURNAL OF FUTURES MARKETS | 0,337

JOURNAL OF GENDER STUDIES | 0,091

JOURNAL OF GENERAL PSYCHOLOGY | 0,519

JOURNAL OF GENETIC PSYCHOLOGY | 0,476

JOURNAL OF GEOGRAPHY | 0,831

JOURNAL OF GEOGRAPHY IN HIGHER EDUCATION | 1,140

JOURNAL OF GOVERNMENT INFORMATION | 0,328

JOURNAL OF HEAD TRAUMA REHABILITATION | 1,353

JOURNAL OF HEALTH AND SOCIAL BEHAVIOR | 2,490

JOURNAL OF HEALTH CARE FOR THE POOR AND UNDERSERVED | 0,767

JOURNAL OF HEALTH COMMUNICATION | 0,463

JOURNAL OF HEALTH ECONOMICS | 1,923

JOURNAL OF HEALTH POLITICS POLICY AND LAW | 0,941

JOURNAL OF HEALTHCARE MANAGEMENT | 0,648

JOURNAL OF HIGHER EDUCATION | 0,562

JOURNAL OF HISTORICAL GEOGRAPHY | 0,795

JOURNAL OF HISTORICAL SOCIOLOGY | 0,303

JOURNAL OF HOMOSEXUALITY | 0,296

JOURNAL OF HOUSING ECONOMICS | 0,242

JOURNAL OF HUMAN EVOLUTION | 2,675

JOURNAL OF HUMAN RESOURCES | 1,235

JOURNAL OF HUMANISTIC PSYCHOLOGY | 0,319

JOURNAL OF INDUSTRIAL ECONOMICS | 1,244

JOURNAL OF INFORMATION ETHICS | 0,148

JOURNAL OF INFORMATION SCIENCE | 0,473

JOURNAL OF INFORMATION TECHNOLOGY | 0,382

JOURNAL OF INSTITUTIONAL AND THEORETICAL ECONOMICS-ZEITSCHRIFT FUR DIE GESA | 0,433

JOURNAL OF INTELLECTUAL DISABILITY RESEARCH | 1,123

JOURNAL OF INTERAMERICAN STUDIES AND WORLD AFFAIRS | 0,121

JOURNAL OF INTERDISCIPLINARY HISTORY | 0,415

JOURNAL OF INTERNATIONAL BUSINESS STUDIES | 1,012

JOURNAL OF INTERNATIONAL ECONOMICS | 1,280

JOURNAL OF INTERNATIONAL MARKETING | 0,850

JOURNAL OF INTERNATIONAL MONEY AND FINANCE | 0,394

JOURNAL OF INTERPERSONAL VIOLENCE | 1,062

JOURNAL OF JAPANESE STUDIES | 0,375

JOURNAL OF LABOR ECONOMICS | 1,273

JOURNAL OF LABOR RESEARCH | 0,219

JOURNAL OF LANGUAGE AND SOCIAL PSYCHOLOGY | 0,525

JOURNAL OF LATIN AMERICAN STUDIES | 0,447

JOURNAL OF LAW & ECONOMICS | 1,050

JOURNAL OF LAW AND SOCIETY | 0,691

JOURNAL OF LAW ECONOMICS & ORGANIZATION | 1,383

JOURNAL OF LAW MEDICINE & ETHICS | 0,810

JOURNAL OF LEARNING DISABILITIES | 1,000

JOURNAL OF LEGAL EDUCATION | 0,646

JOURNAL OF LEGAL MEDICINE | 0,733

JOURNAL OF LEGAL STUDIES | 4,468

JOURNAL OF LEISURE RESEARCH | 1,304

JOURNAL OF LIBRARIANSHIP AND INFORMATION SCIENCE | 0,263

JOURNAL OF LINGUISTICS | 0,571

JOURNAL OF LITERACY RESEARCH | 0,909

JOURNAL OF MACROECONOMICS | 0,241

JOURNAL OF MANAGEMENT | 1,235

JOURNAL OF MANAGEMENT INQUIRY | 0,649

JOURNAL OF MANAGEMENT STUDIES | 0,646

JOURNAL OF MARITAL AND FAMILY THERAPY | 1,106

JOURNAL OF MARITIME LAW AND COMMERCE | 0,712

JOURNAL OF MARKETING | 2,039

JOURNAL OF MARKETING RESEARCH | 1,679

JOURNAL OF MARRIAGE AND THE FAMILY | 2,135

JOURNAL OF MATERIAL CULTURE | 0,375

JOURNAL OF MATHEMATICAL ECONOMICS | 0,314

JOURNAL OF MATHEMATICAL PSYCHOLOGY | 1,056

JOURNAL OF MATHEMATICAL SOCIOLOGY | 0,500

JOURNAL OF MEDIA ECONOMICS | 0,259

JOURNAL OF MEDICAL ETHICS | 0,955

JOURNAL OF MEDICINE AND PHILOSOPHY | 0,479

JOURNAL OF MEMORY AND LANGUAGE | 2,638

JOURNAL OF MIDWIFERY & WOMENS HEALTH |

JOURNAL OF MIND AND BEHAVIOR | 0,316

JOURNAL OF MODERN AFRICAN STUDIES | 0,688

JOURNAL OF MODERN HISTORY | 0,656

JOURNAL OF MONETARY ECONOMICS | 0,970

JOURNAL OF MONEY CREDIT AND BANKING | 0,915

JOURNAL OF MORAL EDUCATION | 0,182

JOURNAL OF MOTOR BEHAVIOR | 1,141

JOURNAL OF MULTICULTURAL COUNSELING AND DEVELOPMENT | 0,395

JOURNAL OF MUSIC THERAPY | 0,152

JOURNAL OF NEGRO EDUCATION | 0,045

JOURNAL OF NERVOUS AND MENTAL DISEASE | 1,626

JOURNAL OF NEUROLINGUISTICS | 0,514

JOURNAL OF NONVERBAL BEHAVIOR | 0,704

JOURNAL OF NURSE-MIDWIFERY | 0,569

JOURNAL OF NURSING ADMINISTRATION | 0,555

JOURNAL OF NURSING CARE QUALITY | 0,272

JOURNAL OF NURSING EDUCATION | 0,420

JOURNAL OF OCCUPATIONAL AND ORGANIZATIONAL PSYCHOLOGY | 0,466

JOURNAL OF OCCUPATIONAL REHABILITATION | 0,683

JOURNAL OF ORGANIZATIONAL BEHAVIOR | 0,808

JOURNAL OF ORGANIZATIONAL BEHAVIOR MANAGEMENT | 0,206

JOURNAL OF ORGANIZATIONAL CHANGE MANAGEMENT | 0,250

JOURNAL OF PALESTINE STUDIES | 0,149

JOURNAL OF PALLIATIVE CARE | 1,153

JOURNAL OF PARAPSYCHOLOGY | 0,654

JOURNAL OF PEACE RESEARCH | 1,027

JOURNAL OF PEASANT STUDIES | 0,647

JOURNAL OF PEDIATRIC PSYCHOLOGY | 1,541

JOURNAL OF PERINATAL & NEONATAL NURSING | 0,236

JOURNAL OF PERSONAL & INTERPERSONAL LOSS | 0,533

JOURNAL OF PERSONALITY | 1,488

JOURNAL OF PERSONALITY AND SOCIAL PSYCHOLOGY | 3,172

JOURNAL OF PERSONALITY ASSESSMENT | 0,734

JOURNAL OF PERSONALITY DISORDERS | 1,333

JOURNAL OF PHILOSOPHY OF EDUCATION | 0,463

JOURNAL OF PHONETICS | 0,667

JOURNAL OF PLANNING EDUCATION AND RESEARCH | 0,740

JOURNAL OF POLICY ANALYSIS AND MANAGEMENT | 0,897

JOURNAL OF POLICY MODELING | 0,145

JOURNAL OF POLITICAL & MILITARY SOCIOLOGY | 0,161

JOURNAL OF POLITICAL ECONOMY | 2,320

JOURNAL OF POLITICAL PHILOSOPHY | 0,622

JOURNAL OF POLITICS | 0,736

JOURNAL OF POPULATION ECONOMICS | 0,390

JOURNAL OF PORTFOLIO MANAGEMENT | 0,253

JOURNAL OF POST KEYNESIAN ECONOMICS | 0,500

JOURNAL OF PRAGMATICS | 0,405

JOURNAL OF PRODUCT INNOVATION MANAGEMENT | 1,000

JOURNAL OF PRODUCTIVITY ANALYSIS | 0,559

JOURNAL OF PROFESSIONAL NURSING | 0,437

JOURNAL OF PSYCHIATRIC RESEARCH | 2,330

JOURNAL OF PSYCHIATRY & NEUROSCIENCE | 2,039

JOURNAL OF PSYCHOACTIVE DRUGS | 0,548

JOURNAL OF PSYCHOEDUCATIONAL ASSESSMENT | 0,543

JOURNAL OF PSYCHOHISTORY | 0,364

JOURNAL OF PSYCHOLINGUISTIC RESEARCH | 0,725

JOURNAL OF PSYCHOLOGY | 0,393

JOURNAL OF PSYCHOLOGY AND THEOLOGY | 0,268

JOURNAL OF PSYCHOPATHOLOGY AND BEHAVIORAL ASSESSMENT | 0,667

JOURNAL OF PSYCHOPHYSIOLOGY | 0,685

JOURNAL OF PSYCHOSOCIAL ONCOLOGY | 0,364

JOURNAL OF PSYCHOSOMATIC OBSTETRICS AND GYNECOLOGY | 0,529

JOURNAL OF PSYCHOSOMATIC RESEARCH | 1,446

JOURNAL OF PUBLIC ECONOMICS | 0,847

JOURNAL OF PUBLIC HEALTH MEDICINE | 1,015

JOURNAL OF PUBLIC HEALTH POLICY | 0,674

JOURNAL OF PUBLIC POLICY & MARKETING | 0,661

JOURNAL OF QUANTITATIVE CRIMINOLOGY | 0,763

JOURNAL OF REAL ESTATE FINANCE AND ECONOMICS | 0,676

JOURNAL OF REAL ESTATE TAXATION | 0,056

JOURNAL OF REGIONAL SCIENCE | 0,651

JOURNAL OF REGULATORY ECONOMICS | 0,361

JOURNAL OF REHABILITATION | 0,153

JOURNAL OF REHABILITATION RESEARCH AND DEVELOPMENT | 0,569

JOURNAL OF RELIGION & HEALTH | 0,104

JOURNAL OF RESEARCH IN CRIME AND DELINQUENCY | 1,657

JOURNAL OF RESEARCH IN PERSONALITY | 1,000

JOURNAL OF RESEARCH IN SCIENCE TEACHING | 0,992

JOURNAL OF RESEARCH ON ADOLESCENCE | 1,500

JOURNAL OF RETAILING | 0,600

JOURNAL OF RISK AND INSURANCE | 0,554

JOURNAL OF RISK AND UNCERTAINTY | 0,878

JOURNAL OF RURAL HEALTH | 0,672

JOURNAL OF RURAL STUDIES | 1,559

JOURNAL OF SAFETY RESEARCH | 0,468

JOURNAL OF SCHOLARLY PUBLISHING | 0,086

JOURNAL OF SCHOOL HEALTH | 0,789

JOURNAL OF SCHOOL PSYCHOLOGY | 0,911

JOURNAL OF SEX & MARITAL THERAPY | 1,017

JOURNAL OF SEX RESEARCH | 1,308

JOURNAL OF SMALL BUSINESS MANAGEMENT | 0,167

JOURNAL OF SOCIAL AND CLINICAL PSYCHOLOGY | 0,882

JOURNAL OF SOCIAL AND PERSONAL RELATIONSHIPS | 0,559

JOURNAL OF SOCIAL BEHAVIOR AND PERSONALITY | 0,168

JOURNAL OF SOCIAL DISTRESS AND THE HOMELESS | 0,059

JOURNAL OF SOCIAL HISTORY | 0,327

JOURNAL OF SOCIAL ISSUES | 1,167

JOURNAL OF SOCIAL POLICY | 1,326

JOURNAL OF SOCIAL PSYCHOLOGY | 0,286

JOURNAL OF SOCIAL SERVICE RESEARCH | 0,386

JOURNAL OF SOCIAL WORK EDUCATION | 1,046

JOURNAL OF SOCIAL WORK PRACTICE | 0,154

JOURNAL OF SOCIOLOGY | 0,235

JOURNAL OF SOCIOLOGY AND SOCIAL WELFARE | 0,139

JOURNAL OF SOUTHEAST ASIAN STUDIES | 0,000

JOURNAL OF SOUTHERN AFRICAN STUDIES | 0,468

JOURNAL OF SPECIAL EDUCATION | 0,617

JOURNAL OF SPEECH LANGUAGE AND HEARING RESEARCH | 1,590

JOURNAL OF SPORT & EXERCISE PSYCHOLOGY | 1,475

JOURNAL OF SPORT HISTORY | 0,071

JOURNAL OF STRATEGIC STUDIES | 0,209

JOURNAL OF STUDIES ON ALCOHOL | 2,005

JOURNAL OF SUBSTANCE ABUSE | 0,800

JOURNAL OF SUBSTANCE ABUSE TREATMENT | 0,914

JOURNAL OF TAXATION | 0,161

JOURNAL OF TEACHER EDUCATION | 0,394

JOURNAL OF TEACHING IN PHYSICAL EDUCATION | 0,412

JOURNAL OF THE ACADEMY OF MARKETING SCIENCE | 0,980

JOURNAL OF THE AMERICAN ACADEMY OF CHILD AND ADOLESCENT PSYCHIATRY | 3,175

JOURNAL OF THE AMERICAN ACADEMY OF PSYCHIATRY AND THE LAW | 0,686

JOURNAL OF THE AMERICAN GERIATRICS SOCIETY | 3,136

JOURNAL OF THE AMERICAN MEDICAL INFORMATICS ASSOCIATION | 3,089

JOURNAL OF THE AMERICAN PLANNING ASSOCIATION | 1,120

JOURNAL OF THE AMERICAN PSYCHOANALYTIC ASSOCIATION | 1,090

JOURNAL OF THE AMERICAN SOCIETY FOR INFORMATION SCIENCE | 1,226

JOURNAL OF THE AMERICAN SOCIETY FOR PSYCHICAL RESEARCH | 0,167

JOURNAL OF THE ASSOCIATION FOR PERSONS WITH SEVERE HANDICAPS | 1,816

JOURNAL OF THE COPYRIGHT SOCIETY OF THE USA | 0,947

JOURNAL OF THE EXPERIMENTAL ANALYSIS OF BEHAVIOR | 1,172

JOURNAL OF THE HISTORY OF BIOLOGY | 0,500

JOURNAL OF THE HISTORY OF IDEAS | 0,275

JOURNAL OF THE HISTORY OF MEDICINE AND ALLIED SCIENCES | 0,250

JOURNAL OF THE HISTORY OF SEXUALITY | 1,000

JOURNAL OF THE HISTORY OF THE BEHAVIORAL SCIENCES | 0,240

JOURNAL OF THE JAPANESE AND INTERNATIONAL ECONOMIES | 0,368

JOURNAL OF THE LEARNING SCIENCES | 1,286

JOURNAL OF THE MARKET RESEARCH SOCIETY | 0,389

JOURNAL OF THE OPERATIONAL RESEARCH SOCIETY | 0,648

JOURNAL OF THE PHILOSOPHY OF SPORT | 1,250

JOURNAL OF THE POLYNESIAN SOCIETY | 0,452

JOURNAL OF THE ROYAL ANTHROPOLOGICAL INSTITUTE | 0,623

JOURNAL OF THE ROYAL SOCIETY FOR THE PROMOTION OF HEALTH | 0,098

JOURNAL OF THE ROYAL SOCIETY OF HEALTH | 0,259

JOURNAL OF THE ROYAL STATISTICAL SOCIETY SERIES A-STATISTICS IN SOCIETY | 1,277

JOURNAL OF THEORETICAL POLITICS | 0,413

JOURNAL OF TRANSPORT ECONOMICS AND POLICY | 0,326

JOURNAL OF TRAUMATIC STRESS | 1,836

JOURNAL OF URBAN AFFAIRS | 0,762

JOURNAL OF URBAN ECONOMICS | 1,011

JOURNAL OF URBAN HISTORY | 0,239

JOURNAL OF URBAN PLANNING AND DEVELOPMENT-ASCE | 0,091

JOURNAL OF URBAN TECHNOLOGY | 0,258

JOURNAL OF VISUAL IMPAIRMENT & BLINDNESS | 0,181

JOURNAL OF VOCATIONAL BEHAVIOR | 1,356

JOURNAL OF WOMEN & AGING | 0,295

JOURNAL OF WOMENS HEALTH | 1,395

JOURNAL OF WOMENS HEALTH & GENDER-BASED MEDICINE | 0,395

JOURNAL OF WORLD BUSINESS | 0,571

JOURNAL OF WORLD TRADE | 0,539

JOURNAL OF YOUTH AND ADOLESCENCE | 0,723

JOURNALISM & MASS COMMUNICATION QUARTERLY | 0,435

JOURNALS OF GERONTOLOGY SERIES A-BIOLOGICAL SCIENCES AND MEDICAL SCIENCES | 1,549

JOURNALS OF GERONTOLOGY SERIES B-PSYCHOLOGICAL SCIENCES AND SOCIAL SCIENCES | 1,102

JUDICATURE | 0,431

JUSTICE SYSTEM JOURNAL | 0,238

JUVENILE AND FAMILY COURT JOURNAL | 0,279

KENNEDY INSTITUTE OF ETHICS JOURNAL | 0,955

KNOWLEDGE ORGANIZATION | 0,778

KOLNER ZEITSCHRIFT FUR SOZIOLOGIE UND SOZIALPSYCHOLOGIE | 0,797

KOREAN JOURNAL OF DEFENSE ANALYSIS | 0,333

KRIMINALISTIK | 0,137

KYKLOS | 0,306

LABOR HISTORY | 0,204

LAND ECONOMICS | 0,987

LAND USE POLICY | 0,429

LANDSCAPE AND URBAN PLANNING | 0,637

LANGUAGE | 3,371

LANGUAGE & COMMUNICATION | 0,583

LANGUAGE AND COGNITIVE PROCESSES | 0,875

LANGUAGE AND SPEECH | 0,639

LANGUAGE IN SOCIETY | 0,667

LANGUAGE LEARNING | 0,340

LANGUAGE SPEECH AND HEARING SERVICES IN SCHOOLS | 0,585

LATIN AMERICAN PERSPECTIVES | 0,209

LATIN AMERICAN RESEARCH REVIEW | 0,574

LAW & SOCIETY REVIEW | 1,778

LAW AND HUMAN BEHAVIOR | 1,861

LAW AND PHILOSOPHY | 0,333

LAW AND SOCIAL INQUIRY-JOURNAL OF THE AMERICAN BAR FOUNDATION | 1,154

LAW LIBRARY JOURNAL | 0,105

LEADERSHIP QUARTERLY | 0,830

LEARNED PUBLISHING | 0,305

LEARNING AND INDIVIDUAL DIFFERENCES | 0,459

LEARNING AND INSTRUCTION | 0,536

LEARNING AND MOTIVATION | 1,156

LEARNING DISABILITY QUARTERLY | 1,091

LEGISLATIVE STUDIES QUARTERLY | 0,468

LEISURE SCIENCES | 1,000

LIBRARY & INFORMATION SCIENCE RESEARCH | 0,297

LIBRARY ACQUISITIONS-PRACTICE AND THEORY | 0,065

LIBRARY AND INFORMATION SCIENCE | 1,167

LIBRARY COLLECTIONS ACQUISITIONS & TECHNICAL SERVICES | 0,071

LIBRARY JOURNAL | 0,265

LIBRARY QUARTERLY | 0,407

LIBRARY RESOURCES & TECHNICAL SERVICES | 0,361

LIBRARY TRENDS | 0,316

LIBRI | 0,188

LINGUA | 0,686

LINGUISTIC INQUIRY | 1,477

LINGUISTICS | 0,353

LOCAL GOVERNMENT STUDIES | 0,490

LOISIR & SOCIETE-SOCIETY AND LEISURE | 0,065

LONG RANGE PLANNING | 0,207

LOUISIANA LAW REVIEW | 0,319

MACROECONOMIC DYNAMICS | 0,591

MAN IN INDIA | 0,024

MANAGEMENT LEARNING | 1,186

MANAGEMENT SCIENCE | 1,011

MANCHESTER SCHOOL | 0,181

MANKIND QUARTERLY | 0,121

MARINE POLICY | 0,603

MARKETING SCIENCE | 1,364

MARRIAGE AND FAMILY REVIEW | 0,217

MATHEMATICAL FINANCE | 0,889

MATHEMATICAL SOCIAL SCIENCES | 0,307

MEASUREMENT AND EVALUATION IN COUNSELING AND DEVELOPMENT | 0,571

MEDIA CULTURE & SOCIETY | 0,387

MEDIA STUDIES JOURNAL | 0,036

MEDICAL ANTHROPOLOGY QUARTERLY | 0,605

MEDICAL CARE | 2,535

MEDICAL CARE RESEARCH AND REVIEW | 1,740

MEDICAL HISTORY | 0,286

MEDICINE SCIENCE AND THE LAW | 0,472

MEMORY | 1,522

MEMORY & COGNITION | 1,507

MENTAL RETARDATION | 0,965

MERRILL-PALMER QUARTERLY-JOURNAL OF DEVELOPMENTAL PSYCHOLOGY | 0,750

MICHIGAN LAW REVIEW | 4,646

MIDDLE EAST JOURNAL | 0,725

MIDDLE EAST POLICY | 0,349

MIDDLE EASTERN STUDIES | 0,145

MIDWIFERY | 0,849

MILBANK QUARTERLY | 4,568

MILITARY LAW REVIEW | 0,303

MILITARY PSYCHOLOGY | 0,297

MILLENNIUM-JOURNAL OF INTERNATIONAL STUDIES | 0,929

MIND & LANGUAGE | 0,385

MINERVA | 0,414

MINNESOTA LAW REVIEW | 2,217

MINNESOTA SYMPOSIA ON CHILD PSYCHOLOGY | 0,950

MIS QUARTERLY | 2,064

MITTEILUNGEN DER OSTERREICHISCHEN GEOGRAPHISCHEN GESELLSCHAFT | 0,083

MODERN ASIAN STUDIES | 0,224

MODERN CHINA | 0,606

MODERN LANGUAGE JOURNAL | 0,918

MONOGRAPHS OF THE SOCIETY FOR RESEARCH IN CHILD DEVELOPMENT | 3,000

MONTHLY LABOR REVIEW | 0,949

MONTHLY REVIEW-AN INDEPENDENT SOCIALIST MAGAZINE | 0,275

MOTIVATION AND EMOTION | 1,133

MOUVEMENT SOCIAL | 0,020

MULTIVARIATE BEHAVIORAL RESEARCH | 0,641

MUSIC PERCEPTION | 1,065

NARRATIVE INQUIRY | 0,364

NATION | 0,379

NATIONAL TAX JOURNAL | 0,720

NATURAL LANGUAGE & LINGUISTIC THEORY | 0,842

NATURAL RESOURCES JOURNAL | 0,537

NBER MACROECONOMICS ANNUAL | 2,000

NEGOTIATION JOURNAL-ON THE PROCESS OF DISPUTE SETTLEMENT | 0,317

NETHERLANDS JOURNAL OF SOCIAL SCIENCES | 0,048

NEUROBIOLOGY OF LEARNING AND MEMORY | 3,040

NEUROPSYCHOLOGIA | 2,778

NEUROPSYCHOLOGY | 2,702

NEUROPSYCHOLOGY REVIEW | 1,250

NEUROREHABILITATION | 0,442

NEW ENGLAND ECONOMIC REVIEW | 0,395

NEW IDEAS IN PSYCHOLOGY | 0,219

NEW LEFT REVIEW | 1,716

NEW REPUBLIC | 0,211

NEW TECHNOLOGY WORK AND EMPLOYMENT | 0,524

NEW YORK UNIVERSITY LAW REVIEW | 3,386

NEW ZEALAND JOURNAL OF EDUCATIONAL STUDIES | 0,244

NEW ZEALAND JOURNAL OF PSYCHOLOGY | 0,172

NFD INFORMATION-WISSENSCHAFT UND PRAXIS | 0,029

NONPROFIT AND VOLUNTARY SECTOR QUARTERLY | 0,500

NORDIC JOURNAL OF PSYCHIATRY | 0,360

NORDISK PSYKOLOGI | 0,077

NORTHWESTERN UNIVERSITY LAW REVIEW | 3,278

NOTRE DAME LAW REVIEW | 1,261

NOUVELLES QUESTIONS FEMINISTES | 0,000

NURSE EDUCATION TODAY | 0,716

NURSE PRACTITIONER FORUM-CURRENT TOPICS AND COMMUNICATIONS | 0,123

NURSING AND HEALTH CARE PERSPECTIVES | 0,150

NURSING CLINICS OF NORTH AMERICA | 0,387

NURSING CONNECTIONS | 0,143

NURSING ECONOMICS | 0,294

NURSING ETHICS | 0,359

NURSING HISTORY REVIEW | 0,438

NURSING OUTLOOK | 0,825

NURSING RESEARCH | 1,080

NURSING SCIENCE QUARTERLY | 1,278

OCCUPATIONAL THERAPY JOURNAL OF RESEARCH | 0,679

OCEAN DEVELOPMENT AND INTERNATIONAL LAW | 0,458

OCEANIA | 0,333

OMEGA-INTERNATIONAL JOURNAL OF MANAGEMENT SCIENCE | 0,453

OMEGA-JOURNAL OF DEATH AND DYING | 0,322

ONLINE | 0,456

ONLINE & CDROM REVIEW | 0,206

ONLINE INFORMATION REVIEW |

ONLINE JOURNAL OF KNOWLEDGE SYNTHESIS FOR NURSING | 0,000

OPEN ECONOMIES REVIEW | 0,240

ORGANIZATION | 0,963

ORGANIZATION SCIENCE | 1,052

ORGANIZATION STUDIES | 0,818

ORGANIZATIONAL BEHAVIOR AND HUMAN DECISION PROCESSES | 1,200

ORGANIZATIONAL DYNAMICS | 0,800

OSIRIS | 0,065

OSTEUROPA | 0,274

OXFORD BULLETIN OF ECONOMICS AND STATISTICS | 0,386

OXFORD ECONOMIC PAPERS-NEW SERIES | 0,824

OXFORD REVIEW OF ECONOMIC POLICY | 0,723

OXFORD REVIEW OF EDUCATION | 0,703

PACIFIC AFFAIRS | 0,161

PACIFIC REVIEW | 0,620

PAPERS IN REGIONAL SCIENCE | 0,182

PARLIAMENTARY AFFAIRS | 0,373

PARTY POLITICS | 0,353

PAST & PRESENT | 0,540

PATIENT EDUCATION AND COUNSELING | 0,875

PATTERNS OF PREJUDICE | 0,308

PENSEE | 0,044

PERCEPTION | 1,193

PERCEPTION & PSYCHOPHYSICS | 1,252

PERCEPTUAL AND MOTOR SKILLS | 0,308

PERSONAL RELATIONSHIPS | 1,017

PERSONALITY AND INDIVIDUAL DIFFERENCES | 0,920

PERSONALITY AND SOCIAL PSYCHOLOGY BULLETIN | 1,205

PERSONNEL PSYCHOLOGY | 1,733

PERSONNEL REVIEW | 0,192

PERSPECTIVES IN PSYCHIATRIC CARE | 0,545

PHI DELTA KAPPAN | 0,519

PHILOSOPHICAL PSYCHOLOGY | 0,471

PHILOSOPHY & PUBLIC AFFAIRS | 1,120

PHILOSOPHY OF SCIENCE | 0,663

PHILOSOPHY OF THE SOCIAL SCIENCES | 0,200

PHONETICA | 0,450

PHYSIOLOGY & BEHAVIOR | 1,419

PLAINS ANTHROPOLOGIST | 0,273

POLICY AND POLITICS | 0,519

POLICY REVIEW | 0,192

POLICY SCIENCES | 0,146

POLICY STUDIES JOURNAL | 0,360

POLITICAL BEHAVIOR | 0,750

POLITICAL COMMUNICATION | 0,729

POLITICAL GEOGRAPHY | 1,226

POLITICAL PSYCHOLOGY | 0,862

POLITICAL QUARTERLY | 0,675

POLITICAL RESEARCH QUARTERLY | 0,397

POLITICAL SCIENCE | 0,036

POLITICAL SCIENCE QUARTERLY | 0,564

POLITICAL STUDIES | 0,494

POLITICAL THEORY | 0,339

POLITICKA EKONOMIE | 0,154

POLITICS & SOCIETY | 1,378

POLITICS AND THE LIFE SCIENCES | 0,095

POLITISCHE VIERTELJAHRESSCHRIFT | 0,400

POLITY | 0,185

POPULATION | 0,370

POPULATION AND DEVELOPMENT REVIEW | 0,756

POPULATION AND ENVIRONMENT | 0,204

POPULATION BULLETIN | 2,857

POPULATION RESEARCH AND POLICY REVIEW | 0,238

POPULATION STUDIES-A JOURNAL OF DEMOGRAPHY | 0,696

POST-COMMUNIST ECONOMIES | 0,038

POST-SOVIET AFFAIRS | 1,161

POST-SOVIET GEOGRAPHY AND ECONOMICS | 0,362

PRAXIS DER KINDERPSYCHOLOGIE UND KINDERPSYCHIATRIE | 0,360

PROFESSIONAL GEOGRAPHER | 1,133

PROFESSIONAL PSYCHOLOGY-RESEARCH AND PRACTICE | 1,240

PROGRAM-ELECTRONIC LIBRARY AND INFORMATION SYSTEMS | 0,364

PROGRESS IN HUMAN GEOGRAPHY | 2,386

PROGRESS IN PLANNING | 0,379

PSICOTHEMA | 0,473

PSIKHOLOGICHESKII ZHURNAL | 0,121

PS-POLITICAL SCIENCE & POLITICS | 0,374

PSYCHE-ZEITSCHRIFT FUR PSYCHOANALYSE UND IHRE ANWENDUNGEN | 0,324

PSYCHIATRIC ANNALS | 1,080

PSYCHIATRIC CLINICS OF NORTH AMERICA | 1,709

PSYCHIATRIC QUARTERLY | 0,889

PSYCHIATRIC REHABILITATION JOURNAL | 0,455

PSYCHIATRIC SERVICES | 1,795

PSYCHIATRIE DE L ENFANT | 0,024

PSYCHIATRISCHE PRAXIS | 0,893

PSYCHIATRY RESEARCH | 1,557

PSYCHIATRY-INTERPERSONAL AND BIOLOGICAL PROCESSES | 0,827

PSYCHOANALYTIC INQUIRY | 0,272

PSYCHOANALYTIC PSYCHOLOGY | 0,583

PSYCHOANALYTIC QUARTERLY | 0,800

PSYCHOANALYTIC STUDY OF THE CHILD | 0,206

PSYCHOBIOLOGY | 1,194

PSYCHOLOGIA | 0,093

PSYCHOLOGICA BELGICA | 0,417

PSYCHOLOGICAL ASSESSMENT | 1,670

PSYCHOLOGICAL BULLETIN | 6,913

PSYCHOLOGICAL INQUIRY | 2,414

PSYCHOLOGICAL MEDICINE | 3,412

PSYCHOLOGICAL METHODS | 2,190

PSYCHOLOGICAL RECORD | 0,684

PSYCHOLOGICAL REPORTS | 0,238

PSYCHOLOGICAL RESEARCH-PSYCHOLOGISCHE FORSCHUNG | 1,360

PSYCHOLOGICAL REVIEW | 6,069

PSYCHOLOGICAL SCIENCE | 2,565

PSYCHOLOGIE IN ERZIEHUNG UND UNTERRICHT | 0,341

PSYCHOLOGISCHE RUNDSCHAU | 0,676

PSYCHOLOGIST | 0,264

PSYCHOLOGY | 0,159

PSYCHOLOGY & HEALTH | 0,909

PSYCHOLOGY & MARKETING | 0,363

PSYCHOLOGY AND AGING | 2,308

PSYCHOLOGY CRIME & LAW | 0,389

PSYCHOLOGY IN THE SCHOOLS | 0,309

PSYCHOLOGY OF ADDICTIVE BEHAVIORS | 1,088

PSYCHOLOGY OF WOMEN QUARTERLY | 0,894

PSYCHOLOGY PUBLIC POLICY AND LAW | 2,407

PSYCHOMETRIKA | 0,898

PSYCHONOMIC BULLETIN & REVIEW | 1,580

PSYCHO-ONCOLOGY | 1,670

PSYCHOPATHOLOGY | 0,547

PSYCHOPHARMACOLOGY BULLETIN | 2,809

PSYCHOPHYSIOLOGY | 3,106

PSYCHOSOMATIC MEDICINE | 3,246

PSYCHOSOMATICS | 1,555

PSYCHOTHERAPEUT | 0,485

PSYCHOTHERAPIE PSYCHOSOMATIK MEDIZINISCHE PSYCHOLOGIE | 0,346

PSYCHOTHERAPY | 0,311

PSYCHOTHERAPY AND PSYCHOSOMATICS | 2,372

PSYCHOTHERAPY RESEARCH | 1,439

PUBLIC ADMINISTRATION | 0,872

PUBLIC ADMINISTRATION AND DEVELOPMENT | 0,456

PUBLIC ADMINISTRATION REVIEW | 1,172

PUBLIC CHOICE | 0,318

PUBLIC CULTURE | 0,412

PUBLIC FINANCE REVIEW | 0,063

PUBLIC HEALTH | 0,600

PUBLIC HEALTH NURSING | 0,528

PUBLIC HEALTH REPORTS | 1,517

PUBLIC INTEREST | 0,464

PUBLIC MONEY & MANAGEMENT | 0,643

PUBLIC OPINION QUARTERLY | 0,863

PUBLIC PERSONNEL MANAGEMENT | 0,218

PUBLIC RELATIONS REVIEW | 0,500

PUBLIC UNDERSTANDING OF SCIENCE | 0,943

PUBLISHING RESEARCH QUARTERLY | 0,049

PUBLIUS-THE JOURNAL OF FEDERALISM | 0,587

QUALITATIVE HEALTH RESEARCH | 0,929

QUALITY & QUANTITY | 0,204

QUARTERLY JOURNAL OF ECONOMICS | 4,024

QUARTERLY JOURNAL OF EXPERIMENTAL PSYCHOLOGY SECTION A-HUMAN EXPERIMENTAL P | 1,452

QUARTERLY JOURNAL OF EXPERIMENTAL PSYCHOLOGY SECTION B-COMPARATIVE AND PHYS | 1,000

QUARTERLY JOURNAL OF SPEECH | 0,366

QUEST | 0,483

R & D MANAGEMENT | 0,737

RACE & CLASS | 0,319

RADICAL PHILOSOPHY | 0,474

RAND JOURNAL OF ECONOMICS | 1,107

RATIONALITY AND SOCIETY | 1,000

READING AND WRITING | 0,122

READING RESEARCH AND INSTRUCTION | 0,174

READING RESEARCH QUARTERLY | 2,486

READING TEACHER | 0,490

REAL ESTATE ECONOMICS | 0,764

REFERENCE & USER SERVICES QUARTERLY | 0,185

REGIONAL SCIENCE AND URBAN ECONOMICS | 0,464

REGIONAL STUDIES | 1,028

REHABILITATION COUNSELING BULLETIN | 0,382

REHABILITATION PSYCHOLOGY | 1,488

RELATIONS INDUSTRIELLES-INDUSTRIAL RELATIONS | 0,382

REMEDIAL AND SPECIAL EDUCATION | 0,603

RESEARCH IN DEVELOPMENTAL DISABILITIES | 0,470

RESEARCH IN HIGHER EDUCATION | 0,338

RESEARCH IN NURSING & HEALTH | 0,789

RESEARCH IN ORGANIZATIONAL BEHAVIOR | 2,562

RESEARCH IN THE TEACHING OF ENGLISH | 1,080

RESEARCH ON AGING | 0,785

RESEARCH ON LANGUAGE AND SOCIAL INTERACTION | 0,522

RESEARCH ON SOCIAL WORK PRACTICE | 0,239

RESEARCH POLICY | 1,078

RESEARCH QUARTERLY FOR EXERCISE AND SPORT | 0,979

RESEARCH-TECHNOLOGY MANAGEMENT | 0,299

RESOURCE AND ENERGY ECONOMICS | 0,472

RESOURCES POLICY | 0,220

RESTAURATOR-INTERNATIONAL JOURNAL FOR THE PRESERVATION OF LIBRARY AND ARCHI | 0,759

REVIEW OF BLACK POLITICAL ECONOMY | 0,094

REVIEW OF ECONOMIC STUDIES | 1,468

REVIEW OF ECONOMICS AND STATISTICS | 1,031

REVIEW OF EDUCATIONAL RESEARCH | 2,088

REVIEW OF FINANCIAL STUDIES | 1,343

REVIEW OF HIGHER EDUCATION | 0,837

REVIEW OF INCOME AND WEALTH | 0,220

REVIEW OF INDUSTRIAL ORGANIZATION | 0,241

REVIEW OF INTERNATIONAL POLITICAL ECONOMY | 1,614

REVIEW OF INTERNATIONAL STUDIES | 1,080

REVIEW OF RELIGIOUS RESEARCH | 0,381

REVIEW OF RESEARCH IN EDUCATION | 2,421

REVISTA DE SAUDE PUBLICA | 0,226

REVISTA INTERAMERICANA DE PSICOLOGIA | 0,075

REVISTA LATINOAMERICANA DE PSICOLOGIA | 0,077

REVISTA MEXICANA DE PSICOLOGIA | 0,109

REVUE CANADIENNE D ETUDES DU DEVELOPPEMENT-CANADIAN JOURNAL OF DEVELOPMENT | 0,091

REVUE D ETUDES COMPARATIVES EST-OUEST | 0,115

REVUE FRANCAISE DE SOCIOLOGIE | 0,545

RISK ANALYSIS | 1,389

RURAL SOCIOLOGY | 0,867

RUSSIAN AND EAST EUROPEAN FINANCE AND TRADE | 0,024

RUSSIAN EDUCATION AND SOCIETY | 0,013

RUSSIAN POLITICS AND LAW | 0,014

RUTGERS LAW REVIEW | 0,571

SALUD MENTAL | 0,259

SALUD PUBLICA DE MEXICO | 0,368

SCANDINAVIAN HOUSING & PLANNING RESEARCH | 0,312

SCANDINAVIAN JOURNAL OF CARING SCIENCES | 0,603

SCANDINAVIAN JOURNAL OF ECONOMICS | 0,324

SCANDINAVIAN JOURNAL OF PSYCHOLOGY | 0,330

SCANDINAVIAN JOURNAL OF PUBLIC HEALTH | 0,340

SCANDINAVIAN JOURNAL OF SOCIAL MEDICINE | 1,250

SCANDINAVIAN JOURNAL OF SOCIAL WELFARE | 0,158

SCANDINAVIAN POLITICAL STUDIES | 0,703

SCHIZOPHRENIA BULLETIN | 6,085

SCHIZOPHRENIA RESEARCH | 3,506

SCHOOL EFFECTIVENESS AND SCHOOL IMPROVEMENT | 0,578

SCHOOL PSYCHOLOGY INTERNATIONAL | 0,400

SCHOOL PSYCHOLOGY QUARTERLY | 1,049

SCHOOL PSYCHOLOGY REVIEW | 1,424

SCIENCE & SOCIETY | 0,377

SCIENCE COMMUNICATION | 0,444

SCIENCE EDUCATION | 0,918

SCIENCE IN CONTEXT | 0,186

SCIENCE TECHNOLOGY & HUMAN VALUES | 0,941

SCIENCES SOCIALES ET SANTE | 0,515

SCIENTIST | 0,347

SCIENTOMETRICS | 0,660

SCOTTISH GEOGRAPHICAL JOURNAL | 0,292

SCOTTISH JOURNAL OF POLITICAL ECONOMY | 0,450

SECURITIES REGULATION LAW JOURNAL | 0,000

SECURITY DIALOGUE | 0,391

SECURITY STUDIES | 0,738

SERVICE INDUSTRIES JOURNAL | 0,213

SEX ROLES | 0,415

SEXUALITY AND DISABILITY | 0,109

SIGNS | 0,469

SINGAPORE JOURNAL OF TROPICAL GEOGRAPHY | 0,280

SLOAN MANAGEMENT REVIEW | 1,794

SMALL BUSINESS ECONOMICS | 0,515

SMALL GROUP RESEARCH | 0,532

SMITH COLLEGE STUDIES IN SOCIAL WORK | 0,079

SOCIAL & LEGAL STUDIES | 0,543

SOCIAL BEHAVIOR AND PERSONALITY | 0,227

SOCIAL BIOLOGY | 0,267

SOCIAL CHOICE AND WELFARE | 0,782

SOCIAL COGNITION | 1,415

SOCIAL COMPASS | 0,185

SOCIAL DEVELOPMENT | 0,886

SOCIAL FORCES | 1,215

SOCIAL HISTORY OF MEDICINE | 0,862

SOCIAL INDICATORS RESEARCH | 0,435

SOCIAL NETWORKS | 0,590

SOCIAL PHILOSOPHY & POLICY | 0,360

SOCIAL POLICY & ADMINISTRATION | 0,667

SOCIAL POLITICS | 0,486

SOCIAL PROBLEMS | 1,085

SOCIAL PSYCHIATRY AND PSYCHIATRIC EPIDEMIOLOGY | 1,622

SOCIAL PSYCHOLOGY QUARTERLY | 1,277

SOCIAL RESEARCH | 0,292

SOCIAL SCIENCE & MEDICINE | 1,691

SOCIAL SCIENCE COMPUTER REVIEW | 0,429

SOCIAL SCIENCE HISTORY | 0,195

SOCIAL SCIENCE INFORMATION SUR LES SCIENCES SOCIALES | 0,264

SOCIAL SCIENCE JOURNAL | 0,140

SOCIAL SCIENCE QUARTERLY | 0,670

SOCIAL SCIENCE RESEARCH | 0,882

SOCIAL SECURITY BULLETIN | 0,391

SOCIAL SERVICE REVIEW | 0,447

SOCIAL STUDIES OF SCIENCE | 1,115

SOCIAL WORK | 1,372

SOCIAL WORK & SOCIAL SCIENCES REVIEW | 0,000

SOCIAL WORK IN HEALTH CARE | 0,456

SOCIAL WORK RESEARCH | 0,634

SOCIETY | 0,092

SOCIETY & ANIMALS | 0,444

SOCIETY & NATURAL RESOURCES | 0,526

SOCIOLOGIA | 0,115

SOCIOLOGIA RURALIS | 1,132

SOCIOLOGICAL FORUM | 0,667

SOCIOLOGICAL INQUIRY | 0,268

SOCIOLOGICAL METHODOLOGY | 1,227

SOCIOLOGICAL METHODS & RESEARCH | 1,258

SOCIOLOGICAL PERSPECTIVES | 0,451

SOCIOLOGICAL QUARTERLY | 0,600

SOCIOLOGICAL RESEARCH ONLINE | 0,211

SOCIOLOGICAL REVIEW | 1,069

SOCIOLOGICAL SPECTRUM | 0,231

SOCIOLOGICAL THEORY | 0,679

SOCIOLOGICAL THEORY AND METHODS | 0,026

SOCIOLOGICKY CASOPIS | 0,080

SOCIOLOGIE DU TRAVAIL | 0,231

SOCIOLOGISK FORSKNING | 0,119

SOCIOLOGY OF EDUCATION | 1,241

SOCIOLOGY OF HEALTH & ILLNESS | 1,481

SOCIOLOGY OF RELIGION | 0,545

SOCIOLOGY OF SPORT JOURNAL | 0,297

SOCIOLOGY-THE JOURNAL OF THE BRITISH SOCIOLOGICAL ASSOCIATION | 1,408

SOTSIOLOGICHESKIE ISSLEDOVANIYA | 0,146

SOUTH AFRICAN JOURNAL OF ECONOMICS | 0,104

SOUTH AFRICAN JOURNAL OF PSYCHOLOGY | 0,220

SOUTHERN CALIFORNIA LAW REVIEW | 1,873

SOUTHERN ECONOMIC JOURNAL | 0,417

SOZIALE WELT-ZEITSCHRIFT FUR SOZIALWISSENSCHAFTLICHE FORSCHUNG UND PRAXIS | 0,271

SPACE POLICY | 0,167

SPATIAL VISION | 1,324

SPORT PSYCHOLOGIST | 0,649

SPRACHE & KOGNITION | 0,357

STANFORD JOURNAL OF INTERNATIONAL LAW | 0,471

STANFORD LAW REVIEW | 5,414

STRATEGIC MANAGEMENT JOURNAL | 2,531

STRESS MEDICINE | 0,759

STUDIA PSYCHOLOGICA | 0,292

STUDIES IN AMERICAN POLITICAL DEVELOPMENT | 0,250

STUDIES IN COMPARATIVE INTERNATIONAL DEVELOPMENT | 0,147

STUDIES IN EAST EUROPEAN THOUGHT | 0,286

STUDIES IN FAMILY PLANNING | 0,984

STUDIES IN HIGHER EDUCATION | 0,636

STUDIES IN HISTORY AND PHILOSOPHY OF SCIENCE | 1,000

STUDIES IN NONLINEAR DYNAMICS AND ECONOMETRICS | 0,150

STUDIES IN SYMBOLIC INTERACTION | 0,091

SUBSTANCE USE & MISUSE | 0,687

SUICIDE AND LIFE-THREATENING BEHAVIOR | 1,306

SUPREME COURT REVIEW | 1,294

SWISS JOURNAL OF PSYCHOLOGY | 0,133

SYMBOLIC INTERACTION | 0,966

SYNTAX AND SEMANTICS | 0,205

SYNTHESE | 0,147

SYSTEM DYNAMICS REVIEW | 0,455

SYSTEM FAMILIE | 0,387

SYSTEMIC PRACTICE AND ACTION RESEARCH | 0,179

SYSTEMS RESEARCH AND BEHAVIORAL SCIENCE | 0,242

TEACHERS COLLEGE RECORD | 0,300

TEACHING AND TEACHER EDUCATION | 0,317

TEACHING OF PSYCHOLOGY | 0,352

TEACHING SOCIOLOGY | 0,484

TECHNICAL COMMUNICATION | 0,393

TECHNOLOGICAL FORECASTING AND SOCIAL CHANGE | 0,231

TECHNOLOGY AND CULTURE | 0,549

TECHNOLOGY IN SOCIETY | 0,185

TELECOMMUNICATIONS POLICY | 0,731

TESOL QUARTERLY | 0,806

TEXAS LAW REVIEW | 3,038

THEORETICAL MEDICINE AND BIOETHICS | 0,443

THEORY & PSYCHOLOGY | 1,372

THEORY AND DECISION | 0,453

THEORY AND SOCIETY | 1,277

THEORY CULTURE & SOCIETY | 1,105

THEORY INTO PRACTICE | 0,191

THIRD WORLD PLANNING REVIEW | 0,195

THIRD WORLD QUARTERLY | 0,311

TIDSSKRIFT FOR SAMFUNNSFORSKNING | 0,161

TIJDSCHRIFT VOOR ECONOMISCHE EN SOCIALE GEOGRAFIE | 0,311

TIME & SOCIETY | 0,462

TOBACCO CONTROL | 1,717

TOPICS IN EARLY CHILDHOOD SPECIAL EDUCATION | 1,081

TOPICS IN GERIATRIC REHABILITATION | 0,203

TOPICS IN LANGUAGE DISORDERS | 0,404

TOTAL QUALITY MANAGEMENT | 0,269

TOURISM MANAGEMENT | 0,328

TRAINING & DEVELOPMENT | 0,102

TRANSACTIONS OF THE INSTITUTE OF BRITISH GEOGRAPHERS | 2,698

TRANSPORT REVIEWS | 0,568

TRANSPORTATION | 0,250

TRANSPORTATION JOURNAL | 0,206

TRANSPORTATION QUARTERLY | 0,082

TRANSPORTATION RESEARCH PART A-POLICY AND PRACTICE | 0,280

TRANSPORTATION RESEARCH PART B-METHODOLOGICAL | 0,442

TRANSPORTATION RESEARCH PART D-TRANSPORT AND ENVIRONMENT | 0,443

TRANSPORTATION RESEARCH PART E-LOGISTICS AND TRANSPORTATION REVIEW | 0,128

TRANSPORTATION SCIENCE | 0,714

TRAVAIL HUMAIN | 0,212

TRIMESTRE ECONOMICO | 0,045

TURK PSIKOLOJI DERGISI | 0,214

UCLA LAW REVIEW | 2,765

UNIVERSITY OF CHICAGO LAW REVIEW | 2,338

UNIVERSITY OF CINCINNATI LAW REVIEW | 0,857

UNIVERSITY OF ILLINOIS LAW REVIEW | 1,352

UNIVERSITY OF PENNSYLVANIA JOURNAL OF INTERNATIONAL ECONOMIC LAW | 0,667

UNIVERSITY OF PENNSYLVANIA LAW REVIEW | 3,278

UNIVERSITY OF PITTSBURGH LAW REVIEW | 0,919

URBAN AFFAIRS REVIEW | 0,746

URBAN EDUCATION | 0,386

URBAN GEOGRAPHY | 0,831

URBAN LAWYER | 0,486

URBAN STUDIES | 0,816

VANDERBILT LAW REVIEW | 2,718

VENEREOLOGY-THE INTERDISCIPLINARY INTERNATIONAL JOURNAL OF SEXUAL HEALTH | 0,237

VERHALTENSTHERAPIE | 0,311

VIRGINIA LAW REVIEW | 4,029

VISUAL COGNITION | 0,295

VOLTA REVIEW | 0,021

VOPROSY PSIKHOLOGII | 0,169

WASHINGTON LAW REVIEW | 0,667

WASHINGTON QUARTERLY | 0,167

WELTWIRTSCHAFTLICHES ARCHIV-REVIEW OF WORLD ECONOMICS | 0,277

WESTERN JOURNAL OF COMMUNICATION | 0,149

WESTERN JOURNAL OF NURSING RESEARCH | 0,329

WISCONSIN LAW REVIEW | 1,134

WOMEN & HEALTH | 0,904

WOMEN & POLITICS | 0,229

WOMEN & THERAPY | 0,115

WOMENS HEALTH ISSUES | 0,611

WOMENS STUDIES INTERNATIONAL FORUM | 0,216

WORK AND OCCUPATIONS | 1,281

WORK AND STRESS | 0,824

WORK EMPLOYMENT AND SOCIETY | 0,952

WORKFORCE | 0,075

WORLD BANK ECONOMIC REVIEW | 0,643

WORLD BANK RESEARCH OBSERVER | 1,036

WORLD DEVELOPMENT | 0,810

WORLD ECONOMY | 0,696

WORLD POLICY JOURNAL | 0,225

WORLD POLITICS | 4,452

WORLD TODAY | 0,044

WRITTEN COMMUNICATION | 0,536

YALE LAW JOURNAL | 4,729

YEARBOOK OF PHYSICAL ANTHROPOLOGY | 1,846

YOUNG CHILDREN | 0,295

YOUTH & SOCIETY | 0,395

ZEITSCHRIFT FUR ARBEITS-UND ORGANISATIONSPSYCHOLOGIE | 0,333

ZEITSCHRIFT FUR BIBLIOTHEKSWESEN UND BIBLIOGRAPHIE | 0,105

ZEITSCHRIFT FUR ENTWICKLUNGSPSYCHOLOGIE UND PADAGOGISCHE PSYCHOLOGIE | 0,345

ZEITSCHRIFT FUR EXPERIMENTELLE PSYCHOLOGIE | 0,500

ZEITSCHRIFT FUR GERONTOLOGIE UND GERIATRIE | 0,458

ZEITSCHRIFT FUR KINDER-UND JUGENDPSYCHIATRIE UND PSYCHOTHERAPIE | 0,375

ZEITSCHRIFT FUR KLINISCHE PSYCHOLOGIE PSYCHIATRIE UND PSYCHOTHERAPIE | 0,500

ZEITSCHRIFT FUR KLINISCHE PSYCHOLOGIE UND PSYCHOTHERAPIE | 0,193

ZEITSCHRIFT FUR PADAGOGIK | 0,189

ZEITSCHRIFT FUR PADAGOGISCHE PSYCHOLOGIE | 1,743

ZEITSCHRIFT FUR PSYCHOLOGIE | 0,167

ZEITSCHRIFT FUR PSYCHOSOMATISCHE MEDIZIN UND PSYCHOTHERAPIE | 0,490

ZEITSCHRIFT FUR SOZIALPSYCHOLOGIE | 0,341

ZEITSCHRIFT FUR SOZIOLOGIE | 0,604

ZYGON | 0,293